'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-6172c188.js');
const transitions = require('./transitions-141d664d.js');
const portal = require('./portal-b7d8bc84.js');
require('./utils-3ac69d07.js');

const bannerQueue = [];
const MxBanner = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.mxClose = index.createEvent(this, "mxClose", 7);
    this.hasActions = false;
    this.isOpen = false;
    this.type = 'default';
    this.isVisible = false;
  }
  async toggleBanner() {
    if (this.isOpen) {
      try {
        if (this.queueItem && bannerQueue.includes(this.queueItem))
          return;
        await this.waitForOtherBanners();
        portal.moveToPortal(this.element);
        this.isVisible = true;
        transitions.slideIn(this.element, 400, transitions.Direction.top, 'var(--mds-animation-ease-bounce)');
      }
      catch (err) {
      }
    }
    else {
      this.removeFromQueue();
      this.isVisible = false;
      this.mxClose.emit();
    }
  }
  componentWillLoad() {
    this.hasActions = !!this.element.querySelector('[slot="actions"]');
  }
  connectedCallback() {
    this.toggleBanner();
  }
  waitForOtherBanners() {
    return new Promise((resolve, reject) => {
      this.queueItem = { resolve, reject };
      bannerQueue.push(this.queueItem);
      if (bannerQueue.length === 1)
        return resolve();
    });
  }
  removeFromQueue() {
    if (!this.queueItem)
      return;
    const queueIndex = bannerQueue.indexOf(this.queueItem);
    bannerQueue.splice(bannerQueue.indexOf(this.queueItem), 1);
    if (queueIndex === 0 && bannerQueue.length > 0)
      bannerQueue[0].resolve();
  }
  async close() {
    if (!this.isOpen)
      return;
    await transitions.slideOut(this.element, 400, transitions.Direction.top, 'var(--mds-animation-ease-bounce)');
    this.isOpen = false;
  }
  onAlertClick() {
    if (this.hasActions)
      return;
    this.close();
  }
  get hostClass() {
    let str = 'flex fixed left-0 top-0 px-12 w-full justify-center pointer-events-none z-50';
    if (!this.isVisible)
      str += ' hidden';
    if (this.type !== 'default')
      str += ' ' + this.type;
    return str;
  }
  get alertClass() {
    let str = 'mx-banner-alert mt-30 flex items-center rounded sm:rounded-full shadow-drop sm:h-60 py-16 sm:py-0 pl-12 pr-12 sm:pr-20 pointer-events-auto';
    if (!this.hasActions)
      str += ' cursor-pointer';
    return str;
  }
  get avatarIcon() {
    if (this.type === 'warning')
      return 'mds-warning';
    return 'mds-hand-waving';
  }
  render() {
    return (index.h(index.Host, { class: this.hostClass }, index.h("div", { role: "alert", class: this.alertClass, onClick: this.onAlertClick.bind(this) }, index.h("div", { class: "flex-shrink-0 self-start sm:self-auto", "data-testid": "avatar" }, index.h("slot", { name: "avatar" }, index.h("mx-avatar", { icon: this.avatarIcon }))), index.h("div", { class: "flex-1 flex flex-col sm:flex-row sm:items-center pl-16 sm:pl-20" }, index.h("p", { class: "flex-1 my-0 leading-none text-4 break-anywhere font-bold pr-16", "data-testid": "message" }, index.h("slot", null)), index.h("div", { class: "flex-shrink-0 -ml-8 sm:ml-0 -mb-8 sm:mb-0", "data-testid": "actions", onClick: this.close.bind(this) }, index.h("slot", { name: "actions" }))), index.h("button", { type: "button", class: "flex w-30 h-30 items-center justify-center", "data-testid": "close-button", onClick: this.close.bind(this) }, index.h("i", { class: "mds-x" })))));
  }
  get element() { return index.getElement(this); }
  static get watchers() { return {
    "isOpen": ["toggleBanner"]
  }; }
};

exports.mx_banner = MxBanner;

//# sourceMappingURL=mx-banner.cjs.entry.js.map