'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-6172c188.js');
const utils = require('./utils-3ac69d07.js');

const MxBlockFileInput = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.mxThumbnailChange = index.createEvent(this, "mxThumbnailChange", 7);
    this.uuid = utils.uuidv4();
    this.accept = undefined;
    this.acceptImage = false;
    this.acceptPdf = false;
    this.assistiveText = undefined;
    this.chooseBtnType = 'contained';
    this.chooseFileText = 'Choose File';
    this.colspan = undefined;
    this.disabled = false;
    this.error = false;
    this.filename = undefined;
    this.inputId = undefined;
    this.label = undefined;
    this.name = undefined;
    this.placeholder = 'No file chosen';
    this.readonly = false;
    this.thumbnailSize = 'cover';
    this.thumbnailUrl = undefined;
    this.thumbnailDataUri = undefined;
  }
  onThumbnailUrlChange() {
    this.mxThumbnailChange.emit(this.thumbnailUrl);
  }
  connectedCallback() {
    this.onThumbnailUrlChange();
  }
  async removeFile() {
    if (this.disabled || this.readonly)
      return;
    if (!this.isFileSelected)
      return;
    this.filename = null;
    this.thumbnailUrl = null;
    this.fileInput.value = '';
    this.fileInput.dispatchEvent(new window.Event('change', { bubbles: true, cancelable: true }));
    this.fileInput.dispatchEvent(new window.Event('input', { bubbles: true, cancelable: true }));
  }
  async selectFile() {
    if (this.disabled || this.readonly)
      return;
    this.fileInput.click();
  }
  onFocus() {
    this.error = false;
  }
  onInput(e) {
    this.error = false;
    if (this.fileInput.value) {
      this.filename = e.target.files[0].name;
      this.setThumnailDataUri(e.target.files[0]);
    }
    else {
      this.filename = null;
      this.thumbnailUrl = null;
      this.thumbnailDataUri = null;
    }
  }
  setThumnailDataUri(file) {
    this.thumbnailDataUri = null;
    if (!/\.(jpe?g|png|gif)$/i.test(file.name))
      return;
    const reader = new FileReader();
    reader.onload = () => {
      this.thumbnailDataUri = reader.result;
      this.mxThumbnailChange.emit(this.thumbnailDataUri);
    };
    reader.readAsDataURL(file);
  }
  getElementId(suffix = '') {
    if (suffix)
      suffix = '-' + suffix;
    return (this.inputId || this.uuid) + suffix;
  }
  get isFileSelected() {
    if (this.filename || this.thumbnailUrl)
      return true;
    if (this.fileInput && this.fileInput.value)
      return true;
    return false;
  }
  get acceptString() {
    const accepts = [];
    if (this.acceptImage)
      accepts.push('image/*');
    if (this.acceptPdf)
      accepts.push('.pdf');
    if (this.accept)
      accepts.push(this.accept);
    return accepts.join(',') || null;
  }
  get thumbnailBackgroundImage() {
    let url = this.thumbnailUrl;
    if (this.fileInput && this.fileInput.value)
      url = this.thumbnailDataUri;
    if (!url)
      return null;
    return `url(${url})`;
  }
  get thumbnailBackgroundSize() {
    if (!['contain', 'cover', 'auto', 'stretch'].includes(this.thumbnailSize))
      return 'cover';
    if (this.thumbnailSize === 'stretch')
      return '100% 100%';
    return this.thumbnailSize;
  }
  get hostClass() {
    let str = 'mx-block-input mx-block-file-input';
    if (this.colspan > 0 && this.colspan < 7) {
      str += ' col-span-' + this.colspan;
    }
    return str;
  }
  get containerClass() {
    let str = 'mx-block-input-container';
    if (this.disabled || this.readonly)
      str += ' disabled';
    if (this.error)
      str += ' error';
    return str;
  }
  render() {
    const removeButton = !this.disabled && !this.readonly && this.isFileSelected && (index.h("button", { type: "button", class: "clear-button flex items-center justify-center w-20 text-1", onClick: this.removeFile.bind(this), "aria-label": "Remove file", title: "Remove file", "data-testid": "remove-file-button" }, index.h("i", { class: "mds-x" })));
    return (index.h(index.Host, { class: this.hostClass }, index.h("div", { class: this.containerClass }, index.h("input", { ref: el => (this.fileInput = el), class: "absolute pointer-events-none opacity-0", id: this.getElementId(), name: this.name, "aria-describedby": [this.getElementId('assistive'), this.getElementId('filename')].join(' '), type: "file", accept: this.acceptString, disabled: this.disabled, readonly: this.readonly, tabindex: "-1", onInput: this.onInput.bind(this) }), this.isFileSelected && this.thumbnailBackgroundImage && (index.h("div", { "data-testid": "thumbnail", class: "thumbnail w-80 h-80 bg-center bg-no-repeat flex-shrink-0", style: { backgroundImage: this.thumbnailBackgroundImage, backgroundSize: this.thumbnailBackgroundSize } })), index.h("div", { class: "mx-block-input-grid" }, index.h("label", { class: "text-small", htmlFor: this.getElementId(), onClick: e => e.preventDefault() }, this.label, index.h("slot", { name: "label" }), this.assistiveText && index.h("span", { id: this.getElementId('assistive') }, this.assistiveText)), index.h("span", { id: this.getElementId('filename'), class: "input-value truncate", "aria-live": "polite", title: this.filename, "data-testid": "filename" }, !this.isFileSelected && index.h("span", { class: "opacity-60" }, this.placeholder), this.filename), removeButton, index.h("mx-button", { "btn-type": this.chooseBtnType, hug: true, small: true, disabled: this.disabled || this.readonly, onClick: this.selectFile.bind(this), "data-testid": "choose-file-button" }, this.chooseFileText)))));
  }
  get element() { return index.getElement(this); }
  static get watchers() { return {
    "thumbnailUrl": ["onThumbnailUrlChange"]
  }; }
};

exports.mx_block_file_input = MxBlockFileInput;

//# sourceMappingURL=mx-block-file-input.cjs.entry.js.map