'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-6172c188.js');
const utils = require('./utils-3ac69d07.js');

const MxBlockInput = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.mxClear = index.createEvent(this, "mxClear", 7);
    this.dataAttributes = {};
    this.uuid = utils.uuidv4();
    this.componentWillRender = utils.propagateDataAttributes;
    this.assistiveText = undefined;
    this.autofocus = false;
    this.colspan = undefined;
    this.disabled = false;
    this.error = false;
    this.inputId = undefined;
    this.label = undefined;
    this.maxlength = undefined;
    this.name = undefined;
    this.placeholder = undefined;
    this.readonly = false;
    this.type = 'text';
    this.value = undefined;
    this.isFocused = false;
    this.characterCount = 0;
  }
  componentDidLoad() {
    this.updateValue();
  }
  onValueChange() {
    this.updateValue();
  }
  updateValue() {
    this.textInput.value = this.hasValue ? this.value : '';
  }
  onFocus() {
    this.isFocused = true;
    this.error = false;
  }
  onBlur() {
    this.isFocused = false;
  }
  onContainerClick(e) {
    if (this.disabled || this.readonly)
      return;
    const slottedButton = this.element.querySelector('[slot="button"]');
    if (slottedButton && slottedButton.contains(e.target))
      return;
    this.textInput.focus();
  }
  onClearClick() {
    this.value = '';
    this.textInput.dispatchEvent(new window.Event('input', { bubbles: true }));
    this.mxClear.emit();
    if (typeof jest === 'undefined')
      this.textInput.focus();
  }
  onInput(e) {
    this.characterCount = e.target.value.length;
    this.value = e.target.value;
  }
  get hasValue() {
    return this.value !== null && this.value !== '' && this.value !== undefined;
  }
  get hostClass() {
    let str = 'mx-block-input';
    if (this.colspan > 0 && this.colspan < 7) {
      str += ' md:col-span-' + this.colspan;
    }
    return str;
  }
  get containerClass() {
    let str = 'mx-block-input-container';
    if (this.disabled)
      str += ' disabled';
    if (this.error)
      str += ' error';
    return str;
  }
  render() {
    const clearButton = !this.disabled && !this.readonly && this.value && (index.h("button", { type: "button", class: "clear-button flex items-center justify-center w-20 text-2", onClick: this.onClearClick.bind(this), "aria-label": `Clear ${this.label}`, title: `Clear ${this.label}`, "data-testid": "clear-button" }, index.h("i", { class: "mds-cross transform rotate-45" })));
    return (index.h(index.Host, { class: this.hostClass }, index.h("div", { class: this.containerClass, onClick: this.onContainerClick.bind(this) }, index.h("div", { class: "mx-block-input-grid" }, index.h("label", { class: "text-small", htmlFor: this.inputId || this.uuid }, this.label, index.h("slot", { name: "label" }), this.assistiveText && index.h("span", { id: this.inputId || this.uuid + '-assistive' }, this.assistiveText)), index.h("input", Object.assign({ "aria-describedby": this.assistiveText ? (this.inputId || this.uuid) + '-assistive' : null, autofocus: this.autofocus, disabled: this.disabled, id: this.inputId || this.uuid, maxlength: this.maxlength, name: this.name, onBlur: this.onBlur.bind(this), onFocus: this.onFocus.bind(this), onInput: this.onInput.bind(this), placeholder: this.placeholder, readonly: this.readonly, ref: el => (this.textInput = el), type: this.type, value: this.value }, this.dataAttributes)), clearButton, index.h("slot", { name: "button" })))));
  }
  get element() { return index.getElement(this); }
  static get watchers() { return {
    "value": ["onValueChange"]
  }; }
};

exports.mx_block_input = MxBlockInput;

//# sourceMappingURL=mx-block-input.cjs.entry.js.map