'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-6172c188.js');
const utils = require('./utils-3ac69d07.js');
const popover = require('./popover-ca69b525.js');
const transitions = require('./transitions-141d664d.js');
const minWidthSync = require('./minWidthSync-44c5ae26.js');

const MxCheckbox = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.dataAttributes = {};
    this.componentWillRender = utils.propagateDataAttributes;
    this.name = '';
    this.value = '';
    this.labelLeft = false;
    this.labelName = '';
    this.labelClass = '';
    this.hideLabel = false;
    this.checked = false;
    this.userchecked = false;
    this.disabled = false;
    this.indeterminate = false;
    this.elAriaLabel = undefined;
  }
  get checkClass() {
    let str = 'flex h-18 w-18 flex-shrink-0';
    str += this.labelLeft ? ' order-2' : ' order-1';
    if (this.labelLeft && !this.hideLabel)
      str += ' ml-16';
    if (this.userchecked)
      str += ' userchecked';
    return str;
  }
  get checkLabelClass() {
    let str = 'checkbox-label inline-block';
    if (this.hideLabel)
      str += ' sr-only';
    str += this.labelLeft ? ' order-1 flex-1' : ' order-2';
    if (!this.labelLeft && !this.hideLabel)
      str += ' ml-16';
    return str;
  }
  onInput(e) {
    this.checked = this.userchecked = e.target.checked;
  }
  render() {
    return (index.h(index.Host, { class: "mx-checkbox inline-flex items-center" }, index.h("label", { class: [
        'relative flex-1 inline-flex flex-nowrap align-center items-center text-4' +
          (this.disabled ? '' : ' cursor-pointer'),
        this.labelClass,
      ].join(' ') }, index.h("input", Object.assign({ class: 'absolute h-0 w-0 opacity-0' + (this.indeterminate ? ' indeterminate' : ''), type: "checkbox", "aria-label": this.elAriaLabel, name: this.name, value: this.value, checked: this.checked, disabled: this.disabled, indeterminate: this.indeterminate }, this.dataAttributes, { onInput: this.onInput.bind(this) })), index.h("span", { class: this.checkClass }), index.h("div", { class: this.checkLabelClass, "data-testid": "labelName" }, this.labelName))));
  }
  get element() { return index.getElement(this); }
};

const MxMenu = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.mxClose = index.createEvent(this, "mxClose", 7);
    this.mxOpen = index.createEvent(this, "mxOpen", 7);
    this.isClosing = false;
    this.uuid = utils.uuidv4();
    this.anchorEl = undefined;
    this.autocompleteOnly = false;
    this.triggerEl = undefined;
    this.offset = undefined;
    this.placement = 'bottom-start';
    this.isOpen = false;
    this.squared = false;
  }
  onMenuItemClick() {
    this.closeMenu();
  }
  onClick(e) {
    const triggerEl = this.triggerEl || this.anchorEl;
    const triggerElWasClicked = triggerEl && triggerEl.contains(e.target);
    if (triggerElWasClicked)
      e.preventDefault();
    if (!this.isOpen && triggerElWasClicked) {
      this.openMenu();
      e.preventDefault();
    }
    else if (this.isOpen && this.element && !this.element.contains(e.target)) {
      if (this.isSubMenu && triggerElWasClicked)
        return;
      if (this.inputEl && this.inputEl.contains(e.target))
        return;
      this.closeMenu();
    }
  }
  onFocus(e) {
    if (!this.anchorEl)
      return;
    if (this.isOpen && !this.anchorEl.contains(e.target) && !this.element.contains(e.target))
      this.closeMenu();
  }
  onDocumentKeyDown(e) {
    const isFocused = (el) => el && el.contains(e.target);
    const enabledMenuItems = this.menuItems.filter(m => !m.disabled);
    if (this.autocompleteOnly && this.inputEl && this.isOpen && e.key === 'Enter' && !isFocused(this.element)) {
      e.preventDefault();
      enabledMenuItems.length && enabledMenuItems[0].click();
      this.onMenuItemClick();
      return;
    }
    const openKeys = ['Enter'];
    if (!this.inputEl)
      openKeys.push(' ');
    if (openKeys.includes(e.key) && this.anchorEl && isFocused(this.anchorEl)) {
      (this.triggerEl || this.anchorEl).click();
      e.preventDefault();
      e.stopPropagation();
      return;
    }
    if (!this.isOpen && this.inputEl && isFocused(this.inputEl)) {
      if (['Escape', 'Tab'].includes(e.key))
        return;
      (this.triggerEl || this.anchorEl).click();
    }
    if (!this.isOpen)
      return;
    const shouldEditInput = e.key.length === 1 || ['Backspace', 'Delete', 'ArrowLeft', 'ArrowRight'].includes(e.key);
    if (this.inputEl && shouldEditInput && !isFocused(this.inputEl)) {
      this.inputEl.focus();
    }
    else if (e.key === 'Escape') {
      this.closeMenu();
      e.preventDefault();
    }
    else if (['Tab', 'ArrowDown'].includes(e.key) && isFocused(this.anchorEl) && enabledMenuItems.length > 0) {
      if (e.shiftKey && e.key === 'Tab')
        return;
      if (!this.inputEl || !this.autocompleteOnly) {
        enabledMenuItems[0].focusMenuItem();
      }
      else if (this.autocompleteOnly && enabledMenuItems.length >= 2) {
        enabledMenuItems[1].focusMenuItem();
      }
      e.preventDefault();
      e.stopPropagation();
    }
    else if (e.key === 'ArrowUp' && isFocused(this.inputEl)) {
      e.preventDefault();
    }
    else if (this.inputEl && isFocused(this.inputEl)) {
      this.isOpen = !this.isOpen;
      this.isOpen = !this.isOpen;
    }
  }
  onKeydown(e) {
    if (!this.isOpen)
      return;
    if (!['ArrowDown', 'ArrowUp'].includes(e.key))
      return;
    e.preventDefault();
    e.stopPropagation();
    const tabbableMenuItems = [];
    this.menuItems.forEach(m => {
      if (m.disabled)
        return;
      tabbableMenuItems.push(m);
      const accordionMenuItems = m.querySelectorAll('[aria-expanded="true"] + mx-menu-accordion mx-menu-item');
      tabbableMenuItems.push(...Array.from(accordionMenuItems));
    });
    const focusedMenuItem = document.activeElement ? document.activeElement.closest('mx-menu-item') : null;
    const focusedIndex = tabbableMenuItems.findIndex(m => m === focusedMenuItem);
    if (e.key === 'ArrowDown' && focusedIndex !== tabbableMenuItems.length - 1) {
      tabbableMenuItems[focusedIndex + 1].focusMenuItem();
    }
    else if (e.key === 'ArrowUp' && focusedIndex > 0) {
      tabbableMenuItems[focusedIndex - 1].focusMenuItem();
    }
  }
  async openMenu() {
    if (this.isOpen || !this.anchorEl)
      return false;
    this.isOpen = true;
    this.mxOpen.emit();
    const offset = this.offset || (this.isSubMenu ? [-8, 0] : [0, 1]);
    this.popoverInstance = await popover.createPopover(this.anchorEl, this.element, this.placement, offset);
    await transitions.fadeScaleIn(this.menuElem, undefined, popover.convertPlacementToOrigin(this.popoverInstance.state.placement));
    return true;
  }
  setTriggerElAttributes() {
    if (!this.anchorEl && !this.triggerEl)
      return;
    (this.triggerEl || this.anchorEl).setAttribute('aria-haspopup', 'true');
    (this.triggerEl || this.anchorEl).setAttribute('aria-controls', this.uuid);
  }
  async closeMenu() {
    if (!this.isOpen || this.isClosing)
      return false;
    this.isClosing = true;
    this.menuItems.forEach(m => m.closeSubMenu());
    await transitions.fadeOut(this.menuElem);
    this.menuItems.forEach(m => m.closeAccordion(true));
    this.isClosing = false;
    this.mxClose.emit();
    this.isOpen = false;
    if (!this.popoverInstance)
      return true;
    this.popoverInstance.destroy();
    this.popoverInstance = null;
    return true;
  }
  componentDidLoad() {
    this.setInputEl();
    if (this.menuItems.length) {
      const role = this.element.querySelector('[role="option"]') ? 'listbox' : 'menu';
      this.scrollElem.setAttribute('role', role);
    }
    this.setTriggerElAttributes();
  }
  componentWillUpdate() {
    this.setInputEl();
    this.anchorEl &&
      this.anchorEl.getAttribute('role') === 'menuitem' &&
      this.anchorEl.setAttribute('aria-expanded', this.isOpen ? 'true' : 'false');
    if (this.inputEl && this.anchorEl)
      this.element.style.width = this.anchorEl.getBoundingClientRect().width + 'px';
    const anyMenuItemHasIcon = this.menuItems.some(m => !!m.icon);
    if (anyMenuItemHasIcon) {
      this.menuItems.forEach(m => {
        if (m.icon === undefined)
          m.icon = null;
      });
    }
    if (this.inputEl) {
      this.menuItems.forEach(async (m) => {
        m.selected = this.inputEl.value === (await m.getValue());
      });
    }
  }
  setInputEl() {
    if (this.anchorEl && !this.inputEl) {
      this.inputEl = this.anchorEl.querySelector('input[type="text"], input[type="search"]');
      this.inputEl && this.inputEl.setAttribute('autocomplete', 'off');
    }
  }
  get menuItems() {
    const menuItems = [];
    Array.from(this.scrollElem.children).forEach((el) => {
      if (el.tagName === 'MX-MENU-ITEM')
        menuItems.push(el);
      if (el.getAttribute('role') === 'group') {
        menuItems.push(...Array.from(el.children).filter(e => e.tagName === 'MX-MENU-ITEM'));
      }
    });
    return menuItems;
  }
  get isSubMenu() {
    return this.element.hasAttribute('slot') && this.element.getAttribute('slot') === 'submenu';
  }
  get hostClass() {
    let str = 'mx-menu block z-50 w-screen sm:w-auto';
    if (!this.isOpen)
      str += ' hidden';
    if (this.autocompleteOnly)
      str += ' autocomplete-only';
    return str;
  }
  get menuClass() {
    let str = 'flex flex-col';
    if (this.squared) {
      str += ' border shadow-drop';
    }
    else {
      str += ' shadow-9 rounded';
    }
    if (!this.isOpen)
      str += ' hidden';
    if (this.autocompleteOnly)
      str += ' autocomplete-only';
    return str;
  }
  render() {
    return (index.h(index.Host, { class: this.hostClass }, index.h("div", { ref: el => (this.menuElem = el), class: this.menuClass }, index.h("div", { id: this.uuid, ref: el => (this.scrollElem = el), class: "scroll-wrapper overflow-y-auto overflow-x-hidden overscroll-contain" }, index.h("slot", null)))));
  }
  get element() { return index.getElement(this); }
  static get watchers() { return {
    "anchorEl": ["setTriggerElAttributes"],
    "triggerEl": ["setTriggerElAttributes"]
  }; }
};

const MxMenuItem = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.mxClick = index.createEvent(this, "mxClick", 7);
    this.hasParentLink = false;
    this.checked = false;
    this.disabled = false;
    this.icon = undefined;
    this.label = undefined;
    this.subtitle = undefined;
    this.multiSelect = false;
    this.selected = false;
    this.minWidths = new minWidthSync.MinWidths();
    this.accordion = undefined;
  }
  onMouseEnter() {
    this.closeSiblingSubMenus();
    this.focusMenuItem();
    if (this.submenu) {
      clearTimeout(this.submenuDelayTimeout);
      this.submenuDelayTimeout = setTimeout(this.openSubMenu.bind(this), 150);
    }
  }
  onMouseLeave() {
    clearTimeout(this.submenuDelayTimeout);
    if (!this.disabled)
      document.activeElement.blur();
  }
  onFocus() {
    this.closeSiblingSubMenus();
  }
  onKeyDown(e) {
    if (this.accordion)
      return this.onKeyDownAccordion(e);
    if (this.submenu)
      return this.onKeyDownSubMenu(e);
    const clickKeys = ['Enter'];
    if (this.multiSelect)
      clickKeys.push(' ');
    if (clickKeys.includes(e.key)) {
      e.preventDefault();
      e.stopPropagation();
      document.activeElement.click();
    }
  }
  componentWillLoad() {
    this.submenu = this.element.querySelector('[slot="submenu"]');
    this.accordion = this.element.querySelector('[slot="accordion"]');
  }
  componentDidLoad() {
    if (this.accordion)
      this.accordion.anchorEl = this.menuItemElem;
  }
  connectedCallback() {
    const parentLink = this.element.closest('a');
    if (parentLink) {
      this.hasParentLink = true;
      parentLink.setAttribute('role', 'menuitem');
    }
    else {
      this.role = this.element.closest('mx-dropdown-menu') ? 'option' : 'menuitem';
    }
    minWidthSync.minWidthSync.subscribeComponent(this);
  }
  disconnectedCallback() {
    minWidthSync.minWidthSync.unsubscribeComponent(this);
  }
  async closeAccordion(skipTransition = false) {
    if (this.accordion) {
      return await this.accordion.closeMenu(skipTransition);
    }
  }
  async closeSubMenu() {
    if (this.submenu) {
      clearTimeout(this.submenuDelayTimeout);
      return await this.submenu.closeMenu();
    }
  }
  async getValue() {
    return this.slotWrapper && this.slotWrapper.innerText.trim();
  }
  async focusMenuItem() {
    if (this.disabled)
      return;
    if (this.multiSelect) {
      const label = this.menuItemElem.querySelector('mx-checkbox label');
      label && label.focus();
    }
    else {
      this.menuItemElem.focus();
    }
  }
  onKeyDownAccordion(e) {
    if (!['Enter', ' ', 'ArrowRight', 'ArrowLeft'].includes(e.key))
      return;
    e.preventDefault();
    e.stopPropagation();
    if (e.key === 'ArrowRight') {
      this.accordion.openMenu();
    }
    else if (e.key === 'ArrowLeft') {
      this.accordion.closeMenu();
      this.focusMenuItem();
    }
    else {
      document.activeElement.click();
    }
  }
  async onKeyDownSubMenu(e) {
    if (['Enter', ' ', 'ArrowRight'].includes(e.key)) {
      e.preventDefault();
      e.stopPropagation();
      const didOpen = await this.openSubMenu();
      if (didOpen) {
        const firstMenuItem = this.element.querySelector('mx-menu-item:not(:disabled)');
        firstMenuItem && firstMenuItem.focusMenuItem();
      }
    }
    else if (e.key === 'ArrowLeft') {
      e.preventDefault();
      e.stopPropagation();
      const didClose = await this.closeSubMenu();
      if (didClose) {
        this.focusMenuItem();
      }
      else {
        this.element.parentElement.dispatchEvent(new KeyboardEvent(e.type, e));
      }
    }
  }
  closeSiblingSubMenus() {
    const siblingMenuItems = Array.from(this.element.parentElement.children).filter(e => e !== this.element && e.tagName === 'MX-MENU-ITEM');
    siblingMenuItems.forEach((m) => m.closeSubMenu());
  }
  openSubMenu() {
    if (this.submenu) {
      this.submenu.placement = 'right-start';
      this.submenu.anchorEl = this.menuItemElem;
      return this.submenu.openMenu();
    }
  }
  onClick(e) {
    if (this.disabled || !!this.submenu || !!this.accordion) {
      e.stopPropagation();
      e.preventDefault();
      return;
    }
    if (!this.multiSelect)
      this.mxClick.emit(e);
  }
  get checkboxLabel() {
    return (this.slotWrapper || this.element).innerText;
  }
  render() {
    return (index.h(index.Host, { role: "none", class: 'mx-menu-item block' + (this.submenu ? ' has-submenu' : '') }, index.h("div", { ref: el => (this.menuItemElem = el), role: this.role, "aria-checked": this.role === 'option' ? (this.checked ? 'true' : 'false') : null, "aria-disabled": this.disabled ? 'true' : null, "aria-haspopup": this.submenu ? 'true' : null, "aria-selected": this.selected ? 'true' : null, tabindex: this.disabled || this.multiSelect || this.hasParentLink ? '-1' : '0', class: "block w-full cursor-pointer select-none text-4 outline-none rounded disabled:cursor-auto", onClick: this.onClick.bind(this) }, this.label && (index.h("p", { class: "item-label flex items-end py-0 pl-14 pr-10 my-0 h-18 uppercase subtitle5" }, index.h("span", { class: "block -mb-4" }, this.label))), index.h("div", { class: 'flex items-center w-full justify-between pl-14 pr-10 h-40 whitespace-nowrap' +
        (this.multiSelect ? ' hidden' : '') }, index.h("div", { class: "flex items-center w-full h-full" }, this.icon !== undefined && (index.h("i", { class: 'inline-flex items-center justify-center text-1 w-20 mr-8 ' + this.icon })), index.h("span", { ref: el => (this.slotWrapper = el), class: "truncate" }, index.h("slot", null)), index.h("span", { class: "ml-auto" }, index.h("slot", { name: "right" }))), this.checked && !this.multiSelect && index.h("i", { class: "check mds-check text-icon ml-14", "data-testid": "check" }), !!this.accordion && (index.h("i", { class: "accordion-arrow mds-chevron-right text-icon transform transition-transform", "data-testid": "accordion-arrow" })), !!this.submenu && (index.h("i", { class: "mds-arrow-triangle-down text-icon transform -rotate-90", "data-testid": "arrow" }))), this.subtitle && (index.h("p", { class: "item-subtitle flex items-start py-0 pl-14 pr-10 my-0 h-16 caption2" }, index.h("span", { class: "block -mt-4 truncate" }, this.subtitle))), this.multiSelect && (index.h("mx-checkbox", { class: "flex items-stretch w-full overflow-hidden h-48 sm:h-32", "label-class": "pl-14 pr-16", checked: this.checked, "label-name": this.checkboxLabel, "label-left": !this.minWidths.sm }))), index.h("slot", { name: "accordion" }), index.h("slot", { name: "submenu" })));
  }
  get element() { return index.getElement(this); }
};

exports.mx_checkbox = MxCheckbox;
exports.mx_menu = MxMenu;
exports.mx_menu_item = MxMenuItem;

//# sourceMappingURL=mx-checkbox_3.cjs.entry.js.map