'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-6172c188.js');
const utils = require('./utils-3ac69d07.js');

const yyyymmdd = /^\d{4}-(0?[1-9]|1[012])-(0?[1-9]|[12][0-9]|3[01])$/;
const isSafari = /^((?!chrome|android).)*safari/i.test(navigator.userAgent);
const MxDatePicker = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.uuid = utils.uuidv4();
    this.dataAttributes = {};
    this.isDateInputSupported = false;
    this.allowFuture = true;
    this.allowPast = true;
    this.assistiveText = undefined;
    this.autofocus = false;
    this.dense = false;
    this.disabled = false;
    this.elAriaLabel = undefined;
    this.error = false;
    this.floatLabel = false;
    this.inputId = undefined;
    this.label = undefined;
    this.min = undefined;
    this.max = undefined;
    this.name = undefined;
    this.value = undefined;
    this.isFocused = false;
    this.isInputDirty = false;
  }
  onValueChange() {
    if (this.value && !yyyymmdd.test(this.value))
      throw new Error('The date picker value must be in YYYY-MM-DD format.');
    this.inputEl.value = this.value;
  }
  componentWillRender() {
    utils.propagateDataAttributes.call(this);
  }
  componentDidLoad() {
    if (!this.inputEl)
      return;
    this.isDateInputSupported = this.inputEl.type === 'date';
    this.onValueChange();
  }
  onBlur() {
    this.isFocused = false;
    if (this.isDateInputSupported && (this.inputEl.validity.rangeOverflow || this.inputEl.validity.rangeUnderflow)) {
      this.error = true;
    }
    else if (!this.isDateInputSupported && this.isInputDirty) {
      if (this.disabled)
        return;
      this.error = false;
      let date;
      if (!this.inputEl.value)
        this.value = null;
      else {
        date = new Date(Date.parse(this.inputEl.value));
        if (!utils.isDateObject(date)) {
          this.error = true;
          return;
        }
        this.value = date.toISOString().split('T')[0];
      }
      this.inputEl.value = this.value;
      this.inputEl.dispatchEvent(new Event('input', { cancelable: true, bubbles: true }));
      if (date)
        this.inputEl.value = date.toLocaleDateString();
    }
  }
  onFocus(e) {
    this.isFocused = true;
    this.error = false;
    this.isInputDirty = false;
    e.stopPropagation();
  }
  onInput(e) {
    const value = e.target.value;
    if (value && !yyyymmdd.test(value))
      e.stopPropagation();
    else if (this.value !== value) {
      this.value = value;
    }
    if (!this.isDateInputSupported && this.isFocused)
      this.isInputDirty = true;
  }
  onClickLabel() {
    this.inputEl.focus();
  }
  onClickButton() {
    if (isSafari)
      this.inputEl.click();
    else
      this.inputEl.showPicker();
  }
  get minDate() {
    if (this.min)
      return new Date(this.min + 'T00:00:00');
    if (!this.allowPast) {
      const today = new Date();
      today.setHours(0, 0, 0, 0);
      return today;
    }
  }
  get maxDate() {
    if (this.max)
      return new Date(this.max + 'T00:00:00');
    if (!this.allowFuture)
      return new Date();
    return new Date(9999, 11, 31);
  }
  get minValue() {
    return this.minDate ? this.minDate.toISOString().split('T')[0] : null;
  }
  get maxValue() {
    return this.maxDate ? this.maxDate.toISOString().split('T')[0] : null;
  }
  get labelClassNames() {
    let str = 'block';
    if (this.floatLabel) {
      str += ' absolute mt-0 left-12 px-4 min-w-1/2';
      if (this.dense)
        str += ' dense text-4';
      if (this.isFocused || this.inputHasText)
        str += ' floating';
    }
    else {
      str += ' subtitle2 mb-4 pointer-events-none';
    }
    return str;
  }
  get inputHasText() {
    if (!this.inputEl)
      return false;
    return this.inputEl.value || this.inputEl.validity.badInput;
  }
  get pickerWrapperClass() {
    let str = 'picker-wrapper w-320 flex items-center relative rounded';
    str += this.dense ? ' h-36' : ' h-48';
    str += ' border';
    if (this.disabled)
      str += ' disabled';
    if (this.isFocused)
      str += ' focused';
    return str;
  }
  get inputClass() {
    let str = 'absolute inset-0 w-full h-full pl-12 overflow-hidden outline-none appearance-none select-none bg-transparent';
    if (this.floatLabel && !this.isFocused && !this.inputHasText)
      str += ' opacity-0';
    else if (isSafari && !this.inputHasText)
      str += ' opacity-50';
    return str;
  }
  get calendarButtonClass() {
    let str = 'calendar-button cursor-pointer border-0 absolute flex items-center text-icon h-full right-0 pr-12 space-x-8 bg-white rounded';
    if (this.disabled)
      str += ' pointer-events-none';
    return str;
  }
  render() {
    const labelJsx = (index.h("label", { htmlFor: this.inputId || this.uuid, class: this.labelClassNames, onClick: this.onClickLabel.bind(this) }, this.label));
    return (index.h(index.Host, { class: 'mx-date-picker block text-3' + (this.error ? ' error' : '') }, this.label && !this.floatLabel && labelJsx, index.h("div", { ref: el => (this.pickerWrapper = el), class: this.pickerWrapperClass }, index.h("input", Object.assign({ ref: el => (this.inputEl = el), "aria-label": this.elAriaLabel || this.label, autofocus: this.autofocus, class: this.inputClass, disabled: this.disabled, id: this.inputId || this.uuid, name: this.name, type: "date", min: this.minValue, max: this.maxValue, onBlur: this.onBlur.bind(this), onFocus: this.onFocus.bind(this), onInput: this.onInput.bind(this) }, this.dataAttributes)), this.label && this.floatLabel && labelJsx, index.h("button", { type: "button", "aria-label": "Open calendar", ref: el => (this.calendarButton = el), class: this.calendarButtonClass, "data-testid": "calendar-button", disabled: this.disabled, onClick: this.onClickButton.bind(this) }, index.h("i", { class: this.error ? 'mds-warning-circle' : 'mds-calendar' }))), this.assistiveText && (index.h("div", { class: "caption1 mt-4 ml-16" }, index.h("span", { "data-testid": "assistive-text", class: "assistive-text" }, this.assistiveText)))));
  }
  get element() { return index.getElement(this); }
  static get watchers() { return {
    "value": ["onValueChange"]
  }; }
};

exports.mx_date_picker = MxDatePicker;

//# sourceMappingURL=mx-date-picker.cjs.entry.js.map