'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-6172c188.js');

const MxDropdownMenu = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.elAriaLabel = undefined;
    this.disabled = false;
    this.readonly = false;
    this.dense = false;
    this.elevated = false;
    this.flat = false;
    this.label = undefined;
    this.dropdownClass = undefined;
    this.dropdownId = undefined;
    this.name = undefined;
    this.suffix = undefined;
    this.value = undefined;
    this.error = undefined;
    this.assistiveText = undefined;
    this.isFocused = false;
  }
  async onClick(e) {
    this.menu.style.width = this.dropdownWrapper.getBoundingClientRect().width + 'px';
    const clickedMenuItem = e.target.closest('mx-menu-item');
    if (!clickedMenuItem)
      return;
    this.value = await clickedMenuItem.getValue();
    this.inputElem.dispatchEvent(new Event('input', { bubbles: true, cancelable: true }));
  }
  componentDidLoad() {
    this.updateInputValue();
    this.attachMenu();
  }
  onValueChange() {
    this.updateInputValue();
  }
  attachMenu() {
    if (!this.disabled && !this.readonly)
      this.menu.anchorEl = this.dropdownWrapper;
    else
      this.menu.anchorEl = undefined;
  }
  onBlur() {
    if (this.menu && this.menu.isOpen)
      return;
    this.isFocused = false;
  }
  onFocus() {
    this.isFocused = true;
    this.error = false;
  }
  onMenuClose(e) {
    e.stopPropagation();
    if (!this.inputElem.contains(document.activeElement))
      this.isFocused = false;
  }
  updateInputValue() {
    this.inputElem.value = this.value;
  }
  get dropdownWrapperClass() {
    let str = 'dropdown-wrapper flex items-center relative rounded';
    str += this.dense ? ' h-36' : ' h-48';
    if (this.elevated)
      str += ' elevated shadow-1';
    if (this.flat)
      str += ' flat';
    str += ' border';
    if (this.disabled || this.readonly)
      str += ' disabled';
    if (this.error)
      str += ' error';
    if (this.dropdownClass)
      str += ' ' + this.dropdownClass;
    return str;
  }
  get inputClass() {
    const str = 'absolute inset-0 w-full h-full pl-16 overflow-hidden outline-none appearance-none select-none bg-transparent cursor-pointer disabled:cursor-auto';
    return str;
  }
  get suffixClass() {
    const str = 'icon-suffix absolute flex items-center h-full right-12 space-x-8 pointer-events-none';
    return str;
  }
  render() {
    return (index.h(index.Host, { class: "mx-dropdown-menu block text-3" }, index.h("div", { ref: el => (this.dropdownWrapper = el), class: this.dropdownWrapperClass }, index.h("input", { "aria-label": this.elAriaLabel || this.label, class: this.inputClass, id: this.dropdownId, name: this.name, onBlur: this.onBlur.bind(this), onFocus: this.onFocus.bind(this), placeholder: this.label, disabled: this.disabled, readonly: !this.disabled, ref: el => (this.inputElem = el), tabindex: "0", type: "text" }), index.h("span", { class: this.suffixClass }, this.suffix && index.h("span", { class: "suffix flex items-center h-full px-4" }, this.suffix), this.error ? (index.h("i", { class: "mds-warning-circle text-icon pointer-events-none" })) : (index.h("i", { "data-testid": "arrow", class: "mds-arrow-triangle-down text-icon" })))), this.assistiveText && index.h("div", { class: "assistive-text caption1 mt-4 ml-16" }, this.assistiveText), index.h("mx-menu", { ref: el => (this.menu = el), placement: "bottom", offset: [0, 1], onMxClose: this.onMenuClose.bind(this) }, index.h("slot", null))));
  }
  static get watchers() { return {
    "value": ["onValueChange"],
    "disabled": ["attachMenu"],
    "readonly": ["attachMenu"]
  }; }
};

exports.mx_dropdown_menu = MxDropdownMenu;

//# sourceMappingURL=mx-dropdown-menu.cjs.entry.js.map