'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-6172c188.js');
const transitions = require('./transitions-141d664d.js');
const utils = require('./utils-3ac69d07.js');

const MxMenuAccordion = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.mxClose = index.createEvent(this, "mxClose", 7);
    this.mxOpen = index.createEvent(this, "mxOpen", 7);
    this.isClosing = false;
    this.uuid = utils.uuidv4();
    this.anchorEl = undefined;
    this.isOpen = false;
  }
  onClick(e) {
    const anchorElWasClicked = this.anchorEl && this.anchorEl.contains(e.target);
    if (!anchorElWasClicked)
      return;
    e.preventDefault();
    this.isOpen ? this.closeMenu() : this.openMenu();
  }
  async toggleMenu() {
    return this.isOpen ? this.closeMenu : this.openMenu;
  }
  async openMenu() {
    if (this.isOpen || !this.anchorEl)
      return false;
    this.isOpen = true;
    this.mxOpen.emit();
    await new Promise(requestAnimationFrame);
    await transitions.expand(this.menuElem);
    return true;
  }
  setAnchorElAttributes() {
    if (!this.anchorEl)
      return;
    this.anchorEl.setAttribute('aria-controls', this.uuid);
    this.setAnchorAriaExpanded(this.isOpen);
  }
  async closeMenu(skipTransition = false) {
    if (!this.isOpen || this.isClosing)
      return false;
    this.isClosing = true;
    this.setAnchorAriaExpanded(false);
    this.menuItems.forEach(m => m.closeSubMenu());
    await transitions.collapse(this.menuElem, !skipTransition ? undefined : 0);
    this.isClosing = false;
    this.mxClose.emit();
    this.isOpen = false;
    return true;
  }
  componentDidLoad() {
    if (this.menuItems.length) {
      const role = this.element.querySelector('[role="option"]') ? 'listbox' : 'menu';
      this.menuElem.setAttribute('role', role);
    }
    this.setAnchorElAttributes();
  }
  componentWillUpdate() {
    this.setAnchorAriaExpanded(this.isOpen);
    const anyMenuItemHasIcon = this.menuItems.some(m => !!m.icon);
    if (anyMenuItemHasIcon) {
      this.menuItems.forEach(m => {
        if (m.icon === undefined)
          m.icon = null;
      });
    }
  }
  setAnchorAriaExpanded(isExpanded = false) {
    if (!this.anchorEl)
      return;
    this.anchorEl.setAttribute('aria-expanded', isExpanded.toString());
  }
  get menuItems() {
    return (Array.from(this.menuElem.children).filter(e => e.tagName === 'MX-MENU-ITEM') ||
      []);
  }
  get hostClass() {
    let str = 'mx-menu-accordion block z-50';
    if (!this.isOpen)
      str += ' invisible h-0 overflow-hidden';
    return str;
  }
  render() {
    return (index.h(index.Host, { class: this.hostClass }, index.h("div", { id: this.uuid, ref: el => (this.menuElem = el), class: "flex flex-col overflow-hidden rounded-b pl-12" }, index.h("slot", null))));
  }
  get element() { return index.getElement(this); }
  static get watchers() { return {
    "anchorEl": ["setAnchorElAttributes"]
  }; }
};

exports.mx_menu_accordion = MxMenuAccordion;

//# sourceMappingURL=mx-menu-accordion.cjs.entry.js.map