'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-6172c188.js');
const portal = require('./portal-b7d8bc84.js');
const transitions = require('./transitions-141d664d.js');
const bodyScroll = require('./bodyScroll-aebe0173.js');
require('./utils-3ac69d07.js');

const MxModalOverlay = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.mxClose = index.createEvent(this, "mxClose", 7);
    this.closeOnEscape = true;
    this.closeOnOutsideClick = true;
    this.isOpen = false;
    this.portal = true;
    this.isVisible = false;
  }
  toggleModal() {
    this.isOpen ? this.openModal() : this.closeModal();
  }
  onKeyDown(e) {
    if (!this.isOpen)
      return;
    if (e.key === 'Tab') {
      if (e.shiftKey && document.activeElement === this.firstFocusElement) {
        this.lastFocusElement.focus();
        e.preventDefault();
      }
      else if (document.activeElement === this.lastFocusElement) {
        this.firstFocusElement.focus();
        e.preventDefault();
      }
    }
  }
  onDocumentKeyDown(e) {
    if (this.isOpen && this.closeOnEscape && e.key === 'Escape')
      this.mxClose.emit();
  }
  disconnectedCallback() {
    bodyScroll.unlockBodyScroll(this.element);
  }
  componentDidLoad() {
    if (this.isOpen)
      this.openModal();
  }
  async openModal() {
    if (this.portal)
      portal.moveToPortal(this.element);
    bodyScroll.lockBodyScroll(this.element);
    this.isVisible = true;
    requestAnimationFrame(async () => {
      this.getFocusElements();
      await Promise.all([transitions.fadeIn(this.backdrop, 250), transitions.fadeScaleIn(this.modal, 250)]);
    });
  }
  getFocusElements() {
    this.ancestorFocusedElement = document.activeElement;
    const isVisible = (el) => !!el.offsetParent;
    this.focusElements = Array.from(this.element.querySelectorAll('button, [href], input, select, textarea, [tabindex]:not([tabindex="-1"])')).filter(isVisible);
    if (this.focusElements.length) {
      this.firstFocusElement = this.focusElements[0];
      this.lastFocusElement = this.focusElements[this.focusElements.length - 1];
      this.focusElements[0].focus();
    }
  }
  async closeModal() {
    await Promise.all([transitions.fadeOut(this.backdrop), transitions.fadeOut(this.modal)]);
    this.isVisible = false;
    bodyScroll.unlockBodyScroll(this.element);
    this.ancestorFocusedElement && this.ancestorFocusedElement.focus();
  }
  onBackdropClick() {
    if (this.closeOnOutsideClick)
      this.mxClose.emit();
  }
  get hostClass() {
    let str = 'mx-modal-overlay block fixed inset-0';
    if (!this.isVisible)
      str += ' hidden';
    return str;
  }
  render() {
    return (index.h(index.Host, { class: this.hostClass, "aria-modal": "true", role: "dialog" }, index.h("div", { ref: el => (this.backdrop = el), class: 'bg-modal-backdrop absolute inset-0 z-0' + (this.closeOnOutsideClick ? ' cursor-pointer' : ''), "data-testid": "backdrop", onClick: this.onBackdropClick.bind(this) }), index.h("div", { ref: el => (this.modal = el), class: "modal flex flex-col absolute inset-0 pt-60 px-10 pb-10 pointer-events-none" }, index.h("div", { class: "pointer-events-auto pt-10", "data-testid": "modal-content" }, index.h("slot", null)), index.h("div", { class: "absolute top-0 right-0 w-60 h-60 flex items-center justify-center" }, index.h("mx-icon-button", { "el-aria-label": "Close modal", close: true, class: "pointer-events-auto", "data-testid": "close-button", onClick: this.mxClose.emit })))));
  }
  get element() { return index.getElement(this); }
  static get watchers() { return {
    "isOpen": ["toggleModal"]
  }; }
};

exports.mx_modal_overlay = MxModalOverlay;

//# sourceMappingURL=mx-modal-overlay.cjs.entry.js.map