'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-6172c188.js');
const minWidthSync = require('./minWidthSync-44c5ae26.js');

var __rest = (undefined && undefined.__rest) || function (s, e) {
  var t = {};
  for (var p in s)
    if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
      t[p] = s[p];
  if (s != null && typeof Object.getOwnPropertySymbols === "function")
    for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
      if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
        t[p[i]] = s[p[i]];
    }
  return t;
};
const MxPageHeader = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.hasTabs = false;
    this.hasModalHeaderCenter = false;
    this.hasModalHeaderRight = false;
    this.buttons = [];
    this.modal = false;
    this.previousPageUrl = '';
    this.previousPageTitle = 'Back';
    this.pattern = false;
    this.minWidths = new minWidthSync.MinWidths();
    this.renderTertiaryButtonAsMenu = false;
  }
  async resetResizeObserver() {
    if (this.resizeObserver)
      this.resizeObserver.disconnect();
    this.resizeObserver = new ResizeObserver(() => this.updateRenderTertiaryButtonAsMenu());
    this.resizeObserver.observe(this.element);
    requestAnimationFrame(this.updateRenderTertiaryButtonAsMenu.bind(this));
  }
  updateSlottedButtonSize() {
    const slottedButtons = this.element.querySelectorAll('[slot="buttons"] mx-button');
    slottedButtons.forEach((button) => (button.xl = this.minWidths.lg));
  }
  componentWillLoad() {
    this.hasTabs = !!this.element.querySelector('[slot="tabs"]');
    this.hasModalHeaderCenter = !!this.element.querySelector('[slot="modal-header-center"]');
    const modalHeaderRight = this.element.querySelector('[slot="modal-header-right"]');
    this.hasModalHeaderRight =
      modalHeaderRight &&
        modalHeaderRight.firstElementChild &&
        modalHeaderRight.firstElementChild.getAttribute('hidden') == null;
    this.updateSlottedButtonSize();
  }
  connectedCallback() {
    minWidthSync.minWidthSync.subscribeComponent(this);
  }
  disconnectedCallback() {
    minWidthSync.minWidthSync.unsubscribeComponent(this);
  }
  updateRenderTertiaryButtonAsMenu() {
    if (this.minWidths.md || this.buttons.length < 3) {
      this.renderTertiaryButtonAsMenu = false;
      return;
    }
    if (!this.tertiaryButtonWrapper)
      return;
    const { left } = this.tertiaryButtonWrapper.getBoundingClientRect();
    const buttonRight = Math.floor(left + this.tertiaryButtonWrapper.offsetWidth);
    const { right: containerRight } = this.buttonRow.getBoundingClientRect();
    const isOverflowing = buttonRight > containerRight;
    this.renderTertiaryButtonAsMenu = isOverflowing;
    if (isOverflowing) {
      requestAnimationFrame(() => {
        if (this.tertiaryMenu)
          this.tertiaryMenu.anchorEl = this.menuButton;
      });
    }
  }
  componentDidLoad() {
    this.resetResizeObserver();
  }
  get hostClass() {
    let str = 'mx-page-header flex flex-col';
    if (this.pattern)
      str += ' bg-pattern';
    if (this.minWidths.md && this.modal) {
      str += ' px-40';
      str += this.hasTabs ? ' min-h-128' : ' min-h-80';
      return str;
    }
    else {
      str += ' px-24 lg:px-72';
    }
    if (this.hasTabs)
      str += ' pb-12 md:pb-0';
    if (this.buttons.length && this.hasTabs)
      str += ' min-h-176 md:min-h-164';
    else if (this.buttons.length)
      str += ' min-h-128';
    else
      str += ' min-h-80 md:min-h-128';
    return str;
  }
  get headingClass() {
    let str = 'my-0 pr-20 ';
    if (!this.minWidths.md)
      str += this.previousPageUrl ? 'text-h3' : 'text-h2';
    else
      str += this.previousPageUrl || this.modal ? 'text-h2' : 'text-h1';
    if (this.hasModalHeaderRight)
      str += ' pr-80';
    return str;
  }
  get previousPageClass() {
    let str = 'flex items-center pt-16 md:pt-20 uppercase caption1 font-semibold tracking-1-25';
    if (this.modal)
      str += ' md:hidden';
    return str;
  }
  get buttonsJsx() {
    return (index.h("div", { ref: el => (this.buttonRow = el), class: "flex py-1 space-x-8 md:space-x-24 md:justify-end md:flex-row-reverse md:space-x-reverse items-center max-w-full" }, this.buttons.map((button, index$1) => {
      let { btnType } = button;
      if (!btnType)
        btnType = index$1 === 0 ? 'contained' : index$1 === 1 ? 'outlined' : 'text';
      const isTertiary = index$1 === 2;
      const { label } = button, menuItemProps = __rest(button, ["label"]);
      return (index.h("div", { ref: el => isTertiary && (this.tertiaryButtonWrapper = el), class: isTertiary ? 'relative flex flex-1 justify-end' : '' }, isTertiary && this.renderTertiaryButtonAsMenu && (index.h("div", { class: "absolute -top-6" }, index.h("mx-icon-button", { ref: el => (this.menuButton = el), icon: "mds-dots-vertical" }), index.h("mx-menu", { ref: el => (this.tertiaryMenu = el), "anchor-el": this.menuButton, onMxClose: e => e.stopPropagation() }, index.h("mx-menu-item", Object.assign({}, menuItemProps), label)))), index.h("mx-button", Object.assign({}, button, { xl: this.minWidths.lg, "btn-type": btnType, "aria-hidden": isTertiary && this.renderTertiaryButtonAsMenu ? 'true' : null, class: isTertiary && this.renderTertiaryButtonAsMenu ? 'opacity-0 pointer-events-none' : '' }), button.label)));
    })));
  }
  render() {
    return (index.h(index.Host, { class: this.hostClass }, index.h("div", { class: "absolute top-20 right-20" }, index.h("slot", { name: "modal-header-right" })), index.h("slot", { name: "previous-page" }, this.previousPageUrl && (index.h("a", { href: this.previousPageUrl, class: this.previousPageClass }, index.h("i", { class: "mds-arrow-left mr-10" }), this.previousPageTitle))), index.h("div", { class: "flex flex-col py-10 space-y-14 md:space-y-0 md:flex-row flex-grow md:items-center justify-center md:justify-between flex-wrap" }, index.h("div", { class: 'flex-1 items-center break-anywhere' +
        (this.hasModalHeaderCenter ? ' grid grid-cols-1 sm:grid-cols-3 h-full' : ' flex') }, index.h("h1", { class: this.headingClass }, index.h("slot", null)), index.h("slot", { name: "modal-header-center" })), !(this.modal && this.minWidths.md) && this.buttons.length > 0 && this.buttonsJsx, index.h("slot", { name: "buttons" })), index.h("slot", { name: "tabs" })));
  }
  get element() { return index.getElement(this); }
  static get watchers() { return {
    "minWidths": ["updateSlottedButtonSize"]
  }; }
};

exports.mx_page_header = MxPageHeader;

//# sourceMappingURL=mx-page-header.cjs.entry.js.map