'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-6172c188.js');
const utils = require('./utils-3ac69d07.js');
const minWidthSync = require('./minWidthSync-44c5ae26.js');

const MxSelect = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.uuid = utils.uuidv4();
    this.dataAttributes = {};
    this.componentWillRender = utils.propagateDataAttributes;
    this.assistiveText = undefined;
    this.autofocus = false;
    this.dense = false;
    this.disabled = false;
    this.elevated = false;
    this.flat = false;
    this.label = undefined;
    this.floatLabel = false;
    this.elAriaLabel = undefined;
    this.selectClass = undefined;
    this.selectId = undefined;
    this.name = undefined;
    this.suffix = undefined;
    this.error = false;
    this.labelClass = '';
    this.value = undefined;
    this.isFocused = false;
  }
  componentDidLoad() {
    this.updateSelectValue();
  }
  onValueChange() {
    this.updateSelectValue();
  }
  updateSelectValue() {
    this.selectElem.value = this.value;
  }
  onFocus() {
    this.isFocused = true;
    this.error = false;
  }
  onBlur() {
    this.isFocused = false;
  }
  onInput(e) {
    this.value = e.target.value;
  }
  get hasValue() {
    return this.value !== null && this.value !== '' && this.value !== undefined;
  }
  get selectWrapperClass() {
    let str = 'mx-select-wrapper flex items-center relative rounded';
    str += this.dense ? ' h-36' : ' h-48';
    if (!this.hasValue)
      str += ' no-value';
    if (this.elevated)
      str += ' elevated shadow-1';
    if (this.flat)
      str += ' flat';
    str += ' border';
    if (this.error)
      str += ' error';
    if (this.disabled)
      str += ' disabled';
    if (this.selectClass)
      str += ' ' + this.selectClass;
    return str;
  }
  get selectElClass() {
    const str = 'absolute inset-0 w-full pl-16 overflow-hidden outline-none appearance-none bg-transparent cursor-pointer disabled:cursor-auto';
    return str;
  }
  get labelClassNames() {
    let str = 'block pointer-events-none';
    if (this.floatLabel) {
      str += ' absolute mt-0 left-12 px-4';
      if (this.dense)
        str += ' dense text-4';
      if (this.isFocused || this.hasValue)
        str += ' floating';
    }
    else {
      str += ' subtitle2 mb-4';
    }
    return (str += ' ' + this.labelClass);
  }
  get iconSuffixClass() {
    const str = 'icon-suffix absolute flex items-center h-full right-12 space-x-8 pointer-events-none';
    return str;
  }
  get iconEl() {
    let icon = index.h("i", { "data-testid": "arrow", class: "mds-arrow-triangle-down text-icon" });
    if (this.error)
      icon = index.h("i", { "data-testid": "error-icon", class: "mds-warning-circle text-icon" });
    return icon;
  }
  render() {
    const labelJsx = (index.h("label", { htmlFor: this.selectId || this.uuid, class: this.labelClassNames }, this.label));
    return (index.h(index.Host, { class: 'mx-select block text-3' + (this.disabled ? ' disabled' : '') }, this.label && !this.floatLabel && labelJsx, index.h("div", { "data-testid": "select-wrapper", class: this.selectWrapperClass }, index.h("select", Object.assign({ "aria-label": this.elAriaLabel || this.label, autoFocus: this.autofocus, class: this.selectElClass, disabled: this.disabled, id: this.selectId || this.uuid, name: this.name, onFocus: this.onFocus.bind(this), onBlur: this.onBlur.bind(this), onInput: this.onInput.bind(this), ref: el => (this.selectElem = el) }, this.dataAttributes), index.h("slot", null)), this.label && this.floatLabel && labelJsx, index.h("span", { class: this.iconSuffixClass }, this.suffix && index.h("span", { class: "suffix flex items-center h-full px-4" }, this.suffix), this.iconEl)), this.assistiveText && index.h("div", { class: "assistive-text caption1 mt-4 ml-16" }, this.assistiveText)));
  }
  get element() { return index.getElement(this); }
  static get watchers() { return {
    "value": ["onValueChange"]
  }; }
};

const MxTab = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.label = '';
    this.elAriaLabel = '';
    this.icon = '';
    this.selected = false;
    this.badge = false;
    this.badgeClass = '';
    this.elRole = 'tab';
    this.href = null;
    this.target = null;
    this.nav = false;
  }
  componentDidLoad() {
    if (!this.label && !this.elAriaLabel) {
      throw new Error('Please provide either a label or an aria-label for each tab.');
    }
  }
  get labelClass() {
    let str = 'flex whitespace-nowrap items-center uppercase my-0 gap-x-6';
    str += this.nav ? ' text-body' : ' text-small';
    return str;
  }
  get badgeEl() {
    return index.h("mx-badge", { indicator: true, badgeClass: ['w-8 h-8', this.badgeClass].join(' ') });
  }
  render() {
    const Tag = this.href ? 'a' : 'button';
    return (index.h(index.Host, { class: "mx-tab relative inline-flex items-center justify-center min-w-0 h-60" }, index.h(Tag, { role: this.href ? null : this.elRole, type: this.href ? null : 'button', href: this.href, target: this.target, "aria-selected": this.selected && !this.href ? 'true' : null, "aria-label": this.elAriaLabel || this.label, class: "relative flex items-center justify-center overflow-hidden w-full h-full" }, index.h("span", { class: this.labelClass }, this.badge && this.badgeEl, index.h("span", { class: "tracking-0-3 font-bold" }, this.label), this.icon && index.h("i", { class: this.icon + ' text-icon' }))), index.h("span", { class: 'active-tab-indicator absolute bottom-0 left-0 w-full h-2 pointer-events-none' +
        (this.selected ? '' : ' opacity-0') })));
  }
  get element() { return index.getElement(this); }
};

const MxTabs = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.mxChange = index.createEvent(this, "mxChange", 7);
    this.mxMenuOpen = index.createEvent(this, "mxMenuOpen", 7);
    this.mxMenuClose = index.createEvent(this, "mxMenuClose", 7);
    this.tabEls = [];
    this.menuItemEls = [];
    this.hasMenuSlot = false;
    this.tabBreakpoints = new Map();
    this.tabVisibility = new Map();
    this.value = null;
    this.tabs = undefined;
    this.menuButton = undefined;
    this.nav = false;
    this.submenu = false;
    this.minWidths = new minWidthSync.MinWidths();
    this.showMoreTab = true;
    this.isMoreSelected = false;
  }
  onMenuOpen(e) {
    if (e.target === this.menuEl)
      this.mxMenuOpen.emit();
  }
  onMenuClose(e) {
    if (e.target === this.menuEl)
      this.mxMenuClose.emit();
  }
  connectedCallback() {
    minWidthSync.minWidthSync.subscribeComponent(this);
  }
  resetTabVisibility() {
    if ((!this.nav && !this.submenu) || !this.tabEls.length)
      return;
    this.setTabBreakpoints();
    this.updateTabVisibility();
  }
  onValueChange(tabIndex, previousTabIndex) {
    const isTabHidden = index => this.nav && !this.tabVisibility.get(this.tabEls[index]);
    const moreTabElIndex = this.tabEls.length;
    if (isTabHidden(tabIndex))
      tabIndex = moreTabElIndex;
    if (isTabHidden(previousTabIndex))
      previousTabIndex = moreTabElIndex;
    this.animateIndicator(tabIndex, previousTabIndex);
    requestAnimationFrame(() => (this.isMoreSelected = isTabHidden(tabIndex)));
  }
  animateIndicator(tabIndex, previousTabIndex) {
    if (utils.queryPrefersReducedMotion())
      return;
    if (tabIndex == null || previousTabIndex == null)
      return;
    const tabEls = this.element.querySelectorAll('.mx-tab');
    const previousSelectedTab = tabEls[previousTabIndex];
    const newSelectedTab = tabEls[tabIndex];
    if (!previousSelectedTab || !newSelectedTab)
      return;
    const distance = previousSelectedTab.offsetLeft - newSelectedTab.offsetLeft;
    const scaleX = previousSelectedTab.offsetWidth / newSelectedTab.offsetWidth;
    const indicator = newSelectedTab.querySelector('.active-tab-indicator');
    if (!indicator)
      return;
    indicator.style.transform = `translateX(${distance}px) scale3d(${scaleX}, 1, 1)`;
    indicator.style.transformOrigin = 'left';
    indicator.style.transition = `none`;
    setTimeout(() => {
      indicator.style.transform = `translateX(0) scale3d(1, 1, 1)`;
      indicator.style.transition = `transform 0.25s cubic-bezier(0.4, 0, 0.2, 1)`;
    }, 0);
  }
  componentWillRender() {
    this.hasMenuSlot = !!this.element.querySelector('[slot="menu"]');
  }
  componentDidLoad() {
    if (this.nav || this.submenu) {
      this.resetTabVisibility();
      const resizeObserver = new ResizeObserver(() => {
        if (this.menuEl)
          this.menuEl.closeMenu();
        this.updateTabVisibility();
      });
      resizeObserver.observe(this.element);
    }
  }
  disconnectedCallback() {
    minWidthSync.minWidthSync.unsubscribeComponent(this);
  }
  setTabBreakpoints() {
    this.showAllTabs();
    this.tabBreakpoints.clear();
    const { left: containerLeft } = this.element.getBoundingClientRect();
    const lastTabRight = this.tabEls[this.tabEls.length - 1].getBoundingClientRect().right;
    const moreTabOffset = this.moreTabEl && this.moreTabEl.getBoundingClientRect().right - lastTabRight;
    this.tabEls.forEach((tab, i) => {
      let breakpoint;
      if (this.submenu) {
        breakpoint = lastTabRight - containerLeft;
      }
      else {
        const { right } = tab.getBoundingClientRect();
        breakpoint = right - containerLeft;
      }
      if (this.moreTabEl) {
        if (i < this.tabs.length - 1)
          breakpoint += moreTabOffset;
        if (i === this.tabs.length - 1) {
          const previousTab = this.tabEls[i - 1];
          const previousTabBreakpoint = this.tabBreakpoints.get(previousTab);
          if (previousTabBreakpoint > breakpoint)
            this.tabBreakpoints.set(previousTab, breakpoint);
        }
      }
      this.tabBreakpoints.set(tab, breakpoint);
    });
    if (this.submenu)
      return;
    if (this.tabs.length === 3)
      this.tabBreakpoints.set(this.tabEls[1], this.tabBreakpoints.get(this.tabEls[2]));
    if (this.tabs.length > 1)
      this.tabBreakpoints.set(this.tabEls[0], this.tabBreakpoints.get(this.tabEls[1]));
  }
  showAllTabs() {
    this.tabEls.forEach(tab => {
      this.tabVisibility.set(tab, true);
    });
    this.applyTabVisibility();
  }
  updateTabVisibility() {
    let { width } = this.element.getBoundingClientRect();
    if (this.allTabsHidden && this.menuButton)
      width += this.menuButton.scrollWidth;
    let isAnyTabHidden = false;
    let isHiddenTabSelected = false;
    let isChanging = false;
    this.tabBreakpoints.forEach((breakpoint, tab) => {
      const isVisible = width >= breakpoint && (this.submenu || this.minWidths.sm);
      isChanging = isChanging || isVisible !== this.tabVisibility.get(tab);
      this.tabVisibility.set(tab, isVisible);
      if (!isVisible) {
        isAnyTabHidden = true;
        if (tab.selected)
          isHiddenTabSelected = true;
      }
    });
    if (this.moreTabEl)
      this.updateMoreTab(isAnyTabHidden, isHiddenTabSelected);
    if (isChanging)
      this.applyTabVisibility();
    if (this.menuButton)
      this.updateMenuButton();
  }
  updateMoreTab(isAnyTabHidden = false, isHiddenTabSelected = false) {
    requestAnimationFrame(() => {
      const canShowMoreTab = !this.allTabsHidden;
      this.showMoreTab = canShowMoreTab && isAnyTabHidden;
      this.isMoreSelected = isHiddenTabSelected;
      if (this.showMoreTab) {
        this.menuEl.anchorEl = this.moreTabEl.firstElementChild;
      }
    });
  }
  updateMenuButton() {
    this.menuButton.classList.toggle('hidden', !this.allTabsHidden);
    if (this.submenu)
      this.submenuLabel.classList.toggle('hidden', !this.allTabsHidden);
    if (this.allTabsHidden)
      this.menuEl.anchorEl = this.menuButton;
  }
  applyTabVisibility() {
    if (this.menuEl)
      this.menuEl.closeMenu();
    this.tabEls.forEach((tab, index) => {
      if (this.tabVisibility.get(tab)) {
        tab.classList.remove('hidden');
        if (this.menuItemEls[index])
          this.menuItemEls[index].classList.add('hidden');
      }
      else {
        tab.classList.add('hidden');
        if (this.menuItemEls[index])
          this.menuItemEls[index].classList.remove('hidden');
      }
    });
  }
  onClick(e) {
    let tab = e.target.closest('.mx-tab');
    const menuItem = e.target.closest('mx-menu-item');
    if (menuItem)
      tab = this.tabEls[+menuItem.dataset.tabIndex];
    if (!tab)
      return;
    const tabIndex = Array.prototype.indexOf.call(this.tabEls, tab);
    if (tabIndex >= 0)
      this.mxChange.emit(tabIndex);
    if (menuItem && tab.href)
      tab.querySelector('a').click();
  }
  onInput(e) {
    this.mxChange.emit(+e.target.value);
  }
  get allTabsHidden() {
    return !this.tabVisibility.get(this.tabEls[0]);
  }
  get selectedTabLabel() {
    return this.tabs[this.value].label || this.tabs[this.value].elAriaLabel;
  }
  get menuEl() {
    if (this.allTabsHidden && this.hasMenuSlot) {
      return this.element.querySelector('mx-menu[slot="menu"]');
    }
    return this.moreMenuEl;
  }
  get renderAsSelect() {
    if (this.nav || this.submenu || this.minWidths.md)
      return false;
    return this.tabs && this.tabs.length > 2;
  }
  get gridClass() {
    let str = 'inline-grid auto-cols-min grid-flow-col';
    str += this.nav ? ' gap-x-24' : ' gap-x-20';
    return str;
  }
  render() {
    return (index.h(index.Host, { class: "mx-tabs relative block", role: "tablist" }, this.renderAsSelect ? (index.h("mx-select", { value: this.value, onInput: this.onInput.bind(this), dense: true }, this.tabs.map((tab, index$1) => (index.h("option", { value: index$1 }, tab.label || tab.elAriaLabel))))) : (this.tabs && (index.h("div", { class: this.gridClass }, this.tabs.map((tab, index$1) => (index.h("mx-tab", Object.assign({ ref: el => (this.tabEls[index$1] = el), key: 'tab-' + index$1, selected: this.value === index$1, nav: this.nav }, tab)))), this.nav && this.tabs.length > 3 && (index.h("mx-tab", { ref: el => (this.moreTabEl = el), class: this.showMoreTab ? '' : 'invisible', label: "More", "el-role": "button", icon: "mds-arrow-triangle-down", selected: this.isMoreSelected, nav: true, "data-testid": "more-tab" })), this.submenu && (index.h("div", { ref: el => (this.submenuLabel = el), class: "submenu-label h-60 text-small hidden", "data-testid": "submenu-label" }, index.h("span", { class: "flex h-full items-center uppercase tracking-0-3 font-bold whitespace-nowrap" }, this.selectedTabLabel)))))), index.h("slot", { name: "menu" }), (this.nav || this.submenu) && (index.h("mx-menu", { ref: el => (this.moreMenuEl = el), squared: true }, this.tabs.map((tab, index$1) => (index.h("mx-menu-item", { ref: el => (this.menuItemEls[index$1] = el), key: 'menu-item-' + index$1, selected: this.value === index$1 || tab.selected, "data-tab-index": index$1 }, tab.label || tab.elAriaLabel)))))));
  }
  get element() { return index.getElement(this); }
  static get watchers() { return {
    "tabs": ["resetTabVisibility"],
    "minWidths": ["resetTabVisibility"],
    "menuButton": ["resetTabVisibility"],
    "value": ["onValueChange"]
  }; }
};

exports.mx_select = MxSelect;
exports.mx_tab = MxTab;
exports.mx_tabs = MxTabs;

//# sourceMappingURL=mx-select_3.cjs.entry.js.map