'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-6172c188.js');
const popover = require('./popover-ca69b525.js');
const transitions = require('./transitions-141d664d.js');
const utils = require('./utils-3ac69d07.js');

const MxTooltip = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.uuid = utils.uuidv4();
    this.appearDelay = 0;
    this.extended = false;
    this.inverted = false;
    this.maxWidth = '10rem';
    this.isOpen = false;
    this.placement = 'bottom';
    this.tooltipClass = undefined;
    this.value = undefined;
  }
  onIsOpenChange() {
    this.isOpen ? this.show() : this.hide();
  }
  componentDidLoad() {
    let anchorEl = this.element.firstElementChild;
    anchorEl = this.element.querySelector('a, button, input, [role="button"]') || anchorEl;
    anchorEl.setAttribute('aria-describedby', this.uuid);
    anchorEl.addEventListener('mouseenter', this.show.bind(this));
    anchorEl.addEventListener('mouseleave', this.hide.bind(this));
    if (anchorEl.tabIndex === -1)
      anchorEl.tabIndex = 0;
    anchorEl.addEventListener('focus', this.show.bind(this));
    anchorEl.addEventListener('blur', this.hide.bind(this));
  }
  async show() {
    clearTimeout(this.openTimeout);
    if (this.isOpen)
      return;
    this.openTimeout = setTimeout(async () => {
      this.isOpen = true;
      this.popoverInstance = await popover.createPopover(this.element.firstElementChild, this.tooltipElem, this.placement, [0, 4]);
      transitions.fadeIn(this.tooltipElem);
    }, this.appearDelay);
  }
  async hide() {
    clearTimeout(this.openTimeout);
    if (!this.isOpen)
      return;
    await transitions.fadeOut(this.tooltipElem);
    this.isOpen = false;
    if (!this.popoverInstance)
      return;
    this.popoverInstance.destroy();
    this.popoverInstance = null;
  }
  get tooltipClasses() {
    let str = 'mx-tooltip caption1 absolute pointer-events-none z-50';
    if (!this.isOpen)
      str += ' hidden';
    if (this.inverted)
      str += ' inverted';
    if (this.extended) {
      str += ' p-16 rounded shadow-4';
    }
    else {
      str += ' px-12 py-4 rounded';
    }
    if (this.tooltipClass)
      str += ' ' + this.tooltipClass;
    return str;
  }
  render() {
    return (index.h(index.Host, { class: "inline-flex" }, index.h("slot", null), index.h("div", { ref: el => (this.tooltipElem = el), id: this.uuid, role: "tooltip", class: this.tooltipClasses, style: { maxWidth: this.maxWidth }, "data-testid": "tooltip" }, index.h("slot", { name: "tooltip" }, this.value))));
  }
  get element() { return index.getElement(this); }
  static get watchers() { return {
    "isOpen": ["onIsOpenChange"]
  }; }
};

exports.mx_tooltip = MxTooltip;

//# sourceMappingURL=mx-tooltip.cjs.entry.js.map