import { Host, h } from "@stencil/core";
export class MxAutocomplete {
  constructor() {
    this.filterOptions = false;
    this.inputTag = 'mx-block-input';
    this.optionGroups = [];
    this.optionIcon = undefined;
    this.optionLabel = undefined;
    this.options = undefined;
    this.setValueOnSelect = false;
    this.assistiveText = undefined;
    this.autofocus = false;
    this.colspan = undefined;
    this.disabled = false;
    this.error = false;
    this.inputId = undefined;
    this.label = 'Search';
    this.maxlength = undefined;
    this.name = undefined;
    this.placeholder = undefined;
    this.readonly = false;
    this.type = 'search';
    this.value = undefined;
    this.isFocused = false;
  }
  async componentDidLoad() {
    await new Promise(requestAnimationFrame);
    this.menuEl.anchorEl = this.inputEl;
  }
  get filterFunction() {
    if (typeof this.filterOptions === 'function')
      return this.filterOptions;
    return this.defaultFilter;
  }
  get visibleOptions() {
    if (!this.options)
      return [];
    if (!this.filterOptions)
      return this.options;
    const filtered = [];
    this.options.forEach(option => {
      var _a;
      if (Array.isArray(option))
        filtered.push(option.filter(o => { var _a; return this.filterFunction(((_a = this.value) === null || _a === void 0 ? void 0 : _a.trim()) || '', o); }));
      if (this.filterFunction(((_a = this.value) === null || _a === void 0 ? void 0 : _a.trim()) || '', option))
        filtered.push(option);
    });
    return filtered;
  }
  get showNoResults() {
    var _a;
    return ((_a = this.value) === null || _a === void 0 ? void 0 : _a.trim()) && this.visibleOptions.length === 0;
  }
  async onSelect(option) {
    this.mxSelect.emit(option);
    this.menuEl.addEventListener('mxClose', async () => {
      await new Promise(requestAnimationFrame);
      await new Promise(requestAnimationFrame);
      this.inputEl.value = this.setValueOnSelect ? this.getOptionLabel(option) : '';
      this.inputEl.dispatchEvent(new window.Event('input', { cancelable: true, bubbles: true }));
      this.inputEl.querySelector('input').focus();
    }, { once: true });
  }
  defaultFilter(value, option) {
    const optionLabel = this.getOptionLabel(option);
    if (!optionLabel)
      return false;
    if (!(value === null || value === void 0 ? void 0 : value.trim()))
      return true;
    return optionLabel.toLowerCase().includes(value.trim().toLowerCase());
  }
  renderOption(option, index) {
    if (!option)
      return;
    if (!Array.isArray(option))
      return this.renderOptionItem(option);
    if (option.length)
      return this.renderOptionGroup(option, index);
  }
  renderOptionItem(option) {
    return (h("mx-menu-item", { icon: this.getOptionIcon(option), onClick: () => this.onSelect(option) }, this.getOptionLabel(option)));
  }
  renderOptionGroup(option, index) {
    return (h("div", { role: "group" }, this.optionGroups[index] && (h("p", { role: "heading", "aria-level": "2" }, this.optionGroups[index])), option.map(o => this.renderOption(o))));
  }
  getOptionLabel(option) {
    if (typeof this.optionLabel === 'function')
      return this.optionLabel(option);
    if (typeof option === 'object' && typeof this.optionLabel === 'string')
      return option[this.optionLabel];
    return option === null || option === void 0 ? void 0 : option.toString();
  }
  getOptionIcon(option) {
    if (!this.optionIcon)
      return;
    if (typeof this.optionIcon === 'string')
      return this.optionIcon;
    if (typeof this.optionIcon === 'function')
      return this.optionIcon(option);
  }
  render() {
    const Tag = this.inputTag;
    return (h(Host, { class: "mx-block-search contents" }, h(Tag, { ref: el => (this.inputEl = el), type: this.type, assistiveText: this.assistiveText, autofocus: this.autofocus, colspan: this.colspan, disabled: this.disabled, error: this.error, inputId: this.inputId, maxlength: this.maxlength, label: this.label, name: this.name, placeholder: this.placeholder, readonly: this.readonly, value: this.value, onInput: (e) => (this.value = e.target.value), onMxClear: this.mxClear.emit.bind(this) }, h("slot", { name: "label", slot: "label" })), h("mx-menu", { offset: [0, 10], ref: el => (this.menuEl = el), squared: true, autocompleteOnly: true }, this.showNoResults && (h("mx-menu-item", { disabled: true }, h("span", { class: "text-primary", "data-test": "no-results" }, "No matching results"))), this.visibleOptions.map(this.renderOption.bind(this)))));
  }
  static get is() { return "mx-autocomplete"; }
  static get properties() {
    return {
      "filterOptions": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean | ((inputValue: string, option: any) => boolean)",
          "resolved": "((inputValue: string, option: any) => boolean) | boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "If not provided (or false), options will not be filtered by the component.\nIf true, `options` are filtered using `String.prototype.includes()`.  If `options` is not an array of strings, `optionLabel` should also be set.\nIf a function (`(inputValue, option) => boolean`) is passed, that function will be used to filter `options` against the input value."
        },
        "attribute": "filter-options",
        "reflect": false,
        "defaultValue": "false"
      },
      "inputTag": {
        "type": "string",
        "mutable": true,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Set to `mx-input`, etc. to change which element is used as the input."
        },
        "attribute": "input-tag",
        "reflect": false,
        "defaultValue": "'mx-block-input'"
      },
      "optionGroups": {
        "type": "unknown",
        "mutable": false,
        "complexType": {
          "original": "string[]",
          "resolved": "string[]",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "An array of group headings if the options are grouped (i.e. `options` is an array of arrays)"
        },
        "defaultValue": "[]"
      },
      "optionIcon": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string | ((option: any) => string)",
          "resolved": "((option: any) => string) | string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Class name of icon to show on the left side of each option, _or_ a function `(option: any) => string` that returns the class name."
        },
        "attribute": "option-icon",
        "reflect": false
      },
      "optionLabel": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "If `options` is an array of objects, this specifies which property should be displayed in the menu item. If `filterOptions` is `true`, this property will also be used for filtering."
        },
        "attribute": "option-label",
        "reflect": false
      },
      "options": {
        "type": "unknown",
        "mutable": false,
        "complexType": {
          "original": "any[]",
          "resolved": "any[]",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Array of options, which may be strings or arbitrary objects."
        }
      },
      "setValueOnSelect": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "If set to true, the selected label will become the value of the input"
        },
        "attribute": "set-value-on-select",
        "reflect": false,
        "defaultValue": "false"
      },
      "assistiveText": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "assistive-text",
        "reflect": false
      },
      "autofocus": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "autofocus",
        "reflect": false,
        "defaultValue": "false"
      },
      "colspan": {
        "type": "number",
        "mutable": false,
        "complexType": {
          "original": "number",
          "resolved": "number",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Used to define the number of columns to span in the parent wrapper if more than 1"
        },
        "attribute": "colspan",
        "reflect": false
      },
      "disabled": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "disabled",
        "reflect": false,
        "defaultValue": "false"
      },
      "error": {
        "type": "boolean",
        "mutable": true,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "error",
        "reflect": true,
        "defaultValue": "false"
      },
      "inputId": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The `id` attribute for the text input"
        },
        "attribute": "input-id",
        "reflect": false
      },
      "label": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Text for the label element"
        },
        "attribute": "label",
        "reflect": false,
        "defaultValue": "'Search'"
      },
      "maxlength": {
        "type": "number",
        "mutable": false,
        "complexType": {
          "original": "number",
          "resolved": "number",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "maxlength",
        "reflect": false
      },
      "name": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The `name` attribute for the text input"
        },
        "attribute": "name",
        "reflect": false
      },
      "placeholder": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Placeholder text for the input"
        },
        "attribute": "placeholder",
        "reflect": false
      },
      "readonly": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "readonly",
        "reflect": false,
        "defaultValue": "false"
      },
      "type": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The `type` attribute for the text input"
        },
        "attribute": "type",
        "reflect": false,
        "defaultValue": "'search'"
      },
      "value": {
        "type": "string",
        "mutable": true,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The current search input value"
        },
        "attribute": "value",
        "reflect": false
      }
    };
  }
  static get states() {
    return {
      "isFocused": {}
    };
  }
  static get events() {
    return [{
        "method": "mxSelect",
        "name": "mxSelect",
        "bubbles": true,
        "cancelable": true,
        "composed": true,
        "docs": {
          "tags": [],
          "text": "Emitted when an option is selected."
        },
        "complexType": {
          "original": "any",
          "resolved": "any",
          "references": {}
        }
      }, {
        "method": "mxClear",
        "name": "mxClear",
        "bubbles": true,
        "cancelable": true,
        "composed": true,
        "docs": {
          "tags": [],
          "text": "Emitted when the clear button is clicked."
        },
        "complexType": {
          "original": "void",
          "resolved": "void",
          "references": {}
        }
      }];
  }
  static get elementRef() { return "element"; }
}
//# sourceMappingURL=mx-autocomplete.js.map
