import { Host, h } from "@stencil/core";
export class MxAvatar {
  constructor() {
    this.icon = '';
    this.imageUrl = '';
    this.fullName = '';
  }
  get avatarType() {
    if (this.imageUrl.trim())
      return 'image';
    if (this.icon.trim())
      return 'icon';
    if (this.fullName.trim())
      return 'monogram';
  }
  get initials() {
    if (this.avatarType !== 'monogram')
      return '';
    const names = this.fullName.trim().split(' ');
    if (names.length === 1)
      return names[0].charAt(0);
    return names[0].charAt(0) + names[names.length - 1].charAt(0);
  }
  connectedCallback() {
    if (!this.avatarType)
      console.error('mx-avatar requires either an image, icon, or full name.');
    if (this.fullName && !this.element.getAttribute('aria-label'))
      this.element.setAttribute('aria-label', this.fullName);
  }
  render() {
    return (h(Host, { class: 'mx-avatar avatar-' + this.avatarType }, this.avatarType == 'image' && h("img", { src: this.imageUrl.trim(), alt: "", class: "w-full h-full object-cover" }), this.avatarType == 'icon' && h("i", { class: this.icon.trim(), role: "presentation" }), this.avatarType == 'monogram' && h("div", { class: "truncate uppercase" }, this.initials)));
  }
  static get is() { return "mx-avatar"; }
  static get properties() {
    return {
      "icon": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The class name(s) to apply to an `<i>` element to display an icon"
        },
        "attribute": "icon",
        "reflect": false,
        "defaultValue": "''"
      },
      "imageUrl": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The URL of an image to display"
        },
        "attribute": "image-url",
        "reflect": false,
        "defaultValue": "''"
      },
      "fullName": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The name of the user (e.g. \"John Smith\"). If no `imageUrl` or `icon` is provided, this will be\nused to render a monogram as the avatar. This will also be used for the `aria-label` if not\nalready provided."
        },
        "attribute": "full-name",
        "reflect": false,
        "defaultValue": "''"
      }
    };
  }
  static get elementRef() { return "element"; }
}
//# sourceMappingURL=mx-avatar.js.map
