import { newSpecPage } from "@stencil/core/testing";
import { MxAvatar } from "../mx-avatar";
describe('mx-avatar', () => {
  it('renders a monogram when only the fullName prop is set', async () => {
    const page = await newSpecPage({
      components: [MxAvatar],
      html: `<mx-avatar full-name="Albert Einstein"></mx-avatar>`,
    });
    expect(page.root.getAttribute('class')).toContain('avatar-monogram');
    expect(page.root.textContent).toContain('AE');
  });
  it('handles a single name', async () => {
    const page = await newSpecPage({
      components: [MxAvatar],
      html: `<mx-avatar full-name="Zoe"></mx-avatar>`,
    });
    expect(page.root.textContent.trim()).toBe('Z');
  });
  it('handles middle names', async () => {
    const page = await newSpecPage({
      components: [MxAvatar],
      html: `<mx-avatar full-name="Zoe Jane Smith"></mx-avatar>`,
    });
    expect(page.root.textContent.trim()).toBe('ZS');
  });
  it('renders an icon when the icon prop is set', async () => {
    const page = await newSpecPage({
      components: [MxAvatar],
      html: `<mx-avatar icon="blah" full-name="Albert Einstein"></mx-avatar>`,
    });
    expect(page.root.getAttribute('class')).toContain('avatar-icon');
    const icon = page.root.querySelector('i');
    expect(icon).toBeTruthy();
    expect(icon.getAttribute('class')).toContain('blah');
  });
  it('renders an image when the imageUrl prop is set', async () => {
    const page = await newSpecPage({
      components: [MxAvatar],
      html: `<mx-avatar image-url="https://example.com/avatar.jpg" full-name="Albert Einstein"></mx-avatar>`,
    });
    expect(page.root.getAttribute('class')).toContain('avatar-image');
    const img = page.root.querySelector('img');
    expect(img).toBeTruthy();
    expect(img.src).toBe('https://example.com/avatar.jpg');
  });
  it('sets the aria-label to the fullName prop by default', async () => {
    const page = await newSpecPage({
      components: [MxAvatar],
      html: `<mx-avatar icon="blah" full-name="Albert Einstein"></mx-avatar>`,
    });
    expect(page.root.getAttribute('aria-label')).toBe('Albert Einstein');
  });
  it('does not override the aria-label if it is already set', async () => {
    const page = await newSpecPage({
      components: [MxAvatar],
      html: `<mx-avatar full-name="Albert Einstein" aria-label="Some Nerd"></mx-avatar>`,
    });
    expect(page.root.getAttribute('aria-label')).toBe('Some Nerd');
  });
  it('logs an error if no props are provided', async () => {
    console.error = jest.fn();
    await newSpecPage({
      components: [MxAvatar],
      html: `<mx-avatar></mx-avatar>`,
    });
    expect(console.error).toHaveBeenCalled();
  });
  it('logs an error if values are whitespace', async () => {
    console.error = jest.fn();
    await newSpecPage({
      components: [MxAvatar],
      html: `<mx-avatar full-name=" " image-url=" " icon=" "></mx-avatar>`,
    });
    expect(console.error).toHaveBeenCalled();
  });
});
//# sourceMappingURL=mx-avatar.spec.js.map
