import { Host, h } from "@stencil/core";
import { Direction, slideIn, slideOut } from "../../utils/transitions";
import { moveToPortal } from "../../utils/portal";
const bannerQueue = [];
export class MxBanner {
  constructor() {
    this.hasActions = false;
    this.isOpen = false;
    this.type = 'default';
    this.isVisible = false;
  }
  async toggleBanner() {
    if (this.isOpen) {
      try {
        if (this.queueItem && bannerQueue.includes(this.queueItem))
          return;
        await this.waitForOtherBanners();
        moveToPortal(this.element);
        this.isVisible = true;
        slideIn(this.element, 400, Direction.top, 'var(--mds-animation-ease-bounce)');
      }
      catch (err) {
      }
    }
    else {
      this.removeFromQueue();
      this.isVisible = false;
      this.mxClose.emit();
    }
  }
  componentWillLoad() {
    this.hasActions = !!this.element.querySelector('[slot="actions"]');
  }
  connectedCallback() {
    this.toggleBanner();
  }
  waitForOtherBanners() {
    return new Promise((resolve, reject) => {
      this.queueItem = { resolve, reject };
      bannerQueue.push(this.queueItem);
      if (bannerQueue.length === 1)
        return resolve();
    });
  }
  removeFromQueue() {
    if (!this.queueItem)
      return;
    const queueIndex = bannerQueue.indexOf(this.queueItem);
    bannerQueue.splice(bannerQueue.indexOf(this.queueItem), 1);
    if (queueIndex === 0 && bannerQueue.length > 0)
      bannerQueue[0].resolve();
  }
  async close() {
    if (!this.isOpen)
      return;
    await slideOut(this.element, 400, Direction.top, 'var(--mds-animation-ease-bounce)');
    this.isOpen = false;
  }
  onAlertClick() {
    if (this.hasActions)
      return;
    this.close();
  }
  get hostClass() {
    let str = 'flex fixed left-0 top-0 px-12 w-full justify-center pointer-events-none z-50';
    if (!this.isVisible)
      str += ' hidden';
    if (this.type !== 'default')
      str += ' ' + this.type;
    return str;
  }
  get alertClass() {
    let str = 'mx-banner-alert mt-30 flex items-center rounded sm:rounded-full shadow-drop sm:h-60 py-16 sm:py-0 pl-12 pr-12 sm:pr-20 pointer-events-auto';
    if (!this.hasActions)
      str += ' cursor-pointer';
    return str;
  }
  get avatarIcon() {
    if (this.type === 'warning')
      return 'mds-warning';
    return 'mds-hand-waving';
  }
  render() {
    return (h(Host, { class: this.hostClass }, h("div", { role: "alert", class: this.alertClass, onClick: this.onAlertClick.bind(this) }, h("div", { class: "flex-shrink-0 self-start sm:self-auto", "data-testid": "avatar" }, h("slot", { name: "avatar" }, h("mx-avatar", { icon: this.avatarIcon }))), h("div", { class: "flex-1 flex flex-col sm:flex-row sm:items-center pl-16 sm:pl-20" }, h("p", { class: "flex-1 my-0 leading-none text-4 break-anywhere font-bold pr-16", "data-testid": "message" }, h("slot", null)), h("div", { class: "flex-shrink-0 -ml-8 sm:ml-0 -mb-8 sm:mb-0", "data-testid": "actions", onClick: this.close.bind(this) }, h("slot", { name: "actions" }))), h("button", { type: "button", class: "flex w-30 h-30 items-center justify-center", "data-testid": "close-button", onClick: this.close.bind(this) }, h("i", { class: "mds-x" })))));
  }
  static get is() { return "mx-banner"; }
  static get properties() {
    return {
      "isOpen": {
        "type": "boolean",
        "mutable": true,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Toggles the visibility of the banner."
        },
        "attribute": "is-open",
        "reflect": true,
        "defaultValue": "false"
      },
      "type": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "'default' | 'warning' | 'progress'",
          "resolved": "\"default\" | \"progress\" | \"warning\"",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "type",
        "reflect": false,
        "defaultValue": "'default'"
      }
    };
  }
  static get states() {
    return {
      "isVisible": {}
    };
  }
  static get events() {
    return [{
        "method": "mxClose",
        "name": "mxClose",
        "bubbles": true,
        "cancelable": true,
        "composed": true,
        "docs": {
          "tags": [],
          "text": "Emitted after the banner closes."
        },
        "complexType": {
          "original": "void",
          "resolved": "void",
          "references": {}
        }
      }];
  }
  static get elementRef() { return "element"; }
  static get watchers() {
    return [{
        "propName": "isOpen",
        "methodName": "toggleBanner"
      }];
  }
}
//# sourceMappingURL=mx-banner.js.map
