import { newSpecPage } from "@stencil/core/testing";
import { MxButton } from "../../mx-button/mx-button";
import { MxBanner } from "../mx-banner";
import { MxAvatar } from "../../mx-avatar/mx-avatar";
describe('mx-banner', () => {
  let page;
  let root;
  beforeEach(async () => {
    page = await newSpecPage({
      components: [MxBanner, MxButton, MxAvatar],
      html: `
      <mx-banner is-open>
        Test message.
        <div slot="actions">
          <mx-button btn-type="text">Action</mx-button>
        </div>
      </mx-banner>
      `,
    });
    root = page.root;
  });
  it('has a role of alert', () => {
    expect(root.querySelector('[role="alert"]')).not.toBeNull();
  });
  it('renders the default slot inside the banner', () => {
    expect(root.querySelector('[data-testid="message"]').textContent).toContain('Test message');
  });
  it('renders the actions slot', () => {
    expect(root.querySelector('[data-testid="actions"] mx-button')).not.toBeNull();
  });
  it('hides the banner if isOpen is false', async () => {
    root.isOpen = false;
    await page.waitForChanges();
    expect(root.classList.contains('hidden')).toBe(true);
  });
  it('sets the appropriate class and avatar for the type prop', async () => {
    expect(root.querySelector('mx-avatar').icon).toBe('mds-hand-waving');
    root.type = 'warning';
    await page.waitForChanges();
    expect(root.classList.contains('warning')).toBe(true);
    expect(root.querySelector('mx-avatar').icon).toBe('mds-warning');
    root.type = 'progress';
    await page.waitForChanges();
    expect(root.classList.contains('progress')).toBe(true);
  });
  it('closes when the close button is clicked', async () => {
    const closeButton = root.querySelector('[data-testid="close-button"]');
    closeButton.click();
    await page.waitForChanges();
    expect(root.isOpen).toBe(false);
  });
  it('closes when an action button is clicked', async () => {
    const actionButton = root.querySelector('[data-testid="actions"] mx-button');
    actionButton.click();
    await page.waitForChanges();
    expect(root.isOpen).toBe(false);
  });
  it('emits an mxClose event after closing', async () => {
    const listener = jest.fn();
    root.addEventListener('mxClose', listener);
    const closeButton = root.querySelector('[data-testid="close-button"]');
    closeButton.click();
    await page.waitForChanges();
    expect(listener).toHaveBeenCalled();
  });
});
describe('mx-banner', () => {
  let page;
  let root;
  beforeEach(async () => {
    page = await newSpecPage({
      components: [MxBanner, MxButton, MxAvatar],
      html: `
      <mx-banner is-open>
        Test message.
        <mx-avatar slot="avatar" icon="test" />
      </mx-banner>
      `,
    });
    root = page.root;
  });
  it('renders the avatar slot', () => {
    expect(root.querySelector('[data-testid="avatar"] mx-avatar[icon="test"]')).not.toBeNull();
  });
});
//# sourceMappingURL=mx-banner.spec.js.map
