import { Host, h } from "@stencil/core";
import { uuidv4, propagateDataAttributes } from "../../utils/utils";
export class MxBlockInput {
  constructor() {
    this.dataAttributes = {};
    this.uuid = uuidv4();
    this.componentWillRender = propagateDataAttributes;
    this.assistiveText = undefined;
    this.autofocus = false;
    this.colspan = undefined;
    this.disabled = false;
    this.error = false;
    this.inputId = undefined;
    this.label = undefined;
    this.maxlength = undefined;
    this.name = undefined;
    this.placeholder = undefined;
    this.readonly = false;
    this.type = 'text';
    this.value = undefined;
    this.isFocused = false;
    this.characterCount = 0;
  }
  componentDidLoad() {
    this.updateValue();
  }
  onValueChange() {
    this.updateValue();
  }
  updateValue() {
    this.textInput.value = this.hasValue ? this.value : '';
  }
  onFocus() {
    this.isFocused = true;
    this.error = false;
  }
  onBlur() {
    this.isFocused = false;
  }
  onContainerClick(e) {
    if (this.disabled || this.readonly)
      return;
    const slottedButton = this.element.querySelector('[slot="button"]');
    if (slottedButton && slottedButton.contains(e.target))
      return;
    this.textInput.focus();
  }
  onClearClick() {
    this.value = '';
    this.textInput.dispatchEvent(new window.Event('input', { bubbles: true }));
    this.mxClear.emit();
    if (typeof jest === 'undefined')
      this.textInput.focus();
  }
  onInput(e) {
    this.characterCount = e.target.value.length;
    this.value = e.target.value;
  }
  get hasValue() {
    return this.value !== null && this.value !== '' && this.value !== undefined;
  }
  get hostClass() {
    let str = 'mx-block-input';
    if (this.colspan > 0 && this.colspan < 7) {
      str += ' md:col-span-' + this.colspan;
    }
    return str;
  }
  get containerClass() {
    let str = 'mx-block-input-container';
    if (this.disabled)
      str += ' disabled';
    if (this.error)
      str += ' error';
    return str;
  }
  render() {
    const clearButton = !this.disabled && !this.readonly && this.value && (h("button", { type: "button", class: "clear-button flex items-center justify-center w-20 text-2", onClick: this.onClearClick.bind(this), "aria-label": `Clear ${this.label}`, title: `Clear ${this.label}`, "data-testid": "clear-button" }, h("i", { class: "mds-cross transform rotate-45" })));
    return (h(Host, { class: this.hostClass }, h("div", { class: this.containerClass, onClick: this.onContainerClick.bind(this) }, h("div", { class: "mx-block-input-grid" }, h("label", { class: "text-small", htmlFor: this.inputId || this.uuid }, this.label, h("slot", { name: "label" }), this.assistiveText && h("span", { id: this.inputId || this.uuid + '-assistive' }, this.assistiveText)), h("input", Object.assign({ "aria-describedby": this.assistiveText ? (this.inputId || this.uuid) + '-assistive' : null, autofocus: this.autofocus, disabled: this.disabled, id: this.inputId || this.uuid, maxlength: this.maxlength, name: this.name, onBlur: this.onBlur.bind(this), onFocus: this.onFocus.bind(this), onInput: this.onInput.bind(this), placeholder: this.placeholder, readonly: this.readonly, ref: el => (this.textInput = el), type: this.type, value: this.value }, this.dataAttributes)), clearButton, h("slot", { name: "button" })))));
  }
  static get is() { return "mx-block-input"; }
  static get properties() {
    return {
      "assistiveText": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "assistive-text",
        "reflect": false
      },
      "autofocus": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "autofocus",
        "reflect": false,
        "defaultValue": "false"
      },
      "colspan": {
        "type": "number",
        "mutable": false,
        "complexType": {
          "original": "number",
          "resolved": "number",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Used to define the number of columns to span in the parent wrapper if more than 1"
        },
        "attribute": "colspan",
        "reflect": false
      },
      "disabled": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "disabled",
        "reflect": false,
        "defaultValue": "false"
      },
      "error": {
        "type": "boolean",
        "mutable": true,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "error",
        "reflect": true,
        "defaultValue": "false"
      },
      "inputId": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The `id` attribute for the text input"
        },
        "attribute": "input-id",
        "reflect": false
      },
      "label": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Text for the label element"
        },
        "attribute": "label",
        "reflect": false
      },
      "maxlength": {
        "type": "number",
        "mutable": false,
        "complexType": {
          "original": "number",
          "resolved": "number",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "maxlength",
        "reflect": false
      },
      "name": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The `name` attribute for the text input"
        },
        "attribute": "name",
        "reflect": false
      },
      "placeholder": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Placeholder text for the input"
        },
        "attribute": "placeholder",
        "reflect": false
      },
      "readonly": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "readonly",
        "reflect": false,
        "defaultValue": "false"
      },
      "type": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The `type` attribute for the text input"
        },
        "attribute": "type",
        "reflect": false,
        "defaultValue": "'text'"
      },
      "value": {
        "type": "string",
        "mutable": true,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "value",
        "reflect": false
      }
    };
  }
  static get states() {
    return {
      "isFocused": {},
      "characterCount": {}
    };
  }
  static get events() {
    return [{
        "method": "mxClear",
        "name": "mxClear",
        "bubbles": true,
        "cancelable": true,
        "composed": true,
        "docs": {
          "tags": [],
          "text": "Emitted when the clear button is clicked."
        },
        "complexType": {
          "original": "void",
          "resolved": "void",
          "references": {}
        }
      }];
  }
  static get elementRef() { return "element"; }
  static get watchers() {
    return [{
        "propName": "value",
        "methodName": "onValueChange"
      }];
  }
}
//# sourceMappingURL=mx-block-input.js.map
