import { Host, h } from "@stencil/core";
import ripple from "../../utils/ripple";
import { propagateDataAttributes } from "../../utils/utils";
export class MxButton {
  constructor() {
    this.dataAttributes = {};
    this.componentWillRender = propagateDataAttributes;
    this.btnType = 'contained';
    this.elAriaDescribedBy = undefined;
    this.elAriaLabel = undefined;
    this.elAriaLabelledBy = undefined;
    this.elAriaPressed = null;
    this.type = 'button';
    this.value = undefined;
    this.form = undefined;
    this.formaction = undefined;
    this.disabled = false;
    this.xl = false;
    this.href = undefined;
    this.target = undefined;
    this.full = false;
    this.hug = false;
    this.small = false;
    this.dropdown = false;
    this.icon = undefined;
  }
  onClick(e) {
    if (this.disabled) {
      e.stopPropagation();
      e.preventDefault();
      return;
    }
    ripple(e, this.href ? this.anchorElem : this.btnElem);
  }
  get buttonClass() {
    let str = this.btnType;
    if (this.dropdown)
      str += ' dropdown';
    str +=
      ' flex items-center justify-center text-small font-bold uppercase relative overflow-hidden cursor-pointer appearance-none disabled:pointer-events-none disabled:cursor-auto hover:no-underline';
    if (['contained', 'outlined'].includes(this.btnType)) {
      str += ' w-full rounded';
      if (this.btnType === 'outlined')
        str += ' border';
      if (this.hug)
        str += ' hug';
      if (this.xl)
        str += ' min-h-48 px-32 text-3 tracking-1-5';
      else if (this.small)
        str += ' min-h-30 px-10';
      else
        str += ' min-h-36 px-16';
    }
    if (this.btnType === 'simple') {
      str += ' w-full border rounded';
      if (this.small)
        str += ' min-h-30 px-10';
      else
        str += ' min-h-36 px-16';
    }
    if (this.btnType === 'text') {
      str += ' w-full rounded';
      str += this.dropdown ? '' : ' tracking-1-25';
      if (this.small)
        str += ' min-h-30 px-10';
      else
        str += ' min-h-36 px-8 py-10';
    }
    return str;
  }
  connectedCallback() {
    if (this.btnType === 'action')
      this.btnType = 'simple';
  }
  render() {
    const buttonContent = (h("div", { class: "flex justify-center items-center content-center relative overflow-hidden whitespace-nowrap" }, this.icon && h("i", { class: 'mr-8 text-3 ' + this.icon }), h("span", { class: "slot-content truncate" }, h("slot", null)), this.dropdown && this.btnType === 'text' && h("span", { class: "separator inline-block w-1 ml-4 -my-4 h-24" }), this.dropdown && (h("i", { "data-testid": "chevron", class: 'mds-chevron-down text-icon ' + (this.btnType === 'text' ? 'chevron-icon' : 'ml-4') }))));
    return (h(Host, { class: 'mx-button appearance-none' + (this.full ? ' flex' : ' inline-flex') }, this.href ? (h("a", Object.assign({ href: this.href, target: this.target, "aria-disabled": this.disabled ? 'true' : null, class: this.buttonClass, ref: el => (this.anchorElem = el), onClick: this.onClick.bind(this) }, this.dataAttributes), buttonContent)) : (h("button", Object.assign({ type: this.type, form: this.form, formaction: this.formaction, value: this.value, disabled: this.disabled, class: this.buttonClass, ref: el => (this.btnElem = el), onClick: this.onClick.bind(this), "aria-describedby": this.elAriaDescribedBy, "aria-label": this.elAriaLabel, "aria-labelledby": this.elAriaLabelledBy, "aria-pressed": this.elAriaPressed != null ? (!!this.elAriaPressed).toString() : null }, this.dataAttributes), buttonContent))));
  }
  static get is() { return "mx-button"; }
  static get properties() {
    return {
      "btnType": {
        "type": "string",
        "mutable": true,
        "complexType": {
          "original": "BtnType",
          "resolved": "\"action\" | \"contained\" | \"outlined\" | \"simple\" | \"text\"",
          "references": {
            "BtnType": {
              "location": "local",
              "path": "/app/packages/mds/src/components/mx-button/mx-button.tsx",
              "id": "src/components/mx-button/mx-button.tsx::BtnType"
            }
          }
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "btn-type",
        "reflect": false,
        "defaultValue": "'contained'"
      },
      "elAriaDescribedBy": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The aria-describedby attribute for the inner button element."
        },
        "attribute": "el-aria-described-by",
        "reflect": false
      },
      "elAriaLabel": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The aria-label attribute for the inner button element."
        },
        "attribute": "el-aria-label",
        "reflect": false
      },
      "elAriaLabelledBy": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The aria-labelledby attribute for the inner button element."
        },
        "attribute": "el-aria-labelled-by",
        "reflect": false
      },
      "elAriaPressed": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean | null",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The aria-pressed attribute for the inner button element."
        },
        "attribute": "el-aria-pressed",
        "reflect": false,
        "defaultValue": "null"
      },
      "type": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "ButtonTypeAttribute",
          "resolved": "\"button\" | \"reset\" | \"submit\"",
          "references": {
            "ButtonTypeAttribute": {
              "location": "local",
              "path": "/app/packages/mds/src/components/mx-button/mx-button.tsx",
              "id": "src/components/mx-button/mx-button.tsx::ButtonTypeAttribute"
            }
          }
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "type",
        "reflect": false,
        "defaultValue": "'button'"
      },
      "value": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "value",
        "reflect": false
      },
      "form": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "form",
        "reflect": false
      },
      "formaction": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "formaction",
        "reflect": false
      },
      "disabled": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "disabled",
        "reflect": false,
        "defaultValue": "false"
      },
      "xl": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "xl",
        "reflect": false,
        "defaultValue": "false"
      },
      "href": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Create button as link"
        },
        "attribute": "href",
        "reflect": false
      },
      "target": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Only for link buttons"
        },
        "attribute": "target",
        "reflect": false
      },
      "full": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Sets display to flex instead of inline-flex"
        },
        "attribute": "full",
        "reflect": false,
        "defaultValue": "false"
      },
      "hug": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "For contained buttons, allow the button width to be less than the default minimum of 150px"
        },
        "attribute": "hug",
        "reflect": false,
        "defaultValue": "false"
      },
      "small": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Sets the min-height to 30px"
        },
        "attribute": "small",
        "reflect": false,
        "defaultValue": "false"
      },
      "dropdown": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Show chevron icon"
        },
        "attribute": "dropdown",
        "reflect": false,
        "defaultValue": "false"
      },
      "icon": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Class name of icon"
        },
        "attribute": "icon",
        "reflect": false
      }
    };
  }
  static get elementRef() { return "element"; }
}
//# sourceMappingURL=mx-button.js.map
