import { newSpecPage } from "@stencil/core/testing";
import { MxComment } from "../mx-comment";
describe('mx-comment', () => {
  let page;
  let root;
  beforeEach(async () => {
    page = await newSpecPage({
      components: [MxComment],
      html: `
      <mx-comment>
        <mx-avatar slot="avatar" full-name="John Smith"></mx-avatar>
        <span slot="author">John Smith</span>
        <span slot="date">Yesterday</span>
        Comment Text Here
      </mx-comment>`,
    });
    root = page.root;
  });
  it('renders the provided content inside the slots', () => {
    expect(root.querySelector('[data-testid="avatar"]').innerHTML).toContain('<mx-avatar slot="avatar" full-name="John Smith"></mx-avatar>');
    expect(root.querySelector('cite').textContent.trim()).toBe('John Smith');
    expect(root.querySelector('time').textContent.trim()).toBe('Yesterday');
    expect(root.querySelector('[data-testid="text"]').textContent.trim()).toBe('Comment Text Here');
  });
  it('does not add the inverted class by default', () => {
    const commentText = root.querySelector('[data-testid="text"]');
    expect(commentText.classList.contains('inverted')).toBe(false);
  });
  it('adds the inverted class when the inverted prop is set', async () => {
    root.inverted = true;
    await page.waitForChanges();
    const commentText = root.querySelector('[data-testid="text"]');
    expect(commentText.classList.contains('inverted')).toBe(true);
  });
});
//# sourceMappingURL=mx-comment.spec.js.map
