import { newSpecPage } from "@stencil/core/testing";
import { MxLibrarySelectionCard } from "../mx-library-selection-card";
import { MxButton } from "../../mx-button/mx-button";
describe('mx-library-selection-card', () => {
  let page;
  let root;
  beforeEach(async () => {
    page = await newSpecPage({
      components: [MxLibrarySelectionCard, MxButton],
      html: `
          <mx-library-selection-card label="Cat" description="asdf" image-url="some-image.jpg"></mx-library-selection-card>
      `,
    });
    root = page.root;
  });
  it('renders the label, description, and image based on props', async () => {
    expect(root.querySelector('[data-testid="label"]').textContent).toBe('Cat');
    expect(root.querySelector('[data-testid="description"]').textContent).toBe('asdf');
    expect(root.querySelector('[data-testid="image"]').innerHTML).toContain('some-image.jpg');
  });
  it('selects the card when the button is clicked', async () => {
    const button = root.querySelector('mx-button');
    button.click();
    await page.waitForChanges();
    expect(root.selected).toBe(true);
    expect(button.elAriaPressed).toBe(true);
  });
  it('emits an mxSelect event when the button is clicked', async () => {
    const listener = jest.fn();
    root.addEventListener('mxSelect', listener);
    const button = root.querySelector('mx-button');
    button.click();
    expect(listener).toHaveBeenCalled();
  });
  it('renders a checkmark icon if the selected prop is set', async () => {
    root.selected = true;
    await page.waitForChanges();
    expect(root.querySelector('[data-testid="check"]')).not.toBeNull();
  });
  it('disables the button if the disabled prop is set', async () => {
    await page.waitForChanges();
    expect(root.querySelector('mx-button').disabled).toBe(true);
  });
});
describe('mx-library-selection-card (slots)', () => {
  let page;
  let root;
  beforeEach(async () => {
    page = await newSpecPage({
      components: [MxLibrarySelectionCard, MxButton],
      html: `
          <mx-library-selection-card>
            <span slot="label">Cat</span>
            <span slot="description">asdf</span>
            <img slot="image" src="some-image.jpg">
          </mx-library-selection-card>
      `,
    });
    root = page.root;
  });
  it('renders the label, description, and image slot content correctly', async () => {
    expect(root.querySelector('[data-testid="label"]').textContent).toBe('Cat');
    expect(root.querySelector('[data-testid="description"]').textContent).toBe('asdf');
    expect(root.querySelector('[data-testid="image"]').innerHTML).toContain('some-image.jpg');
  });
});
//# sourceMappingURL=mx-library-selection-card.js.map
