import { newSpecPage } from "@stencil/core/testing";
import { MxMenuAccordion } from "../mx-menu-accordion";
import { MxMenuItem } from "../../mx-menu-item/mx-menu-item";
describe('mx-menu-accordion', () => {
  let page;
  let button;
  let root;
  beforeEach(async () => {
    page = await newSpecPage({
      components: [MxMenuAccordion, MxMenuItem],
      html: `
      <button>Toggle Accordion</button>
      <mx-menu-accordion>
        <mx-menu-item>Item 1</mx-menu-item>
        <mx-menu-item>Item 2</mx-menu-item>
      </mx-menu-accordion>
      `,
    });
    root = page.root;
    button = page.doc.querySelector('button');
    root.anchorEl = button;
    await page.waitForChanges();
  });
  it('is initially not visible', () => {
    expect(root.isOpen).toBe(false);
    expect(root.classList.contains('invisible')).toBe(true);
  });
  it("sets the inner menu's role attribute", async () => {
    expect(root.firstElementChild.getAttribute('role')).toBe('menu');
  });
  it('expands when the anchorEl is clicked', async () => {
    button.click();
    await page.waitForChanges();
    expect(root.isOpen).toBe(true);
    expect(root.classList.contains('invisible')).toBe(false);
  });
  it('collapses when the anchorEl is clicked again', async () => {
    button.click();
    await page.waitForChanges();
    button.click();
    await page.waitForChanges();
    await page.waitForChanges();
    expect(root.isOpen).toBe(false);
    expect(root.classList.contains('invisible')).toBe(true);
  });
  it('emits an mxOpen event when it opens', async () => {
    const listener = jest.fn();
    root.addEventListener('mxOpen', listener);
    button.click();
    await page.waitForChanges();
    expect(listener).toHaveBeenCalled();
  });
  it('emits an mxClose event when it closes', async () => {
    button.click();
    await page.waitForChanges();
    const listener = jest.fn();
    root.addEventListener('mxClose', listener);
    button.click();
    await page.waitForChanges();
    expect(listener).toHaveBeenCalled();
  });
  it('updates aria attributes on anchorEl', async () => {
    button.click();
    await page.waitForChanges();
    expect(button.getAttribute('aria-expanded')).toBe('true');
    expect(button.getAttribute('aria-controls')).toBe(root.firstElementChild.getAttribute('id'));
    button.click();
    await page.waitForChanges();
    expect(button.getAttribute('aria-expanded')).toBe('false');
  });
});
//# sourceMappingURL=mx-menu-accordion.spec.js.map
