import { Host, h } from "@stencil/core";
export class MxSelectionCardGroup {
  constructor() {
    this.name = undefined;
    this.value = undefined;
  }
  async onValueChange() {
    this.updateCards();
    if (this.name) {
      await new Promise(requestAnimationFrame);
      const input = this.element.querySelector('input');
      if (input)
        input.dispatchEvent(new Event('input', { bubbles: true }));
    }
  }
  connectedCallback() {
    this.updateCards();
  }
  onCardSelect(e) {
    const isSelected = e.detail;
    if (!isSelected) {
      this.value = undefined;
    }
    else {
      const card = e.target.closest('mx-selection-card, mx-library-selection-card');
      if (card && !card.disabled)
        this.value = card.value;
    }
  }
  updateCards() {
    const cards = this.element.querySelectorAll('mx-selection-card, mx-library-selection-card');
    cards.forEach(card => {
      card.selected = card.value === this.value;
    });
  }
  render() {
    return (h(Host, { class: "flex flex-wrap gap-10" }, h("slot", null), this.name && h("input", { type: "hidden", name: this.name, value: this.value })));
  }
  static get is() { return "mx-selection-card-group"; }
  static get properties() {
    return {
      "name": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "If provided, a hidden input will be added with this `name` attribute."
        },
        "attribute": "name",
        "reflect": false
      },
      "value": {
        "type": "any",
        "mutable": true,
        "complexType": {
          "original": "any",
          "resolved": "any",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The selected value. All child components must have a unique `value` prop."
        },
        "attribute": "value",
        "reflect": false
      }
    };
  }
  static get elementRef() { return "element"; }
  static get watchers() {
    return [{
        "propName": "value",
        "methodName": "onValueChange"
      }];
  }
  static get listeners() {
    return [{
        "name": "mxSelect",
        "method": "onCardSelect",
        "target": undefined,
        "capture": false,
        "passive": false
      }];
  }
}
//# sourceMappingURL=mx-selection-card-group.js.map
