import { newSpecPage } from "@stencil/core/testing";
import { MxSelectionCardGroup } from "../mx-selection-card-group";
import { MxSelectionCard } from "../../mx-selection-card/mx-selection-card";
import { MxButton } from "../../mx-button/mx-button";
describe('mx-selection-card-group', () => {
  let page;
  let root;
  let cards;
  beforeEach(async () => {
    page = await newSpecPage({
      components: [MxSelectionCardGroup, MxSelectionCard, MxButton],
      html: `
        <mx-selection-card-group value="dog">
          <mx-selection-card label="Cat" value="cat" description="asdf"></mx-selection-card>
          <mx-selection-card label="Dog" value="dog" description="asdf"></mx-selection-card>
          <mx-selection-card label="Bird" value="bird" description="asdf"></mx-selection-card>
        </mx-selection-card-group>
      `,
    });
    root = page.root;
    cards = Array.from(root.querySelectorAll('mx-selection-card'));
  });
  it('sets the selected prop on the card with the selected value', async () => {
    expect(cards[0].selected).toBe(false);
    expect(cards[1].selected).toBe(true);
    expect(cards[2].selected).toBe(false);
  });
  it('creates a hidden input when the name prop is set', async () => {
    expect(root.querySelector('input')).toBeNull();
    root.name = 'test';
    await page.waitForChanges();
    const input = root.querySelector('input');
    expect(input).not.toBeNull();
    expect(input.name).toBe('test');
    expect(input.type).toBe('hidden');
    expect(input.value).toBe('dog');
  });
  it('updates its value when a card is selected', async () => {
    cards[0].querySelector('button').click();
    await page.waitForChanges();
    expect(root.value).toBe('cat');
    expect(cards[0].selected).toBe(true);
    expect(cards[1].selected).toBe(false);
    expect(cards[2].selected).toBe(false);
  });
  it('emits an input event when a card is selected (and if name prop is set)', async () => {
    root.name = 'test';
    await page.waitForChanges();
    const listener = jest.fn();
    root.addEventListener('input', listener);
    cards[0].querySelector('button').click();
    await page.waitForChanges();
    await new Promise(requestAnimationFrame);
    expect(listener).toHaveBeenCalled();
  });
});
//# sourceMappingURL=mx-selection-card-group.spec.js.map
