import { Host, h } from "@stencil/core";
import { uuidv4 } from "../../utils/utils";
export class MxSelectionCard {
  constructor() {
    this.uuid = uuidv4();
    this.description = undefined;
    this.disabled = false;
    this.elAriaLabel = undefined;
    this.imageUrl = undefined;
    this.label = undefined;
    this.selected = false;
    this.value = undefined;
  }
  toggle() {
    if (this.disabled)
      return;
    this.selected = !this.selected;
    this.mxSelect.emit(this.selected);
  }
  get hostClass() {
    let str = 'mx-selection-card flex items-center justify-center relative p-20 border rounded-sm transform';
    if (this.selected) {
      str += ' selected shadow-drop -translate-y-2';
    }
    else {
      str += ' hover:shadow-drop hover:-translate-y-2';
    }
    return str;
  }
  render() {
    return (h(Host, { class: this.hostClass }, this.selected && (h("i", { class: "selection-card-checked mds-check-circle text-3 absolute top-30 right-30", role: "presentation", "data-testid": "check" })), h("div", { class: "flex flex-col items-center" }, h("div", { class: "h-60", "data-testid": "image" }, h("slot", { name: "image" }, this.imageUrl && h("img", { src: this.imageUrl, alt: "" }))), h("p", { class: "selection-card-label my-0 mt-40", id: this.uuid + '-label', "data-testid": "label" }, h("slot", { name: "label" }, this.label)), h("div", { class: "my-0 mt-20 mb-40 flex-1 text-center leading-tight tracking-0-4", id: this.uuid + '-description', "data-testid": "description" }, h("slot", { name: "description" }, this.description)), h("mx-button", { class: "selection-card-button", disabled: this.disabled, "el-aria-label": this.elAriaLabel, "el-aria-labelledby": this.uuid + '-label', "el-aria-describedby": this.uuid + '-description', "el-aria-pressed": this.selected ? 'true' : 'false', onClick: this.toggle.bind(this) }, this.selected ? 'Selected' : 'Select'))));
  }
  static get is() { return "mx-selection-card"; }
  static get properties() {
    return {
      "description": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The description text to display below the label. This has no effect if using the \"description\" slot."
        },
        "attribute": "description",
        "reflect": false
      },
      "disabled": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "disabled",
        "reflect": false,
        "defaultValue": "false"
      },
      "elAriaLabel": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The aria-label attribute for the inner button element."
        },
        "attribute": "el-aria-label",
        "reflect": false
      },
      "imageUrl": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The URL for the card image. This has no effect if using the \"image\" slot."
        },
        "attribute": "image-url",
        "reflect": false
      },
      "label": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The label text to display below the image. This has no effect if using the \"label\" slot."
        },
        "attribute": "label",
        "reflect": false
      },
      "selected": {
        "type": "boolean",
        "mutable": true,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "selected",
        "reflect": true,
        "defaultValue": "false"
      },
      "value": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Only used inside a selection card group"
        },
        "attribute": "value",
        "reflect": false
      }
    };
  }
  static get events() {
    return [{
        "method": "mxSelect",
        "name": "mxSelect",
        "bubbles": true,
        "cancelable": true,
        "composed": true,
        "docs": {
          "tags": [],
          "text": "When the button is clicked, this event is emitted. The `CustomEvent.detail` will be true or false depending on whether the card is now selected. If using a selection card group with a `name`, the group element will also then emit an `input` event with the selected value."
        },
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        }
      }];
  }
}
//# sourceMappingURL=mx-selection-card.js.map
