import { Host, h } from "@stencil/core";
export class MxTab {
  constructor() {
    this.label = '';
    this.elAriaLabel = '';
    this.icon = '';
    this.selected = false;
    this.badge = false;
    this.badgeClass = '';
    this.elRole = 'tab';
    this.href = null;
    this.target = null;
    this.nav = false;
  }
  componentDidLoad() {
    if (!this.label && !this.elAriaLabel) {
      throw new Error('Please provide either a label or an aria-label for each tab.');
    }
  }
  get labelClass() {
    let str = 'flex whitespace-nowrap items-center uppercase my-0 gap-x-6';
    str += this.nav ? ' text-body' : ' text-small';
    return str;
  }
  get badgeEl() {
    return h("mx-badge", { indicator: true, badgeClass: ['w-8 h-8', this.badgeClass].join(' ') });
  }
  render() {
    const Tag = this.href ? 'a' : 'button';
    return (h(Host, { class: "mx-tab relative inline-flex items-center justify-center min-w-0 h-60" }, h(Tag, { role: this.href ? null : this.elRole, type: this.href ? null : 'button', href: this.href, target: this.target, "aria-selected": this.selected && !this.href ? 'true' : null, "aria-label": this.elAriaLabel || this.label, class: "relative flex items-center justify-center overflow-hidden w-full h-full" }, h("span", { class: this.labelClass }, this.badge && this.badgeEl, h("span", { class: "tracking-0-3 font-bold" }, this.label), this.icon && h("i", { class: this.icon + ' text-icon' }))), h("span", { class: 'active-tab-indicator absolute bottom-0 left-0 w-full h-2 pointer-events-none' +
        (this.selected ? '' : ' opacity-0') })));
  }
  static get is() { return "mx-tab"; }
  static get properties() {
    return {
      "label": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Label text to display"
        },
        "attribute": "label",
        "reflect": false,
        "defaultValue": "''"
      },
      "elAriaLabel": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "If you are not providing a `label`, this should be provided instead for accessibility"
        },
        "attribute": "el-aria-label",
        "reflect": false,
        "defaultValue": "''"
      },
      "icon": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Class name of icon to display"
        },
        "attribute": "icon",
        "reflect": false,
        "defaultValue": "''"
      },
      "selected": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Only set this manually if you are NOT setting the `value` prop on the parent `mx-tabs`"
        },
        "attribute": "selected",
        "reflect": true,
        "defaultValue": "false"
      },
      "badge": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Display a circular badge"
        },
        "attribute": "badge",
        "reflect": false,
        "defaultValue": "false"
      },
      "badgeClass": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Additional classes for the badge"
        },
        "attribute": "badge-class",
        "reflect": false,
        "defaultValue": "''"
      },
      "elRole": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The button's `role` attribute. This is set internally for the [Top Navigation](/components/navigation.html#top-navigation) component. This has no effect if `href` is set."
        },
        "attribute": "el-role",
        "reflect": false,
        "defaultValue": "'tab'"
      },
      "href": {
        "type": "any",
        "mutable": false,
        "complexType": {
          "original": "any",
          "resolved": "any",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The URL to link to. This will cause the tab to render an `<a>` instead of a `<button>`."
        },
        "attribute": "href",
        "reflect": false,
        "defaultValue": "null"
      },
      "target": {
        "type": "any",
        "mutable": false,
        "complexType": {
          "original": "any",
          "resolved": "any",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The `target` attribute of the link. The only applies if `href` is also set."
        },
        "attribute": "target",
        "reflect": false,
        "defaultValue": "null"
      },
      "nav": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "This is set by the parent `mx-tabs` if its `nav` prop is also set."
        },
        "attribute": "nav",
        "reflect": true,
        "defaultValue": "false"
      }
    };
  }
  static get elementRef() { return "element"; }
}
//# sourceMappingURL=mx-tab.js.map
