import { newSpecPage } from "@stencil/core/testing";
import { MxTab } from "../mx-tab";
import { MxBadge } from "../../mx-badge/mx-badge";
describe('mx-tab (button)', () => {
  let page;
  let root;
  beforeEach(async () => {
    page = await newSpecPage({
      components: [MxTab, MxBadge],
      html: `<mx-tab label="Home" />`,
    });
    root = page.root;
  });
  it('renders a <button role="tab">', async () => {
    expect(root.querySelector('button[role="tab"]')).not.toBeNull();
  });
  it('renders the label text', async () => {
    expect(root.innerText).toContain('Home');
  });
  it('sets the aria-label', async () => {
    expect(root.querySelector('[aria-label="Home"]')).not.toBeNull();
    root.elAriaLabel = 'Search';
    await page.waitForChanges();
    expect(root.querySelector('[aria-label="Search"]')).not.toBeNull();
  });
  it('sets aria-selected', async () => {
    expect(root.querySelector('[aria-selected="true"]')).toBeNull();
    root.selected = true;
    await page.waitForChanges();
    expect(root.querySelector('[aria-selected="true"]')).not.toBeNull();
  });
  it('renders the icon', async () => {
    expect(root.querySelector('i')).toBeNull();
    root.icon = 'mds-search';
    await page.waitForChanges();
    expect(root.querySelector('i')).not.toBeNull();
  });
  it('renders the badge', async () => {
    expect(root.querySelector('mx-badge')).toBeNull();
    root.badge = true;
    root.badgeClass = 'my-badge-class';
    await page.waitForChanges();
    const badge = root.querySelector('mx-badge');
    expect(badge).not.toBeNull();
    expect(badge.badgeClass).toContain('my-badge-class');
  });
});
describe('mx-tab (as link)', () => {
  let page;
  let root;
  let link;
  beforeEach(async () => {
    page = await newSpecPage({
      components: [MxTab],
      html: `<mx-tab label="Search" href="#search" target="_blank" />`,
    });
    root = page.root;
    link = root.querySelector('a');
  });
  it('renders an <a>', async () => {
    expect(link).not.toBeNull();
  });
  it('renders the label text', async () => {
    expect(link.innerText).toContain('Search');
  });
  it('sets the href', async () => {
    expect(link.getAttribute('href')).toBe('#search');
  });
  it('sets the target', async () => {
    expect(link.getAttribute('target')).toBe('_blank');
  });
});
//# sourceMappingURL=mx-tab.spec.js.map
