import "../../../utils/matchMedia.mock";
import { newSpecPage } from "@stencil/core/testing";
import { MxTabs } from "../mx-tabs";
import { MxTab } from "../../mx-tab/mx-tab";
import { MxSelect } from "../../mx-select/mx-select";
import { MxMenu } from "../../mx-menu/mx-menu";
import { MxMenuItem } from "../../mx-menu-item/mx-menu-item";
describe('mx-tabs', () => {
  let page;
  let root;
  let tabs;
  beforeEach(async () => {
    page = await newSpecPage({
      components: [MxTabs, MxTab, MxSelect, MxMenu, MxMenuItem],
      html: `<mx-tabs />`,
    });
    page.root.tabs = [{ label: 'Home' }, { label: 'Search' }];
    await page.waitForChanges();
    root = page.root;
    tabs = root.querySelectorAll('mx-tab');
  });
  it('renders an inline grid', async () => {
    const grid = root.firstElementChild;
    expect(grid.getAttribute('class')).toContain('inline-grid');
  });
  it('sets a tab as selected based on the value prop', async () => {
    expect(tabs[1].selected).toBe(false);
    root.value = 1;
    await page.waitForChanges();
    expect(tabs[1].selected).toBe(true);
  });
  it('emits an mxChange event when a tab is clicked', async () => {
    let emittedValue;
    root.addEventListener('mxChange', (e) => (emittedValue = e.detail));
    tabs[1].click();
    expect(emittedValue).toBe(1);
  });
  it('uses an mx-select when screen width <= 768 and >2 tabs', async () => {
    root.tabs = [{ label: 'Home' }, { label: 'Favorites' }, { label: 'Search' }];
    await page.waitForChanges();
    const select = root.querySelector('mx-select');
    const options = root.querySelectorAll('option');
    expect(select).not.toBeNull();
    expect(options.length).toBe(3);
  });
  it('should handle mx-select value changes properly', async () => {
    root.tabs = [{ label: 'Home' }, { label: 'Favorites' }, { label: 'Search' }];
    await page.waitForChanges();
    let emittedValue;
    root.addEventListener('mxChange', (e) => (emittedValue = e.detail));
    const select = root.querySelector('mx-select');
    select.value = '2';
    select.dispatchEvent(new Event('input'));
    expect(emittedValue).toBe(2);
  });
  it('should not show "More" tab if nav prop is false', async () => {
    const moreTab = root.querySelector('[data-testid="more-tab"]');
    expect(moreTab).toBeNull();
  });
  it('should not show submenu label if submenu prop is false', async () => {
    const submenuLabel = root.querySelector('[data-testid="submenu-label"]');
    expect(submenuLabel).toBeNull();
  });
});
describe('mx-tabs (nav)', () => {
  let page;
  let root;
  beforeEach(async () => {
    page = await newSpecPage({
      components: [MxTabs, MxTab, MxSelect, MxMenu, MxMenuItem],
      html: `<mx-tabs />`,
    });
    page.root.nav = true;
    page.root.tabs = [{ label: 'Home' }, { label: 'Search' }];
    await page.waitForChanges();
    root = page.root;
  });
  it('should only show "More" tab if there are more than 3 tabs', async () => {
    let moreTab = root.querySelector('[data-testid="more-tab"]');
    expect(moreTab).toBeNull();
    root.tabs = [{ label: 'Home' }, { label: 'Favorites' }, { label: 'Search' }, { label: 'Profile' }];
    await page.waitForChanges();
    moreTab = root.querySelector('[data-testid="more-tab"]');
    expect(moreTab).not.toBeNull();
  });
  it('should emit the correct value when a menu item is clicked', async () => {
    let emittedValue;
    root.addEventListener('mxChange', (e) => (emittedValue = e.detail));
    const menuItems = root.querySelectorAll('mx-menu-item');
    menuItems[1].click();
    expect(emittedValue).toBe(1);
  });
});
//# sourceMappingURL=mx-tabs.spec.js.map
