import { newSpecPage } from "@stencil/core/testing";
import { MxTimelineCard } from "../mx-timeline-card";
describe('mx-timeline-card', () => {
  let page;
  let root;
  let cardTextEl;
  let contentEl;
  beforeEach(async () => {
    page = await newSpecPage({
      components: [MxTimelineCard],
      html: `
        <mx-timeline-card status-color="#ff0000">
          <span slot="date">March 3, 2023</span>
          <span>Test Content</span>
        </mx-timeline-card>`,
    });
    root = page.root;
    cardTextEl = root.querySelector('.timeline-card-text');
    contentEl = root.querySelector('.timeline-card-content');
  });
  it('has a role of listitem', () => {
    expect(root.getAttribute('role')).toBe('listitem');
  });
  it('sets the statusColor for the appropriate elements', () => {
    const indicator = root.querySelector('[data-testid="status-indicator"]');
    expect(indicator.style.backgroundColor).toBe('#ff0000');
    expect(root.style.getPropertyValue('--mds-timeline-card-status-color')).toBe('#ff0000');
  });
  it('renders slot contents correctly', () => {
    expect(contentEl.textContent).toContain('March 3, 2023');
    expect(cardTextEl.textContent.trim()).toBe('Test Content');
    expect(root.querySelector('.timeline-card-status')).toBeNull();
  });
  it('expands text on mouseover and focus', async () => {
    expect(cardTextEl.classList.contains('truncate')).toBe(true);
    root.dispatchEvent(new Event('mouseover'));
    await page.waitForChanges();
    expect(cardTextEl.classList.contains('truncate')).toBe(false);
    root.dispatchEvent(new Event('mouseout'));
    await page.waitForChanges();
    expect(cardTextEl.classList.contains('truncate')).toBe(true);
    root.dispatchEvent(new Event('focus'));
    await page.waitForChanges();
    expect(cardTextEl.classList.contains('truncate')).toBe(false);
    root.dispatchEvent(new Event('blur'));
    await page.waitForChanges();
    expect(cardTextEl.classList.contains('truncate')).toBe(true);
  });
});
describe('mx-timeline-card (with status slot)', () => {
  let page;
  let root;
  beforeEach(async () => {
    page = await newSpecPage({
      components: [MxTimelineCard],
      html: `
        <mx-timeline-card status-color="#ff0000">
          <span slot="date">March 3, 2023</span>
          <span>Test Content</span>
          <span slot="status">Status</span>
        </mx-timeline-card>`,
    });
    root = page.root;
  });
  it('renders the status slot when provided', () => {
    const statusWrapper = root.querySelector('.timeline-card-status');
    expect(statusWrapper.textContent).toBe('Status');
  });
});
//# sourceMappingURL=mx-timeline-card.spec.js.map
