import { Host, h } from "@stencil/core";
import { MinWidths, minWidthSync } from "../../utils/minWidthSync";
export class MxTopNav {
  constructor() {
    this.hasAvatar = false;
    this.searchLoading = false;
    this.searchForm = undefined;
    this.searchId = undefined;
    this.searchName = undefined;
    this.searchPlaceholder = 'Search';
    this.searchValue = undefined;
    this.selectedTabIndex = null;
    this.showSearch = true;
    this.tabs = undefined;
    this.minWidths = new MinWidths();
    this.isSearchFocused = false;
    this.extendSearch = false;
    this.isMenuOpen = false;
  }
  connectedCallback() {
    minWidthSync.subscribeComponent(this);
  }
  componentDidLoad() {
    if (this.mxTabs)
      this.mxTabs.menuButton = this.menuButton;
    this.setExtendSearch();
    new ResizeObserver(() => this.setExtendSearch()).observe(this.element);
  }
  componentWillRender() {
    this.hasAvatar = !!this.element.querySelector('[slot="avatar"]');
  }
  disconnectedCallback() {
    minWidthSync.unsubscribeComponent(this);
  }
  setExtendSearch() {
    const leftWrapperWidth = this.leftWrapper.offsetWidth;
    const headerWidth = this.leftWrapper.querySelector('header').scrollWidth;
    const availableWidth = leftWrapperWidth - headerWidth;
    this.extendSearch = availableWidth < 250;
  }
  onSearchClick() {
    if (document.activeElement !== this.searchInput) {
      this.searchInput.focus();
    }
    else {
      this.searchLoading = false;
    }
  }
  onSearchKeydown(e) {
    if (e.key === 'Enter' && this.searchInput.value.trim()) {
      this.searchLoading = true;
      this.mxSearch.emit(this.searchInput.value.trim());
    }
  }
  get searchClass() {
    let str = 'top-nav-search';
    if (this.isSearchFocused)
      str += ' search-focused';
    if (this.extendSearch)
      str += ' extend-search';
    return str;
  }
  render() {
    return (h(Host, { class: "mx-top-nav relative flex h-60" }, h("div", { ref: el => (this.leftWrapper = el), class: "flex flex-1 relative items-stretch overflow-hidden" }, h("header", { class: "flex flex-shrink-0 pl-20 items-center overflow-hidden" }, h("slot", { name: "header" })), h("nav", { class: 'flex-grow pl-80 overflow-hidden' + (!this.showSearch ? ' pr-20' : '') }, this.tabs && this.tabs.length && (h("mx-tabs", { ref: el => (this.mxTabs = el), nav: true, tabs: this.tabs, value: this.selectedTabIndex, onMxChange: e => this.mxChange.emit(e.detail), onMxMenuOpen: () => (this.isMenuOpen = true), onMxMenuClose: () => (this.isMenuOpen = false) }, h("slot", { name: "menu", slot: "menu" })))), this.showSearch && (h("div", { class: "top-nav-search-placeholder flex-shrink-0" })), this.showSearch && (h("div", { class: this.searchClass }, h("input", { ref: el => (this.searchInput = el), id: this.searchId, type: "search", placeholder: this.searchPlaceholder, name: this.searchName, value: this.searchValue, form: this.searchForm, onFocus: () => (this.isSearchFocused = true), onBlur: () => (this.isSearchFocused = false), onKeyDown: this.onSearchKeydown.bind(this) }), h("button", { tabindex: "-1", class: "absolute left-0 flex h-60 w-60 items-center justify-center", onClick: () => this.onSearchClick() }, this.searchLoading && this.isSearchFocused ? (h("svg", { class: "top-nav-search-spinner w-14 h-14", viewBox: "0 0 18 18", fill: "none", xmlns: "http://www.w3.org/2000/svg", "data-testid": "search-spinner" }, h("path", { d: "M17 9C17 4.58172 13.4183 1 9 1C4.58172 1 1 4.58172 1 9C1 13.4183 4.58172 17 9 17", "stroke-width": "2", "stroke-linecap": "round" }))) : (h("i", { class: "mds-search text-2" })))))), this.tabs && this.tabs.length && (h("button", { ref: el => (this.menuButton = el), "aria-label": "Show navigation menu", class: 'hidden h-60 w-60 flex-shrink-0 items-center justify-center leading-none' +
        (this.isMenuOpen ? ' menu-open' : '') }, h("i", { class: "mds-list text-2" }))), this.hasAvatar && (h("div", { class: "hidden h-60 w-60 sm:flex flex-shrink-0", "data-testid": "avatar" }, h("slot", { name: "avatar" })))));
  }
  static get is() { return "mx-top-nav"; }
  static get properties() {
    return {
      "searchLoading": {
        "type": "boolean",
        "mutable": true,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Set to true to show the search animation"
        },
        "attribute": "search-loading",
        "reflect": true,
        "defaultValue": "false"
      },
      "searchForm": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The `form` attribute for the search input"
        },
        "attribute": "search-form",
        "reflect": false
      },
      "searchId": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The `id` attribute for the search input"
        },
        "attribute": "search-id",
        "reflect": false
      },
      "searchName": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The `name` attribute for the search input"
        },
        "attribute": "search-name",
        "reflect": false
      },
      "searchPlaceholder": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The placeholder text for the search"
        },
        "attribute": "search-placeholder",
        "reflect": false,
        "defaultValue": "'Search'"
      },
      "searchValue": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The value of the search input"
        },
        "attribute": "search-value",
        "reflect": false
      },
      "selectedTabIndex": {
        "type": "number",
        "mutable": false,
        "complexType": {
          "original": "number",
          "resolved": "number",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The index of the selected tab (if not setting an `href` for each tab)"
        },
        "attribute": "selected-tab-index",
        "reflect": false,
        "defaultValue": "null"
      },
      "showSearch": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Set to false to hide the search"
        },
        "attribute": "show-search",
        "reflect": false,
        "defaultValue": "true"
      },
      "tabs": {
        "type": "unknown",
        "mutable": false,
        "complexType": {
          "original": "IMxTabProps[]",
          "resolved": "IMxTabProps[]",
          "references": {
            "IMxTabProps": {
              "location": "import",
              "path": "../mx-tab/mx-tab",
              "id": "src/components/mx-tab/mx-tab.tsx::IMxTabProps"
            }
          }
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "An array of objects for each tab (see Tab Properties)"
        }
      }
    };
  }
  static get states() {
    return {
      "minWidths": {},
      "isSearchFocused": {},
      "extendSearch": {},
      "isMenuOpen": {}
    };
  }
  static get events() {
    return [{
        "method": "mxChange",
        "name": "mxChange",
        "bubbles": true,
        "cancelable": true,
        "composed": true,
        "docs": {
          "tags": [],
          "text": "Emits the newly selected tab's index as `Event.detail`"
        },
        "complexType": {
          "original": "number",
          "resolved": "number",
          "references": {}
        }
      }, {
        "method": "mxSearch",
        "name": "mxSearch",
        "bubbles": true,
        "cancelable": true,
        "composed": true,
        "docs": {
          "tags": [],
          "text": "Emits the search value when the Enter key is pressed inside the search input."
        },
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        }
      }];
  }
  static get elementRef() { return "element"; }
}
//# sourceMappingURL=mx-top-nav.js.map
