const SCREENS = {
  'sm': '640px',
  'md': '768px',
  'lg': '1024px',
  'xl': '1280px',
  '2xl': '1536px',
};
export class MinWidths {
  constructor() {
    this['sm'] = false;
    this['md'] = false;
    this['lg'] = false;
    this['xl'] = false;
    this['2xl'] = false;
  }
}
class MinWidthSync {
  constructor() {
    this.componentRefs = [];
    this.minWidths = new MinWidths();
    this.listeners = new Map();
  }
  subscribeComponent(componentRef) {
    if (this.componentRefs.length === 0)
      this.addListeners();
    this.componentRefs.push(componentRef);
    componentRef.minWidths = Object.assign({}, this.minWidths);
  }
  addListeners() {
    Object.keys(SCREENS).forEach(screen => {
      const mql = window.matchMedia(`(min-width: ${SCREENS[screen]})`);
      const listener = (e) => {
        this.minWidths[screen] = e.matches;
        this.componentRefs.forEach(componentRef => {
          componentRef.minWidths = Object.assign({}, this.minWidths);
        });
      };
      listener(mql);
      mql.addListener(listener);
      this.listeners.set(mql, listener);
    });
  }
  unsubscribeComponent(componentRef) {
    this.componentRefs = this.componentRefs.filter(c => c !== componentRef);
    if (this.componentRefs.length === 0)
      this.removeListeners();
  }
  removeListeners() {
    this.listeners.forEach((listener, mql) => {
      mql.removeListener(listener);
    });
  }
}
export const minWidthSync = new MinWidthSync();
//# sourceMappingURL=minWidthSync.js.map
