import { createPopper } from "@popperjs/core";
export async function createPopover(anchorEl, popoverEl, placement, offset) {
  if ('componentOnReady' in popoverEl)
    await popoverEl.componentOnReady();
  const instance = createPopper(anchorEl, popoverEl, {
    placement,
    modifiers: getModifiers(placement, offset),
    strategy: 'fixed',
  });
  return new Promise(resolve => {
    requestAnimationFrame(() => {
      instance.update();
      resolve(instance);
    });
  });
}
function getModifiers(placement, offset) {
  const modifiers = [{
      name: 'flip',
      options: {
        fallbackPlacements: [getOppositeVariationPlacement(placement), 'auto'],
        boundary: document.body,
      },
    }, {
      name: 'preventOverflow',
      options: {
        padding: { top: 32, bottom: 32 },
        boundary: document.body,
      },
    }];
  if (offset)
    modifiers.push({
      name: 'offset',
      options: {
        offset,
      },
    });
  return modifiers;
}
export function convertPlacementToOrigin(placement) {
  const origins = {
    'bottom-end': 'top right',
    'bottom-start': 'top left',
    'bottom': 'top',
    'left-end': 'bottom right',
    'left-start': 'top right',
    'left': 'right',
    'right-end': 'bottom left',
    'right-start': 'top left',
    'right': 'left',
    'top-end': 'bottom right',
    'top-start': 'bottom left',
    'top': 'bottom',
  };
  return origins[placement] || 'center';
}
function getOppositeVariationPlacement(placement) {
  return placement.replace(/start|end/g, matched => (matched === 'start' ? 'end' : 'start'));
}
//# sourceMappingURL=popover.js.map
