export function uuidv4() {
  return 'xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx'.replace(/[xy]/g, c => {
    const r = (Math.random() * 16) | 0;
    const v = c == 'x' ? r : (r & 0x3) | 0x8;
    return v.toString(16);
  });
}
export function queryPrefersReducedMotion() {
  const mediaQuery = window.matchMedia('(prefers-reduced-motion: reduce)');
  return !mediaQuery || mediaQuery.matches;
}
export function capitalize(str) {
  return str.charAt(0).toUpperCase() + str.slice(1);
}
export function isDateObject(val) {
  if (val == null)
    return false;
  if (typeof val !== 'object')
    return false;
  return 'getTime' in val && !isNaN(val.getTime());
}
export function parseTimeString(str) {
  if (str == null || str.trim() === '')
    return;
  const isExplicitAM = str.toLowerCase().includes('a');
  const isExplicitPM = str.toLowerCase().includes('p');
  const digits = str.replace(/[^0-9]/g, '');
  if (!digits.length || digits.length > 4)
    return null;
  let hours = digits.length <= 2 ? Number(digits) : Number(digits.slice(0, -2));
  const minutes = digits.length <= 2 ? 0 : Number(digits.slice(-2));
  if (hours === 12 && isExplicitAM)
    hours = 0;
  if (hours < 12 && isExplicitPM)
    hours += 12;
  if (hours > 23 || minutes > 59)
    return null;
  return { hours, minutes };
}
export function getCursorCoords(e) {
  if (e.changedTouches)
    return e.changedTouches[0];
  else if (e.touches)
    return e.touches[0];
  else
    return e;
}
export function getPageRect(el) {
  const { height, width } = el.getBoundingClientRect();
  let top = 0;
  let left = 0;
  do {
    top += el.offsetTop;
    left += el.offsetLeft;
    el = el.offsetParent;
  } while (el);
  return { top, left, width, height, bottom: top + height, right: left + width };
}
export function getBounds(container) {
  if (container === window) {
    return { top: 0, right: window.innerWidth, bottom: window.innerHeight, left: 0 };
  }
  return container.getBoundingClientRect();
}
export function isScrolledOutOfView(el) {
  const bounds = el.getBoundingClientRect();
  const scrollBounds = getBounds(getScrollingParent(el));
  if (bounds.top < scrollBounds.top)
    return true;
  if (bounds.bottom > scrollBounds.bottom)
    return true;
  if (bounds.left < scrollBounds.left)
    return true;
  if (bounds.left > scrollBounds.right)
    return true;
  return false;
}
export function getScrollingParent(el) {
  if (!(el instanceof HTMLElement))
    return window;
  if (isScrollable(el))
    return el;
  return getScrollingParent(el.parentNode);
}
function isScrollable(el) {
  const computedStyle = window.getComputedStyle(el);
  const overflowRegex = /(auto|scroll)/;
  const properties = ['overflow', 'overflowX', 'overflowY'];
  return properties.find(property => overflowRegex.test(computedStyle[property]));
}
export function propagateDataAttributes() {
  Array.from(this.element.attributes).forEach((attribute) => {
    if (!/^data-/.test(attribute.name))
      return;
    this.element.removeAttribute(attribute.name);
    this.dataAttributes[attribute.name] = attribute.value;
  });
}
//# sourceMappingURL=utils.js.map
