import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { d as defineCustomElement$4 } from './mx-checkbox2.js';
import { d as defineCustomElement$3 } from './mx-menu2.js';
import { d as defineCustomElement$2 } from './mx-menu-item2.js';

const MxAutocomplete$1 = proxyCustomElement(class MxAutocomplete extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.mxSelect = createEvent(this, "mxSelect", 7);
    this.mxClear = createEvent(this, "mxClear", 7);
    this.filterOptions = false;
    this.inputTag = 'mx-block-input';
    this.optionGroups = [];
    this.optionIcon = undefined;
    this.optionLabel = undefined;
    this.options = undefined;
    this.setValueOnSelect = false;
    this.assistiveText = undefined;
    this.autofocus = false;
    this.colspan = undefined;
    this.disabled = false;
    this.error = false;
    this.inputId = undefined;
    this.label = 'Search';
    this.maxlength = undefined;
    this.name = undefined;
    this.placeholder = undefined;
    this.readonly = false;
    this.type = 'search';
    this.value = undefined;
    this.isFocused = false;
  }
  async componentDidLoad() {
    await new Promise(requestAnimationFrame);
    this.menuEl.anchorEl = this.inputEl;
  }
  get filterFunction() {
    if (typeof this.filterOptions === 'function')
      return this.filterOptions;
    return this.defaultFilter;
  }
  get visibleOptions() {
    if (!this.options)
      return [];
    if (!this.filterOptions)
      return this.options;
    const filtered = [];
    this.options.forEach(option => {
      var _a;
      if (Array.isArray(option))
        filtered.push(option.filter(o => { var _a; return this.filterFunction(((_a = this.value) === null || _a === void 0 ? void 0 : _a.trim()) || '', o); }));
      if (this.filterFunction(((_a = this.value) === null || _a === void 0 ? void 0 : _a.trim()) || '', option))
        filtered.push(option);
    });
    return filtered;
  }
  get showNoResults() {
    var _a;
    return ((_a = this.value) === null || _a === void 0 ? void 0 : _a.trim()) && this.visibleOptions.length === 0;
  }
  async onSelect(option) {
    this.mxSelect.emit(option);
    this.menuEl.addEventListener('mxClose', async () => {
      await new Promise(requestAnimationFrame);
      await new Promise(requestAnimationFrame);
      this.inputEl.value = this.setValueOnSelect ? this.getOptionLabel(option) : '';
      this.inputEl.dispatchEvent(new window.Event('input', { cancelable: true, bubbles: true }));
      this.inputEl.querySelector('input').focus();
    }, { once: true });
  }
  defaultFilter(value, option) {
    const optionLabel = this.getOptionLabel(option);
    if (!optionLabel)
      return false;
    if (!(value === null || value === void 0 ? void 0 : value.trim()))
      return true;
    return optionLabel.toLowerCase().includes(value.trim().toLowerCase());
  }
  renderOption(option, index) {
    if (!option)
      return;
    if (!Array.isArray(option))
      return this.renderOptionItem(option);
    if (option.length)
      return this.renderOptionGroup(option, index);
  }
  renderOptionItem(option) {
    return (h("mx-menu-item", { icon: this.getOptionIcon(option), onClick: () => this.onSelect(option) }, this.getOptionLabel(option)));
  }
  renderOptionGroup(option, index) {
    return (h("div", { role: "group" }, this.optionGroups[index] && (h("p", { role: "heading", "aria-level": "2" }, this.optionGroups[index])), option.map(o => this.renderOption(o))));
  }
  getOptionLabel(option) {
    if (typeof this.optionLabel === 'function')
      return this.optionLabel(option);
    if (typeof option === 'object' && typeof this.optionLabel === 'string')
      return option[this.optionLabel];
    return option === null || option === void 0 ? void 0 : option.toString();
  }
  getOptionIcon(option) {
    if (!this.optionIcon)
      return;
    if (typeof this.optionIcon === 'string')
      return this.optionIcon;
    if (typeof this.optionIcon === 'function')
      return this.optionIcon(option);
  }
  render() {
    const Tag = this.inputTag;
    return (h(Host, { class: "mx-block-search contents" }, h(Tag, { ref: el => (this.inputEl = el), type: this.type, assistiveText: this.assistiveText, autofocus: this.autofocus, colspan: this.colspan, disabled: this.disabled, error: this.error, inputId: this.inputId, maxlength: this.maxlength, label: this.label, name: this.name, placeholder: this.placeholder, readonly: this.readonly, value: this.value, onInput: (e) => (this.value = e.target.value), onMxClear: this.mxClear.emit.bind(this) }, h("slot", { name: "label", slot: "label" })), h("mx-menu", { offset: [0, 10], ref: el => (this.menuEl = el), squared: true, autocompleteOnly: true }, this.showNoResults && (h("mx-menu-item", { disabled: true }, h("span", { class: "text-primary", "data-test": "no-results" }, "No matching results"))), this.visibleOptions.map(this.renderOption.bind(this)))));
  }
  get element() { return this; }
}, [4, "mx-autocomplete", {
    "filterOptions": [4, "filter-options"],
    "inputTag": [1025, "input-tag"],
    "optionGroups": [16],
    "optionIcon": [1, "option-icon"],
    "optionLabel": [1, "option-label"],
    "options": [16],
    "setValueOnSelect": [4, "set-value-on-select"],
    "assistiveText": [1, "assistive-text"],
    "autofocus": [4],
    "colspan": [2],
    "disabled": [4],
    "error": [1540],
    "inputId": [1, "input-id"],
    "label": [1],
    "maxlength": [2],
    "name": [1],
    "placeholder": [1],
    "readonly": [4],
    "type": [1],
    "value": [1025],
    "isFocused": [32]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["mx-autocomplete", "mx-checkbox", "mx-menu", "mx-menu-item"];
  components.forEach(tagName => { switch (tagName) {
    case "mx-autocomplete":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, MxAutocomplete$1);
      }
      break;
    case "mx-checkbox":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "mx-menu":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "mx-menu-item":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const MxAutocomplete = MxAutocomplete$1;
const defineCustomElement = defineCustomElement$1;

export { MxAutocomplete, defineCustomElement };

//# sourceMappingURL=mx-autocomplete.js.map