import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';

const MxAvatar = proxyCustomElement(class MxAvatar extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.icon = '';
    this.imageUrl = '';
    this.fullName = '';
  }
  get avatarType() {
    if (this.imageUrl.trim())
      return 'image';
    if (this.icon.trim())
      return 'icon';
    if (this.fullName.trim())
      return 'monogram';
  }
  get initials() {
    if (this.avatarType !== 'monogram')
      return '';
    const names = this.fullName.trim().split(' ');
    if (names.length === 1)
      return names[0].charAt(0);
    return names[0].charAt(0) + names[names.length - 1].charAt(0);
  }
  connectedCallback() {
    if (!this.avatarType)
      console.error('mx-avatar requires either an image, icon, or full name.');
    if (this.fullName && !this.element.getAttribute('aria-label'))
      this.element.setAttribute('aria-label', this.fullName);
  }
  render() {
    return (h(Host, { class: 'mx-avatar avatar-' + this.avatarType }, this.avatarType == 'image' && h("img", { src: this.imageUrl.trim(), alt: "", class: "w-full h-full object-cover" }), this.avatarType == 'icon' && h("i", { class: this.icon.trim(), role: "presentation" }), this.avatarType == 'monogram' && h("div", { class: "truncate uppercase" }, this.initials)));
  }
  get element() { return this; }
}, [0, "mx-avatar", {
    "icon": [1],
    "imageUrl": [1, "image-url"],
    "fullName": [1, "full-name"]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["mx-avatar"];
  components.forEach(tagName => { switch (tagName) {
    case "mx-avatar":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, MxAvatar);
      }
      break;
  } });
}

export { MxAvatar as M, defineCustomElement as d };

//# sourceMappingURL=mx-avatar2.js.map