import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';

const MxBadge = proxyCustomElement(class MxBadge extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.isStandalone = true;
    this.value = undefined;
    this.squared = false;
    this.indicator = undefined;
    this.badgeClass = undefined;
    this.icon = undefined;
    this.offset = 0;
    this.bottom = false;
    this.left = false;
  }
  componentWillLoad() {
    this.isStandalone = !this.element.firstElementChild;
  }
  get isIconOnly() {
    return this.icon && this.value === undefined;
  }
  get indicatorIcon() {
    if ([false, undefined].includes(this.indicator))
      return null;
    if (this.indicator.length)
      return this.indicator;
    return 'circle';
  }
  get badgeClassNames() {
    let str = 'badge inline-flex items-center justify-center text-4 font-semibold pointer-events-none';
    if (this.isIconOnly) {
      str += ' rounded-full';
    }
    else if (this.squared) {
      str += ' rounded';
    }
    else {
      str += ' rounded-xl';
    }
    if (this.indicator != null) {
      str += ' w-12 h-12';
    }
    else if (this.isStandalone) {
      str += ' h-24';
      str += this.isIconOnly ? ' w-24' : ' px-8';
    }
    else {
      str += ' h-20';
      str += this.isIconOnly ? ' w-20' : ' px-6';
    }
    if (!this.isStandalone) {
      str += ' absolute transform';
      if (this.bottom) {
        str += ` bottom-${this.offset} translate-y-1/2`;
        str += this.left ? ' origin-bottom-left' : ' origin-bottom-right';
      }
      else {
        str += ` top-${this.offset} -translate-y-1/2`;
        str += this.left ? ' origin-top-left' : ' origin-top-right';
      }
      str += this.left ? ` left-${this.offset} -translate-x-1/2` : ` right-${this.offset} translate-x-1/2`;
    }
    return [str, this.badgeClass].join(' ');
  }
  render() {
    return (h(Host, { class: "mx-badge inline-flex relative" }, h("slot", null), this.indicatorIcon ? (h("span", { class: this.badgeClassNames, "data-testid": 'indicator-' + this.indicatorIcon }, h("i", { class: 'mds-badge-' + this.indicatorIcon }))) : (h("span", { class: this.badgeClassNames }, this.icon && h("i", { class: this.icon + (this.isIconOnly ? '' : ' mr-4') }), this.value))));
  }
  get element() { return this; }
}, [4, "mx-badge", {
    "value": [8],
    "squared": [4],
    "indicator": [8],
    "badgeClass": [1, "badge-class"],
    "icon": [1],
    "offset": [2],
    "bottom": [4],
    "left": [4]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["mx-badge"];
  components.forEach(tagName => { switch (tagName) {
    case "mx-badge":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, MxBadge);
      }
      break;
  } });
}

export { MxBadge as M, defineCustomElement as d };

//# sourceMappingURL=mx-badge2.js.map