import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { s as slideIn, b as slideOut, D as Direction } from './transitions.js';
import { m as moveToPortal } from './portal.js';
import { d as defineCustomElement$2 } from './mx-avatar2.js';

const bannerQueue = [];
const MxBanner$1 = proxyCustomElement(class MxBanner extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.mxClose = createEvent(this, "mxClose", 7);
    this.hasActions = false;
    this.isOpen = false;
    this.type = 'default';
    this.isVisible = false;
  }
  async toggleBanner() {
    if (this.isOpen) {
      try {
        if (this.queueItem && bannerQueue.includes(this.queueItem))
          return;
        await this.waitForOtherBanners();
        moveToPortal(this.element);
        this.isVisible = true;
        slideIn(this.element, 400, Direction.top, 'var(--mds-animation-ease-bounce)');
      }
      catch (err) {
      }
    }
    else {
      this.removeFromQueue();
      this.isVisible = false;
      this.mxClose.emit();
    }
  }
  componentWillLoad() {
    this.hasActions = !!this.element.querySelector('[slot="actions"]');
  }
  connectedCallback() {
    this.toggleBanner();
  }
  waitForOtherBanners() {
    return new Promise((resolve, reject) => {
      this.queueItem = { resolve, reject };
      bannerQueue.push(this.queueItem);
      if (bannerQueue.length === 1)
        return resolve();
    });
  }
  removeFromQueue() {
    if (!this.queueItem)
      return;
    const queueIndex = bannerQueue.indexOf(this.queueItem);
    bannerQueue.splice(bannerQueue.indexOf(this.queueItem), 1);
    if (queueIndex === 0 && bannerQueue.length > 0)
      bannerQueue[0].resolve();
  }
  async close() {
    if (!this.isOpen)
      return;
    await slideOut(this.element, 400, Direction.top, 'var(--mds-animation-ease-bounce)');
    this.isOpen = false;
  }
  onAlertClick() {
    if (this.hasActions)
      return;
    this.close();
  }
  get hostClass() {
    let str = 'flex fixed left-0 top-0 px-12 w-full justify-center pointer-events-none z-50';
    if (!this.isVisible)
      str += ' hidden';
    if (this.type !== 'default')
      str += ' ' + this.type;
    return str;
  }
  get alertClass() {
    let str = 'mx-banner-alert mt-30 flex items-center rounded sm:rounded-full shadow-drop sm:h-60 py-16 sm:py-0 pl-12 pr-12 sm:pr-20 pointer-events-auto';
    if (!this.hasActions)
      str += ' cursor-pointer';
    return str;
  }
  get avatarIcon() {
    if (this.type === 'warning')
      return 'mds-warning';
    return 'mds-hand-waving';
  }
  render() {
    return (h(Host, { class: this.hostClass }, h("div", { role: "alert", class: this.alertClass, onClick: this.onAlertClick.bind(this) }, h("div", { class: "flex-shrink-0 self-start sm:self-auto", "data-testid": "avatar" }, h("slot", { name: "avatar" }, h("mx-avatar", { icon: this.avatarIcon }))), h("div", { class: "flex-1 flex flex-col sm:flex-row sm:items-center pl-16 sm:pl-20" }, h("p", { class: "flex-1 my-0 leading-none text-4 break-anywhere font-bold pr-16", "data-testid": "message" }, h("slot", null)), h("div", { class: "flex-shrink-0 -ml-8 sm:ml-0 -mb-8 sm:mb-0", "data-testid": "actions", onClick: this.close.bind(this) }, h("slot", { name: "actions" }))), h("button", { type: "button", class: "flex w-30 h-30 items-center justify-center", "data-testid": "close-button", onClick: this.close.bind(this) }, h("i", { class: "mds-x" })))));
  }
  get element() { return this; }
  static get watchers() { return {
    "isOpen": ["toggleBanner"]
  }; }
}, [4, "mx-banner", {
    "isOpen": [1540, "is-open"],
    "type": [1],
    "isVisible": [32]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["mx-banner", "mx-avatar"];
  components.forEach(tagName => { switch (tagName) {
    case "mx-banner":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, MxBanner$1);
      }
      break;
    case "mx-avatar":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const MxBanner = MxBanner$1;
const defineCustomElement = defineCustomElement$1;

export { MxBanner, defineCustomElement };

//# sourceMappingURL=mx-banner.js.map