import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { u as uuidv4 } from './utils.js';
import { d as defineCustomElement$2 } from './mx-button2.js';

const MxBlockFileInput$1 = proxyCustomElement(class MxBlockFileInput extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.mxThumbnailChange = createEvent(this, "mxThumbnailChange", 7);
    this.uuid = uuidv4();
    this.accept = undefined;
    this.acceptImage = false;
    this.acceptPdf = false;
    this.assistiveText = undefined;
    this.chooseBtnType = 'contained';
    this.chooseFileText = 'Choose File';
    this.colspan = undefined;
    this.disabled = false;
    this.error = false;
    this.filename = undefined;
    this.inputId = undefined;
    this.label = undefined;
    this.name = undefined;
    this.placeholder = 'No file chosen';
    this.readonly = false;
    this.thumbnailSize = 'cover';
    this.thumbnailUrl = undefined;
    this.thumbnailDataUri = undefined;
  }
  onThumbnailUrlChange() {
    this.mxThumbnailChange.emit(this.thumbnailUrl);
  }
  connectedCallback() {
    this.onThumbnailUrlChange();
  }
  async removeFile() {
    if (this.disabled || this.readonly)
      return;
    if (!this.isFileSelected)
      return;
    this.filename = null;
    this.thumbnailUrl = null;
    this.fileInput.value = '';
    this.fileInput.dispatchEvent(new window.Event('change', { bubbles: true, cancelable: true }));
    this.fileInput.dispatchEvent(new window.Event('input', { bubbles: true, cancelable: true }));
  }
  async selectFile() {
    if (this.disabled || this.readonly)
      return;
    this.fileInput.click();
  }
  onFocus() {
    this.error = false;
  }
  onInput(e) {
    this.error = false;
    if (this.fileInput.value) {
      this.filename = e.target.files[0].name;
      this.setThumnailDataUri(e.target.files[0]);
    }
    else {
      this.filename = null;
      this.thumbnailUrl = null;
      this.thumbnailDataUri = null;
    }
  }
  setThumnailDataUri(file) {
    this.thumbnailDataUri = null;
    if (!/\.(jpe?g|png|gif)$/i.test(file.name))
      return;
    const reader = new FileReader();
    reader.onload = () => {
      this.thumbnailDataUri = reader.result;
      this.mxThumbnailChange.emit(this.thumbnailDataUri);
    };
    reader.readAsDataURL(file);
  }
  getElementId(suffix = '') {
    if (suffix)
      suffix = '-' + suffix;
    return (this.inputId || this.uuid) + suffix;
  }
  get isFileSelected() {
    if (this.filename || this.thumbnailUrl)
      return true;
    if (this.fileInput && this.fileInput.value)
      return true;
    return false;
  }
  get acceptString() {
    const accepts = [];
    if (this.acceptImage)
      accepts.push('image/*');
    if (this.acceptPdf)
      accepts.push('.pdf');
    if (this.accept)
      accepts.push(this.accept);
    return accepts.join(',') || null;
  }
  get thumbnailBackgroundImage() {
    let url = this.thumbnailUrl;
    if (this.fileInput && this.fileInput.value)
      url = this.thumbnailDataUri;
    if (!url)
      return null;
    return `url(${url})`;
  }
  get thumbnailBackgroundSize() {
    if (!['contain', 'cover', 'auto', 'stretch'].includes(this.thumbnailSize))
      return 'cover';
    if (this.thumbnailSize === 'stretch')
      return '100% 100%';
    return this.thumbnailSize;
  }
  get hostClass() {
    let str = 'mx-block-input mx-block-file-input';
    if (this.colspan > 0 && this.colspan < 7) {
      str += ' col-span-' + this.colspan;
    }
    return str;
  }
  get containerClass() {
    let str = 'mx-block-input-container';
    if (this.disabled || this.readonly)
      str += ' disabled';
    if (this.error)
      str += ' error';
    return str;
  }
  render() {
    const removeButton = !this.disabled && !this.readonly && this.isFileSelected && (h("button", { type: "button", class: "clear-button flex items-center justify-center w-20 text-1", onClick: this.removeFile.bind(this), "aria-label": "Remove file", title: "Remove file", "data-testid": "remove-file-button" }, h("i", { class: "mds-x" })));
    return (h(Host, { class: this.hostClass }, h("div", { class: this.containerClass }, h("input", { ref: el => (this.fileInput = el), class: "absolute pointer-events-none opacity-0", id: this.getElementId(), name: this.name, "aria-describedby": [this.getElementId('assistive'), this.getElementId('filename')].join(' '), type: "file", accept: this.acceptString, disabled: this.disabled, readonly: this.readonly, tabindex: "-1", onInput: this.onInput.bind(this) }), this.isFileSelected && this.thumbnailBackgroundImage && (h("div", { "data-testid": "thumbnail", class: "thumbnail w-80 h-80 bg-center bg-no-repeat flex-shrink-0", style: { backgroundImage: this.thumbnailBackgroundImage, backgroundSize: this.thumbnailBackgroundSize } })), h("div", { class: "mx-block-input-grid" }, h("label", { class: "text-small", htmlFor: this.getElementId(), onClick: e => e.preventDefault() }, this.label, h("slot", { name: "label" }), this.assistiveText && h("span", { id: this.getElementId('assistive') }, this.assistiveText)), h("span", { id: this.getElementId('filename'), class: "input-value truncate", "aria-live": "polite", title: this.filename, "data-testid": "filename" }, !this.isFileSelected && h("span", { class: "opacity-60" }, this.placeholder), this.filename), removeButton, h("mx-button", { "btn-type": this.chooseBtnType, hug: true, small: true, disabled: this.disabled || this.readonly, onClick: this.selectFile.bind(this), "data-testid": "choose-file-button" }, this.chooseFileText)))));
  }
  get element() { return this; }
  static get watchers() { return {
    "thumbnailUrl": ["onThumbnailUrlChange"]
  }; }
}, [4, "mx-block-file-input", {
    "accept": [1537],
    "acceptImage": [4, "accept-image"],
    "acceptPdf": [4, "accept-pdf"],
    "assistiveText": [1, "assistive-text"],
    "chooseBtnType": [1, "choose-btn-type"],
    "chooseFileText": [1, "choose-file-text"],
    "colspan": [2],
    "disabled": [4],
    "error": [1540],
    "filename": [1537],
    "inputId": [1, "input-id"],
    "label": [1],
    "name": [1],
    "placeholder": [1],
    "readonly": [4],
    "thumbnailSize": [1, "thumbnail-size"],
    "thumbnailUrl": [1537, "thumbnail-url"],
    "thumbnailDataUri": [32],
    "removeFile": [64],
    "selectFile": [64]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["mx-block-file-input", "mx-button"];
  components.forEach(tagName => { switch (tagName) {
    case "mx-block-file-input":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, MxBlockFileInput$1);
      }
      break;
    case "mx-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const MxBlockFileInput = MxBlockFileInput$1;
const defineCustomElement = defineCustomElement$1;

export { MxBlockFileInput, defineCustomElement };

//# sourceMappingURL=mx-block-file-input.js.map