import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { u as uuidv4, p as propagateDataAttributes } from './utils.js';

const MxBlockInput = proxyCustomElement(class MxBlockInput extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.mxClear = createEvent(this, "mxClear", 7);
    this.dataAttributes = {};
    this.uuid = uuidv4();
    this.componentWillRender = propagateDataAttributes;
    this.assistiveText = undefined;
    this.autofocus = false;
    this.colspan = undefined;
    this.disabled = false;
    this.error = false;
    this.inputId = undefined;
    this.label = undefined;
    this.maxlength = undefined;
    this.name = undefined;
    this.placeholder = undefined;
    this.readonly = false;
    this.type = 'text';
    this.value = undefined;
    this.isFocused = false;
    this.characterCount = 0;
  }
  componentDidLoad() {
    this.updateValue();
  }
  onValueChange() {
    this.updateValue();
  }
  updateValue() {
    this.textInput.value = this.hasValue ? this.value : '';
  }
  onFocus() {
    this.isFocused = true;
    this.error = false;
  }
  onBlur() {
    this.isFocused = false;
  }
  onContainerClick(e) {
    if (this.disabled || this.readonly)
      return;
    const slottedButton = this.element.querySelector('[slot="button"]');
    if (slottedButton && slottedButton.contains(e.target))
      return;
    this.textInput.focus();
  }
  onClearClick() {
    this.value = '';
    this.textInput.dispatchEvent(new window.Event('input', { bubbles: true }));
    this.mxClear.emit();
    if (typeof jest === 'undefined')
      this.textInput.focus();
  }
  onInput(e) {
    this.characterCount = e.target.value.length;
    this.value = e.target.value;
  }
  get hasValue() {
    return this.value !== null && this.value !== '' && this.value !== undefined;
  }
  get hostClass() {
    let str = 'mx-block-input';
    if (this.colspan > 0 && this.colspan < 7) {
      str += ' md:col-span-' + this.colspan;
    }
    return str;
  }
  get containerClass() {
    let str = 'mx-block-input-container';
    if (this.disabled)
      str += ' disabled';
    if (this.error)
      str += ' error';
    return str;
  }
  render() {
    const clearButton = !this.disabled && !this.readonly && this.value && (h("button", { type: "button", class: "clear-button flex items-center justify-center w-20 text-2", onClick: this.onClearClick.bind(this), "aria-label": `Clear ${this.label}`, title: `Clear ${this.label}`, "data-testid": "clear-button" }, h("i", { class: "mds-cross transform rotate-45" })));
    return (h(Host, { class: this.hostClass }, h("div", { class: this.containerClass, onClick: this.onContainerClick.bind(this) }, h("div", { class: "mx-block-input-grid" }, h("label", { class: "text-small", htmlFor: this.inputId || this.uuid }, this.label, h("slot", { name: "label" }), this.assistiveText && h("span", { id: this.inputId || this.uuid + '-assistive' }, this.assistiveText)), h("input", Object.assign({ "aria-describedby": this.assistiveText ? (this.inputId || this.uuid) + '-assistive' : null, autofocus: this.autofocus, disabled: this.disabled, id: this.inputId || this.uuid, maxlength: this.maxlength, name: this.name, onBlur: this.onBlur.bind(this), onFocus: this.onFocus.bind(this), onInput: this.onInput.bind(this), placeholder: this.placeholder, readonly: this.readonly, ref: el => (this.textInput = el), type: this.type, value: this.value }, this.dataAttributes)), clearButton, h("slot", { name: "button" })))));
  }
  get element() { return this; }
  static get watchers() { return {
    "value": ["onValueChange"]
  }; }
}, [4, "mx-block-input", {
    "assistiveText": [1, "assistive-text"],
    "autofocus": [4],
    "colspan": [2],
    "disabled": [4],
    "error": [1540],
    "inputId": [1, "input-id"],
    "label": [1],
    "maxlength": [2],
    "name": [1],
    "placeholder": [1],
    "readonly": [4],
    "type": [1],
    "value": [1025],
    "isFocused": [32],
    "characterCount": [32]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["mx-block-input"];
  components.forEach(tagName => { switch (tagName) {
    case "mx-block-input":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, MxBlockInput);
      }
      break;
  } });
}

export { MxBlockInput as M, defineCustomElement as d };

//# sourceMappingURL=mx-block-input2.js.map