import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { u as uuidv4, p as propagateDataAttributes } from './utils.js';

const MxBlockTextarea$1 = proxyCustomElement(class MxBlockTextarea extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.dataAttributes = {};
    this.uuid = uuidv4();
    this.componentWillRender = propagateDataAttributes;
    this.assistiveText = undefined;
    this.autofocus = false;
    this.disabled = false;
    this.error = false;
    this.textareaId = undefined;
    this.label = undefined;
    this.maxlength = undefined;
    this.name = undefined;
    this.placeholder = undefined;
    this.readonly = false;
    this.value = undefined;
    this.isFocused = false;
    this.characterCount = 0;
  }
  componentDidLoad() {
    this.updateValue();
  }
  onValueChange() {
    this.updateValue();
  }
  updateValue() {
    this.textarea.value = this.hasValue ? this.value : '';
  }
  onFocus() {
    this.isFocused = true;
    this.error = false;
  }
  onBlur() {
    this.isFocused = false;
  }
  onInput(e) {
    this.characterCount = e.target.value.length;
    this.value = e.target.value;
  }
  get hasValue() {
    return this.value !== null && this.value !== '' && this.value !== undefined;
  }
  get containerClass() {
    let str = 'mx-block-input-container';
    if (this.disabled)
      str += ' disabled';
    if (this.error)
      str += ' error';
    return str;
  }
  render() {
    return (h(Host, { class: "mx-block-textarea mx-block-input col-span-full" }, h("div", { class: this.containerClass }, h("label", { class: "text-small", htmlFor: this.textareaId || this.uuid }, this.label, h("slot", { name: "label" }), this.assistiveText && h("span", { id: this.textareaId || this.uuid + '-assistive' }, this.assistiveText)), h("textarea", Object.assign({ "aria-describedby": this.assistiveText ? (this.textareaId || this.uuid) + '-assistive' : null, autofocus: this.autofocus, disabled: this.disabled, id: this.textareaId || this.uuid, maxlength: this.maxlength, name: this.name, onBlur: this.onBlur.bind(this), onFocus: this.onFocus.bind(this), onInput: this.onInput.bind(this), placeholder: this.placeholder, readonly: this.readonly, ref: el => (this.textarea = el), value: this.value }, this.dataAttributes)))));
  }
  get element() { return this; }
  static get watchers() { return {
    "value": ["onValueChange"]
  }; }
}, [4, "mx-block-textarea", {
    "assistiveText": [1, "assistive-text"],
    "autofocus": [4],
    "disabled": [4],
    "error": [1540],
    "textareaId": [1, "textarea-id"],
    "label": [1],
    "maxlength": [2],
    "name": [1],
    "placeholder": [1],
    "readonly": [4],
    "value": [1025],
    "isFocused": [32],
    "characterCount": [32]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["mx-block-textarea"];
  components.forEach(tagName => { switch (tagName) {
    case "mx-block-textarea":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, MxBlockTextarea$1);
      }
      break;
  } });
}

const MxBlockTextarea = MxBlockTextarea$1;
const defineCustomElement = defineCustomElement$1;

export { MxBlockTextarea, defineCustomElement };

//# sourceMappingURL=mx-block-textarea.js.map