import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { p as propagateDataAttributes } from './utils.js';

const MxCheckbox = proxyCustomElement(class MxCheckbox extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.dataAttributes = {};
    this.componentWillRender = propagateDataAttributes;
    this.name = '';
    this.value = '';
    this.labelLeft = false;
    this.labelName = '';
    this.labelClass = '';
    this.hideLabel = false;
    this.checked = false;
    this.userchecked = false;
    this.disabled = false;
    this.indeterminate = false;
    this.elAriaLabel = undefined;
  }
  get checkClass() {
    let str = 'flex h-18 w-18 flex-shrink-0';
    str += this.labelLeft ? ' order-2' : ' order-1';
    if (this.labelLeft && !this.hideLabel)
      str += ' ml-16';
    if (this.userchecked)
      str += ' userchecked';
    return str;
  }
  get checkLabelClass() {
    let str = 'checkbox-label inline-block';
    if (this.hideLabel)
      str += ' sr-only';
    str += this.labelLeft ? ' order-1 flex-1' : ' order-2';
    if (!this.labelLeft && !this.hideLabel)
      str += ' ml-16';
    return str;
  }
  onInput(e) {
    this.checked = this.userchecked = e.target.checked;
  }
  render() {
    return (h(Host, { class: "mx-checkbox inline-flex items-center" }, h("label", { class: [
        'relative flex-1 inline-flex flex-nowrap align-center items-center text-4' +
          (this.disabled ? '' : ' cursor-pointer'),
        this.labelClass,
      ].join(' ') }, h("input", Object.assign({ class: 'absolute h-0 w-0 opacity-0' + (this.indeterminate ? ' indeterminate' : ''), type: "checkbox", "aria-label": this.elAriaLabel, name: this.name, value: this.value, checked: this.checked, disabled: this.disabled, indeterminate: this.indeterminate }, this.dataAttributes, { onInput: this.onInput.bind(this) })), h("span", { class: this.checkClass }), h("div", { class: this.checkLabelClass, "data-testid": "labelName" }, this.labelName))));
  }
  get element() { return this; }
}, [0, "mx-checkbox", {
    "name": [1],
    "value": [1],
    "labelLeft": [4, "label-left"],
    "labelName": [1, "label-name"],
    "labelClass": [1, "label-class"],
    "hideLabel": [4, "hide-label"],
    "checked": [1028],
    "userchecked": [1028],
    "disabled": [4],
    "indeterminate": [4],
    "elAriaLabel": [1, "el-aria-label"]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["mx-checkbox"];
  components.forEach(tagName => { switch (tagName) {
    case "mx-checkbox":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, MxCheckbox);
      }
      break;
  } });
}

export { MxCheckbox as M, defineCustomElement as d };

//# sourceMappingURL=mx-checkbox2.js.map