import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';

const MxChipGroup$1 = proxyCustomElement(class MxChipGroup extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.mxInput = createEvent(this, "mxInput", 7);
    this.value = undefined;
  }
  onValueChange() {
    this.updateChildChips();
  }
  connectedCallback() {
    this.updateChildChips();
  }
  onChipClick(e) {
    const chip = e.target.closest('mx-chip');
    if (!chip || chip.disabled)
      return;
    this.toggleValue(chip.value);
    this.mxInput.emit(this.value);
  }
  toggleValue(value) {
    if (this.value !== value)
      this.value = value;
    else
      this.value = null;
  }
  updateChildChips() {
    const chips = this.element.querySelectorAll('mx-chip');
    chips.forEach(chip => {
      chip.choice = true;
      chip.clickable = true;
      chip.selected = chip.value === this.value;
    });
  }
  render() {
    return (h(Host, { class: "inline-flex", role: "radiogroup" }, h("slot", null)));
  }
  get element() { return this; }
  static get watchers() { return {
    "value": ["onValueChange"]
  }; }
}, [4, "mx-chip-group", {
    "value": [1032]
  }, [[0, "click", "onChipClick"]]]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["mx-chip-group"];
  components.forEach(tagName => { switch (tagName) {
    case "mx-chip-group":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, MxChipGroup$1);
      }
      break;
  } });
}

const MxChipGroup = MxChipGroup$1;
const defineCustomElement = defineCustomElement$1;

export { MxChipGroup, defineCustomElement };

//# sourceMappingURL=mx-chip-group.js.map