import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { d as defineCustomElement$2 } from './mx-input2.js';

const MxConfirmInput$1 = proxyCustomElement(class MxConfirmInput extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.isEmittingEventAfterConfirm = false;
    this.name = undefined;
    this.inputId = undefined;
    this.label = undefined;
    this.placeholder = undefined;
    this.value = undefined;
    this.type = 'text';
    this.autofocus = false;
    this.dense = false;
    this.disabled = false;
    this.readonly = false;
    this.maxlength = undefined;
    this.leftIcon = undefined;
    this.rightIcon = undefined;
    this.suffix = undefined;
    this.outerContainerClass = '';
    this.labelClass = '';
    this.error = false;
    this.assistiveText = undefined;
    this.floatLabel = false;
    this.textarea = false;
    this.textareaHeight = '250px';
    this.elAriaLabel = undefined;
    this.hideCharacterCount = false;
    this.step = undefined;
    this.clearErrorOnFocus = true;
    this.isFocused = false;
    this.isHovered = false;
  }
  onValueChange() {
    this.previousValue = this.value;
    this.mxInput.value = this.value;
  }
  connectedCallback() {
    this.previousValue = this.value;
  }
  get rightIcons() {
    if (this.isFocused) {
      return [
        { icon: 'mds-x', ariaLabel: 'Cancel', onClick: this.onCancel.bind(this) },
        { icon: 'mds-check', ariaLabel: 'Okay', onClick: this.onConfirm.bind(this) },
      ];
    }
    const canEdit = this.value != null && this.value !== '' && !this.readonly && !this.disabled;
    const canHover = window.matchMedia('(hover: hover)');
    if ((this.isHovered || !canHover.matches) && canEdit)
      return 'mds-edit';
  }
  onCancel(e) {
    if (e)
      e.stopPropagation();
    if (!this.mxInput)
      return;
    this.mxInput.value = this.previousValue;
    if (document.activeElement && this.mxInput.contains(document.activeElement))
      document.activeElement.blur();
  }
  onConfirm(e) {
    if (e)
      e.stopPropagation();
    this.value = this.mxInput.value;
    if (this.mxInput) {
      const input = this.mxInput.querySelector('input');
      this.isEmittingEventAfterConfirm = true;
      input && input.dispatchEvent(new Event('input', { bubbles: true, cancelable: true }));
    }
    if (document.activeElement)
      document.activeElement.blur();
  }
  onFocusin() {
    this.isFocused = true;
    if (this.clearErrorOnFocus) {
      this.error = false;
    }
  }
  async onFocusout() {
    await new Promise(requestAnimationFrame);
    if (document.activeElement && this.mxInput.contains(document.activeElement))
      return;
    this.isFocused = false;
    this.onCancel();
  }
  onMouseEnter() {
    this.isHovered = true;
  }
  onMouseLeave() {
    this.isHovered = false;
  }
  onInput(e) {
    if (!this.isEmittingEventAfterConfirm) {
      e.stopPropagation();
    }
    else {
      this.isEmittingEventAfterConfirm = false;
    }
  }
  onKeyDown(e) {
    if (e.key === 'Escape')
      this.onCancel();
    if (e.target.closest('button'))
      return;
    if (e.key === 'Enter')
      this.onConfirm();
  }
  render() {
    return (h(Host, { class: 'mx-confirm-input block' + (this.value != null && this.value !== '' ? ' has-value' : '') }, h("mx-input", { ref: el => (this.mxInput = el), name: this.name, inputId: this.inputId, label: this.label, placeholder: this.placeholder, value: this.value, type: this.type, autofocus: this.autofocus, dense: this.dense, disabled: this.disabled, readonly: this.readonly, maxlength: this.maxlength, leftIcon: this.leftIcon, suffix: this.suffix, outerContainerClass: this.outerContainerClass, labelClass: this.labelClass, error: this.error, assistiveText: this.assistiveText, floatLabel: this.floatLabel, rightIcon: this.rightIcons, elAriaLabel: this.elAriaLabel, hideCharacterCount: this.hideCharacterCount, onFocusin: this.onFocusin.bind(this), onFocusout: this.onFocusout.bind(this), onInput: this.onInput.bind(this), onKeyDown: this.onKeyDown.bind(this), onMouseEnter: this.onMouseEnter.bind(this), onMouseLeave: this.onMouseLeave.bind(this) })));
  }
  static get watchers() { return {
    "value": ["onValueChange"]
  }; }
}, [0, "mx-confirm-input", {
    "name": [1],
    "inputId": [1, "input-id"],
    "label": [1],
    "placeholder": [1],
    "value": [1025],
    "type": [1],
    "autofocus": [4],
    "dense": [4],
    "disabled": [4],
    "readonly": [4],
    "maxlength": [2],
    "leftIcon": [1, "left-icon"],
    "rightIcon": [1025, "right-icon"],
    "suffix": [1],
    "outerContainerClass": [1, "outer-container-class"],
    "labelClass": [1025, "label-class"],
    "error": [1540],
    "assistiveText": [1, "assistive-text"],
    "floatLabel": [4, "float-label"],
    "textarea": [4],
    "textareaHeight": [1025, "textarea-height"],
    "elAriaLabel": [1, "el-aria-label"],
    "hideCharacterCount": [4, "hide-character-count"],
    "step": [1],
    "clearErrorOnFocus": [4, "clear-error-on-focus"],
    "isFocused": [32],
    "isHovered": [32]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["mx-confirm-input", "mx-input"];
  components.forEach(tagName => { switch (tagName) {
    case "mx-confirm-input":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, MxConfirmInput$1);
      }
      break;
    case "mx-input":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const MxConfirmInput = MxConfirmInput$1;
const defineCustomElement = defineCustomElement$1;

export { MxConfirmInput, defineCustomElement };

//# sourceMappingURL=mx-confirm-input.js.map