import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { l as lockBodyScroll, u as unlockBodyScroll } from './bodyScroll.js';
import { m as moveToPortal } from './portal.js';
import { c as fadeIn, f as fadeScaleIn, a as fadeOut } from './transitions.js';
import { u as uuidv4 } from './utils.js';
import { d as defineCustomElement$2 } from './mx-button2.js';

const MxDialog$1 = proxyCustomElement(class MxDialog extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.mxClose = createEvent(this, "mxClose", 7);
    this.isSimple = true;
    this.hasButtons = false;
    this.hasHeading = false;
    this.uuid = uuidv4();
    this.isOpen = false;
    this.modalClass = undefined;
    this.isVisible = false;
  }
  onIsOpenChange() {
    this.isOpen ? this.showDialog() : this.closeDialog();
  }
  onKeyDown(e) {
    if (!this.isVisible)
      return;
    const isFocusOutside = () => !document.activeElement || !this.focusElements.includes(document.activeElement);
    if (e.key === 'Tab') {
      this.getFocusElements();
      if (e.shiftKey && document.activeElement === this.firstFocusElement) {
        this.lastFocusElement.focus();
        e.preventDefault();
      }
      else if (isFocusOutside() || document.activeElement === this.lastFocusElement) {
        this.firstFocusElement && this.firstFocusElement.focus();
        e.preventDefault();
      }
    }
    else if (e.key === 'Enter') {
      this.getFocusElements();
      if (isFocusOutside()) {
        e.preventDefault();
        this.firstFocusElement && this.firstFocusElement.focus();
        this.closeDialog(true);
      }
    }
    else if (e.key === 'Escape') {
      this.closeDialog();
      e.preventDefault();
    }
  }
  async alert(message, { confirmLabel = 'OK', cancelLabel, heading } = {}) {
    return this.open(message, { heading, confirmLabel, cancelLabel });
  }
  async confirm(message, { confirmLabel = 'OK', cancelLabel = 'Cancel', heading } = {}) {
    return this.open(message, { heading, confirmLabel, cancelLabel });
  }
  componentWillRender() {
    this.hasHeading = !!this.heading || !!this.element.querySelector('[slot="heading"]');
    this.hasButtons = !!this.confirmLabel || !!this.cancelLabel || !!this.element.querySelector('[slot="buttons"]');
    this.isSimple = !this.element.innerText;
  }
  componentDidLoad() {
    if (this.isOpen)
      this.showDialog();
  }
  disconnectedCallback() {
    unlockBodyScroll(this.element);
  }
  async open(message, { cancelLabel, confirmLabel, heading } = {}) {
    this.heading = heading;
    this.message = message;
    this.cancelLabel = cancelLabel;
    this.confirmLabel = confirmLabel;
    this.showDialog();
    return new Promise(resolve => {
      this.deferredResolve = resolve;
    });
  }
  async showDialog() {
    if (this.isVisible)
      return;
    this.ancestorFocusedElement = document.activeElement;
    moveToPortal(this.element);
    lockBodyScroll(this.element);
    this.isVisible = true;
    await new Promise(resolve => requestAnimationFrame(resolve));
    await Promise.all([fadeIn(this.backdrop), fadeScaleIn(this.modal)]);
  }
  async closeDialog(isConfirmed = false) {
    if (!this.isVisible)
      return;
    await Promise.all([fadeOut(this.backdrop), fadeOut(this.modal)]);
    this.isVisible = false;
    unlockBodyScroll(this.element);
    this.ancestorFocusedElement && this.ancestorFocusedElement.focus();
    if (this.deferredResolve)
      this.deferredResolve(isConfirmed);
    this.mxClose.emit();
  }
  getFocusElements() {
    const isVisible = (el) => !!el.offsetParent;
    this.focusElements = Array.from(this.element.querySelectorAll('button, [href], input, select, textarea, [tabindex]:not([tabindex="-1"])')).filter(isVisible);
    if (this.focusElements.length) {
      this.firstFocusElement = this.focusElements[0];
      this.lastFocusElement = this.focusElements[this.focusElements.length - 1];
    }
  }
  get hostClass() {
    let str = 'mx-dialog fixed inset-0 flex items-center justify-center';
    if (!this.isVisible)
      str += ' hidden';
    return str;
  }
  get modalClassNames() {
    let str = 'modal p-20 w-480 m-16 flex flex-col rounded shadow-4 relative overflow-hidden';
    if (this.isSimple)
      str += ' w-320';
    if (this.modalClass)
      str += ' ' + this.modalClass;
    return str;
  }
  render() {
    return (h(Host, { class: this.hostClass }, h("div", { ref: el => (this.backdrop = el), class: "bg-dialog-backdrop absolute inset-0 z-0" }), h("div", { ref: el => (this.modal = el), role: "alertdialog", "aria-labelledby": this.heading ? this.uuid + '-dialog-heading' : null, "aria-describedby": this.message ? this.uuid + '-dialog-message' : null, "aria-modal": "true", "data-testid": "modal", class: this.modalClassNames }, h("div", { class: "text-4 p-20 flex-grow overflow-auto", tabindex: "0", "data-testid": "modal-content" }, this.hasHeading && (h("h1", { id: this.uuid + '-dialog-heading', class: "text-h6 emphasis my-0 pb-16", "data-testid": "heading" }, this.heading, h("slot", { name: "heading" }))), this.message && (h("p", { id: this.uuid + '-dialog-message', class: "my-0" }, this.message)), h("slot", null)), this.hasButtons && (h("div", { class: "flex flex-col flex-wrap items-stretch gap-10 sm:flex-row sm:items-center sm:justify-end p-10", "data-testid": "button-tray" }, this.confirmLabel && (h("mx-button", { class: "sm:order-2", onClick: () => this.closeDialog(true) }, this.confirmLabel)), this.cancelLabel && (h("mx-button", { class: "sm:order-1", btnType: "text", onClick: () => this.closeDialog() }, this.cancelLabel)), h("slot", { name: "buttons" }))))));
  }
  get element() { return this; }
  static get watchers() { return {
    "isOpen": ["onIsOpenChange"]
  }; }
}, [4, "mx-dialog", {
    "isOpen": [4, "is-open"],
    "modalClass": [1, "modal-class"],
    "isVisible": [32],
    "alert": [64],
    "confirm": [64]
  }, [[16, "keydown", "onKeyDown"]]]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["mx-dialog", "mx-button"];
  components.forEach(tagName => { switch (tagName) {
    case "mx-dialog":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, MxDialog$1);
      }
      break;
    case "mx-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const MxDialog = MxDialog$1;
const defineCustomElement = defineCustomElement$1;

export { MxDialog, defineCustomElement };

//# sourceMappingURL=mx-dialog.js.map