import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { d as defineCustomElement$2 } from './mx-menu2.js';

const MxDropdownMenu$1 = proxyCustomElement(class MxDropdownMenu extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.elAriaLabel = undefined;
    this.disabled = false;
    this.readonly = false;
    this.dense = false;
    this.elevated = false;
    this.flat = false;
    this.label = undefined;
    this.dropdownClass = undefined;
    this.dropdownId = undefined;
    this.name = undefined;
    this.suffix = undefined;
    this.value = undefined;
    this.error = undefined;
    this.assistiveText = undefined;
    this.isFocused = false;
  }
  async onClick(e) {
    this.menu.style.width = this.dropdownWrapper.getBoundingClientRect().width + 'px';
    const clickedMenuItem = e.target.closest('mx-menu-item');
    if (!clickedMenuItem)
      return;
    this.value = await clickedMenuItem.getValue();
    this.inputElem.dispatchEvent(new Event('input', { bubbles: true, cancelable: true }));
  }
  componentDidLoad() {
    this.updateInputValue();
    this.attachMenu();
  }
  onValueChange() {
    this.updateInputValue();
  }
  attachMenu() {
    if (!this.disabled && !this.readonly)
      this.menu.anchorEl = this.dropdownWrapper;
    else
      this.menu.anchorEl = undefined;
  }
  onBlur() {
    if (this.menu && this.menu.isOpen)
      return;
    this.isFocused = false;
  }
  onFocus() {
    this.isFocused = true;
    this.error = false;
  }
  onMenuClose(e) {
    e.stopPropagation();
    if (!this.inputElem.contains(document.activeElement))
      this.isFocused = false;
  }
  updateInputValue() {
    this.inputElem.value = this.value;
  }
  get dropdownWrapperClass() {
    let str = 'dropdown-wrapper flex items-center relative rounded';
    str += this.dense ? ' h-36' : ' h-48';
    if (this.elevated)
      str += ' elevated shadow-1';
    if (this.flat)
      str += ' flat';
    str += ' border';
    if (this.disabled || this.readonly)
      str += ' disabled';
    if (this.error)
      str += ' error';
    if (this.dropdownClass)
      str += ' ' + this.dropdownClass;
    return str;
  }
  get inputClass() {
    const str = 'absolute inset-0 w-full h-full pl-16 overflow-hidden outline-none appearance-none select-none bg-transparent cursor-pointer disabled:cursor-auto';
    return str;
  }
  get suffixClass() {
    const str = 'icon-suffix absolute flex items-center h-full right-12 space-x-8 pointer-events-none';
    return str;
  }
  render() {
    return (h(Host, { class: "mx-dropdown-menu block text-3" }, h("div", { ref: el => (this.dropdownWrapper = el), class: this.dropdownWrapperClass }, h("input", { "aria-label": this.elAriaLabel || this.label, class: this.inputClass, id: this.dropdownId, name: this.name, onBlur: this.onBlur.bind(this), onFocus: this.onFocus.bind(this), placeholder: this.label, disabled: this.disabled, readonly: !this.disabled, ref: el => (this.inputElem = el), tabindex: "0", type: "text" }), h("span", { class: this.suffixClass }, this.suffix && h("span", { class: "suffix flex items-center h-full px-4" }, this.suffix), this.error ? (h("i", { class: "mds-warning-circle text-icon pointer-events-none" })) : (h("i", { "data-testid": "arrow", class: "mds-arrow-triangle-down text-icon" })))), this.assistiveText && h("div", { class: "assistive-text caption1 mt-4 ml-16" }, this.assistiveText), h("mx-menu", { ref: el => (this.menu = el), placement: "bottom", offset: [0, 1], onMxClose: this.onMenuClose.bind(this) }, h("slot", null))));
  }
  static get watchers() { return {
    "value": ["onValueChange"],
    "disabled": ["attachMenu"],
    "readonly": ["attachMenu"]
  }; }
}, [4, "mx-dropdown-menu", {
    "elAriaLabel": [1, "el-aria-label"],
    "disabled": [4],
    "readonly": [4],
    "dense": [4],
    "elevated": [4],
    "flat": [4],
    "label": [1],
    "dropdownClass": [1, "dropdown-class"],
    "dropdownId": [1, "dropdown-id"],
    "name": [1],
    "suffix": [1],
    "value": [1032],
    "error": [1540],
    "assistiveText": [1, "assistive-text"],
    "isFocused": [32]
  }, [[0, "click", "onClick"]]]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["mx-dropdown-menu", "mx-menu"];
  components.forEach(tagName => { switch (tagName) {
    case "mx-dropdown-menu":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, MxDropdownMenu$1);
      }
      break;
    case "mx-menu":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const MxDropdownMenu = MxDropdownMenu$1;
const defineCustomElement = defineCustomElement$1;

export { MxDropdownMenu, defineCustomElement };

//# sourceMappingURL=mx-dropdown-menu.js.map