import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { p as propagateDataAttributes } from './utils.js';

const MxIconButton = proxyCustomElement(class MxIconButton extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.dataAttributes = {};
    this.type = 'button';
    this.form = undefined;
    this.formaction = undefined;
    this.value = undefined;
    this.href = undefined;
    this.target = undefined;
    this.disabled = false;
    this.elAriaLabel = undefined;
    this.chevronDown = false;
    this.chevronLeft = false;
    this.chevronRight = false;
    this.chevronUp = false;
    this.close = false;
    this.icon = undefined;
  }
  componentWillRender() {
    if (this.close)
      this.icon = 'mds-x';
    propagateDataAttributes.call(this);
  }
  onClick(e) {
    if (this.disabled) {
      e.stopPropagation();
      e.preventDefault();
      return;
    }
  }
  get isChevron() {
    return this.chevronDown || this.chevronLeft || this.chevronRight || this.chevronUp;
  }
  get buttonClass() {
    let str = 'flex text-current appearance-none items-center rounded-full justify-center relative overflow-hidden cursor-pointer disabled:pointer-events-none disabled:cursor-auto';
    str += this.close ? ' close-icon-button w-30 h-30' : ' w-48 h-48';
    return str;
  }
  render() {
    const Tag = this.href ? 'a' : 'button';
    const buttonContent = (h("div", { class: "flex justify-center items-center content-center relative" }, this.icon && h("i", { class: [this.close ? 'text-small' : 'text-icon', this.icon].join(' ') }), h("span", { class: "slot-content" }, h("slot", null)), this.isChevron && (h("span", { class: "chevron-wrapper inline-flex w-24 h-24 rounded-full items-center justify-center text-icon shadow-1" }, h("i", { "data-testid": "chevron", class: this.chevronLeft
        ? 'mds-chevron-left'
        : this.chevronRight
          ? 'mds-chevron-right'
          : this.chevronUp
            ? 'mds-chevron-up'
            : 'mds-chevron-down' })))));
    return (h(Host, { class: "mx-icon-button inline-block appearance-none" }, h(Tag, Object.assign({ type: this.href ? null : this.type, form: this.form, formaction: this.formaction, value: this.value, href: this.href, target: this.href ? this.target : null, class: this.buttonClass, ref: el => (this.btnElem = el), disabled: this.disabled, "aria-disabled": this.disabled ? 'true' : null, "aria-label": this.elAriaLabel, tabindex: this.disabled ? '-1' : '0' }, this.dataAttributes, { onClick: this.onClick.bind(this) }), buttonContent)));
  }
  get element() { return this; }
}, [4, "mx-icon-button", {
    "type": [1],
    "form": [1],
    "formaction": [1],
    "value": [1],
    "href": [1],
    "target": [1],
    "disabled": [516],
    "elAriaLabel": [1, "el-aria-label"],
    "chevronDown": [4, "chevron-down"],
    "chevronLeft": [4, "chevron-left"],
    "chevronRight": [4, "chevron-right"],
    "chevronUp": [4, "chevron-up"],
    "close": [4],
    "icon": [1537]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["mx-icon-button"];
  components.forEach(tagName => { switch (tagName) {
    case "mx-icon-button":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, MxIconButton);
      }
      break;
  } });
}

export { MxIconButton as M, defineCustomElement as d };

//# sourceMappingURL=mx-icon-button2.js.map