import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { u as uuidv4, p as propagateDataAttributes } from './utils.js';

const MxInput = proxyCustomElement(class MxInput extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.dataAttributes = {};
    this.uuid = uuidv4();
    this.componentWillRender = propagateDataAttributes;
    this.name = undefined;
    this.inputId = undefined;
    this.label = undefined;
    this.placeholder = undefined;
    this.value = undefined;
    this.type = 'text';
    this.dense = false;
    this.autofocus = false;
    this.disabled = false;
    this.readonly = false;
    this.maxlength = undefined;
    this.leftIcon = undefined;
    this.rightIcon = undefined;
    this.suffix = undefined;
    this.outerContainerClass = '';
    this.labelClass = '';
    this.error = false;
    this.assistiveText = undefined;
    this.floatLabel = false;
    this.textarea = false;
    this.textareaHeight = '15.625rem';
    this.elAriaLabel = undefined;
    this.hideCharacterCount = false;
    this.step = undefined;
    this.clearErrorOnFocus = true;
    this.isFocused = false;
    this.characterCount = 0;
  }
  connectedCallback() {
    this.characterCount = this.hasValue ? this.value.length : 0;
  }
  componentDidLoad() {
    this.updateValue();
  }
  onValueChange() {
    this.updateValue();
    this.characterCount = this.hasValue ? this.value.length : 0;
  }
  updateValue() {
    this.workingElem.value = this.hasValue ? this.value : '';
  }
  onFocus() {
    this.isFocused = true;
    if (this.clearErrorOnFocus) {
      this.error = false;
    }
  }
  onBlur() {
    this.isFocused = false;
  }
  onContainerClick() {
    if (!this.disabled && !this.readonly)
      this.workingElem.focus();
  }
  onInput(e) {
    this.characterCount = e.target.value.length;
    this.value = e.target.value;
  }
  getIconJsx(icon) {
    return icon.onClick ? (h("button", { type: "button", class: "inline-flex items-center justify-center cursor-pointer", "aria-label": icon.ariaLabel, onClick: icon.onClick }, h("i", { class: icon.icon }))) : (h("i", { class: icon.icon + ' pointer-events-none' }));
  }
  get workingElem() {
    return this.textarea ? this.textArea : this.textInput;
  }
  get hasValue() {
    return this.value !== null && this.value !== '' && this.value !== undefined;
  }
  get containerClass() {
    let str = 'mx-input-wrapper flex items-center relative rounded';
    if (!this.textarea) {
      str += this.dense ? ' h-36' : ' h-48';
    }
    str += ' border';
    if (this.error)
      str += ' error';
    if (this.disabled)
      str += ' disabled';
    if (this.readonly)
      str += ' readonly';
    return str;
  }
  get inputClass() {
    let str = 'flex-1 outline-none appearance-none bg-transparent';
    if (!this.textarea) {
      str += ' px-16 overflow-hidden';
    }
    else {
      str += ' p-16 overflow-y-auto resize-none';
    }
    return str;
  }
  get labelClassNames() {
    let str = 'block whitespace-nowrap pointer-events-none';
    if (this.floatLabel) {
      str += ' absolute mt-0 px-4';
      if (this.textarea)
        str += ' top-12';
      str += this.leftIcon && !this.textarea ? ' left-48 has-left-icon' : ' left-12';
      if (this.dense && !this.textarea)
        str += ' dense text-4';
      if (this.isFocused || this.characterCount > 0)
        str += ' floating';
    }
    else {
      str += ' subtitle2 mb-4';
    }
    if (this.labelClass)
      str += this.labelClass;
    return str;
  }
  get leftIconWrapperClass() {
    const str = 'flex items-center h-full pl-16 space-x-16';
    return str;
  }
  get rightContentClass() {
    const str = 'icon-suffix flex items-center h-full pr-16 space-x-8';
    return str;
  }
  get textareaClass() {
    return this.textarea ? ' textarea items-start' : '';
  }
  get leftIcons() {
    if (typeof this.leftIcon === 'string')
      return [{ icon: this.leftIcon }];
    return this.leftIcon;
  }
  get rightIcons() {
    if (typeof this.rightIcon === 'string')
      return [{ icon: this.rightIcon }];
    return this.rightIcon;
  }
  render() {
    const labelJsx = (h("label", { htmlFor: this.inputId || this.uuid, class: this.labelClassNames }, this.label));
    return (h(Host, { class: 'mx-input block text-3' + (this.disabled ? ' disabled' : '') }, this.label && !this.floatLabel && labelJsx, h("div", { class: this.containerClass, onClick: this.onContainerClick.bind(this) }, this.leftIcon && h("div", { class: this.leftIconWrapperClass }, this.leftIcons.map(this.getIconJsx)), this.label && this.floatLabel && labelJsx, !this.textarea ? (h("input", Object.assign({ type: this.type, class: this.inputClass, name: this.name, id: this.inputId || this.uuid, value: this.value, placeholder: this.floatLabel ? null : this.placeholder, "aria-label": this.elAriaLabel || this.placeholder, autofocus: this.autofocus, maxlength: this.maxlength, disabled: this.disabled, readonly: this.readonly, step: this.step, onFocus: this.onFocus.bind(this), onBlur: this.onBlur.bind(this), onInput: this.onInput.bind(this), ref: el => (this.textInput = el) }, this.dataAttributes))) : (h("textarea", Object.assign({ class: this.inputClass, style: { height: this.textareaHeight }, name: this.name, id: this.inputId || this.uuid, placeholder: this.floatLabel ? null : this.placeholder, maxlength: this.maxlength, disabled: this.disabled, readonly: this.readonly, onFocus: this.onFocus.bind(this), onBlur: this.onBlur.bind(this), onInput: this.onInput.bind(this), ref: el => (this.textArea = el) }, this.dataAttributes), this.value)), !this.textarea && (this.maxlength || this.suffix || this.error || this.rightIcon) && (h("span", { class: this.rightContentClass }, this.maxlength && !this.hideCharacterCount && (h("span", { "data-testid": "character-count", class: "character-count pointer-events-none" }, this.characterCount, "/", this.maxlength)), this.suffix && (h("span", { "data-testid": "suffix", class: "suffix flex items-center h-full px-4 pointer-events-none" }, this.suffix)), this.error && h("i", { class: "mds-warning-circle text-icon pointer-events-none" }), this.rightIcon && !this.error && (h("span", { class: "flex items-center space-x-16" }, this.rightIcons.map(this.getIconJsx)))))), (this.assistiveText || (this.textarea && this.maxlength && !this.hideCharacterCount)) && (h("div", { class: "flex justify-between caption1 mt-4 ml-16 space-x-32" }, h("span", { "data-testid": "assistive-text", class: "assistive-text" }, this.assistiveText), this.textarea && this.maxlength && !this.hideCharacterCount && (h("span", { "data-testid": "character-count", class: "character-count" }, this.characterCount, "/", this.maxlength))))));
  }
  get element() { return this; }
  static get watchers() { return {
    "value": ["onValueChange"]
  }; }
}, [0, "mx-input", {
    "name": [1],
    "inputId": [1, "input-id"],
    "label": [1],
    "placeholder": [1],
    "value": [1025],
    "type": [1],
    "dense": [4],
    "autofocus": [4],
    "disabled": [4],
    "readonly": [4],
    "maxlength": [2],
    "leftIcon": [1, "left-icon"],
    "rightIcon": [1, "right-icon"],
    "suffix": [1],
    "outerContainerClass": [1, "outer-container-class"],
    "labelClass": [1025, "label-class"],
    "error": [1540],
    "assistiveText": [1, "assistive-text"],
    "floatLabel": [4, "float-label"],
    "textarea": [4],
    "textareaHeight": [1025, "textarea-height"],
    "elAriaLabel": [1, "el-aria-label"],
    "hideCharacterCount": [4, "hide-character-count"],
    "step": [1],
    "clearErrorOnFocus": [4, "clear-error-on-focus"],
    "isFocused": [32],
    "characterCount": [32]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["mx-input"];
  components.forEach(tagName => { switch (tagName) {
    case "mx-input":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, MxInput);
      }
      break;
  } });
}

export { MxInput as M, defineCustomElement as d };

//# sourceMappingURL=mx-input2.js.map