import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';

const MxLinearProgress = proxyCustomElement(class MxLinearProgress extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.value = null;
    this.simulateProgressDuration = null;
    this.appearDelay = 0;
  }
  simulateProgress() {
    clearInterval(this.simulateProgressInterval);
    if (!this.simulateProgressDuration)
      return;
    this.simulateProgressInterval = setInterval(() => {
      if (this.value === 100)
        return;
      this.value = Math.min((this.value || 0) + 1, 99);
    }, this.simulateProgressDuration / 100);
  }
  connectedCallback() {
    this.simulateProgress();
    if (!this.appearDelay)
      return;
    this.element.classList.remove('block');
    this.element.classList.add('hidden');
    this.delayTimeout = setTimeout(() => {
      this.element.classList.remove('hidden');
      this.element.classList.add('block');
    }, this.appearDelay);
  }
  disconnectedCallback() {
    clearTimeout(this.delayTimeout);
  }
  get determinateBarStyle() {
    return {
      transform: `translateX(${this.value - 100}%)`,
      transition: 'transform 0.4s linear',
    };
  }
  render() {
    return (h(Host, { class: "mx-linear-progress block h-4 w-full rounded-sm overflow-hidden pointer-events-none", role: "progressbar", "aria-valuenow": this.value != null ? Math.round(this.value) : null, "aria-valuemin": this.value != null ? 0 : null, "aria-valuemax": this.value != null ? 100 : null }, h("div", { class: "relative h-full" }, this.value != null ? (h("div", { "data-testid": "determinate", class: "fill h-4 absolute inset-0 rounded-sm", style: this.determinateBarStyle })) : ([
      h("div", { "data-testid": "indeterminate1", class: "indeterminate1 absolute h-full w-full" }, h("div", { class: "fill absolute w-full h-full rounded-sm" })),
      h("div", { "data-testid": "indeterminate2", class: "indeterminate2 absolute h-full w-full" }, h("div", { class: "fill absolute w-full h-full rounded-sm" })),
    ]))));
  }
  get element() { return this; }
  static get watchers() { return {
    "simulateProgressDuration": ["simulateProgress"]
  }; }
}, [0, "mx-linear-progress", {
    "value": [1026],
    "simulateProgressDuration": [2, "simulate-progress-duration"],
    "appearDelay": [2, "appear-delay"]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["mx-linear-progress"];
  components.forEach(tagName => { switch (tagName) {
    case "mx-linear-progress":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, MxLinearProgress);
      }
      break;
  } });
}

export { MxLinearProgress as M, defineCustomElement as d };

//# sourceMappingURL=mx-linear-progress2.js.map