import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { e as expand, d as collapse } from './transitions.js';
import { u as uuidv4 } from './utils.js';

const MxMenuAccordion$1 = proxyCustomElement(class MxMenuAccordion extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.mxClose = createEvent(this, "mxClose", 7);
    this.mxOpen = createEvent(this, "mxOpen", 7);
    this.isClosing = false;
    this.uuid = uuidv4();
    this.anchorEl = undefined;
    this.isOpen = false;
  }
  onClick(e) {
    const anchorElWasClicked = this.anchorEl && this.anchorEl.contains(e.target);
    if (!anchorElWasClicked)
      return;
    e.preventDefault();
    this.isOpen ? this.closeMenu() : this.openMenu();
  }
  async toggleMenu() {
    return this.isOpen ? this.closeMenu : this.openMenu;
  }
  async openMenu() {
    if (this.isOpen || !this.anchorEl)
      return false;
    this.isOpen = true;
    this.mxOpen.emit();
    await new Promise(requestAnimationFrame);
    await expand(this.menuElem);
    return true;
  }
  setAnchorElAttributes() {
    if (!this.anchorEl)
      return;
    this.anchorEl.setAttribute('aria-controls', this.uuid);
    this.setAnchorAriaExpanded(this.isOpen);
  }
  async closeMenu(skipTransition = false) {
    if (!this.isOpen || this.isClosing)
      return false;
    this.isClosing = true;
    this.setAnchorAriaExpanded(false);
    this.menuItems.forEach(m => m.closeSubMenu());
    await collapse(this.menuElem, !skipTransition ? undefined : 0);
    this.isClosing = false;
    this.mxClose.emit();
    this.isOpen = false;
    return true;
  }
  componentDidLoad() {
    if (this.menuItems.length) {
      const role = this.element.querySelector('[role="option"]') ? 'listbox' : 'menu';
      this.menuElem.setAttribute('role', role);
    }
    this.setAnchorElAttributes();
  }
  componentWillUpdate() {
    this.setAnchorAriaExpanded(this.isOpen);
    const anyMenuItemHasIcon = this.menuItems.some(m => !!m.icon);
    if (anyMenuItemHasIcon) {
      this.menuItems.forEach(m => {
        if (m.icon === undefined)
          m.icon = null;
      });
    }
  }
  setAnchorAriaExpanded(isExpanded = false) {
    if (!this.anchorEl)
      return;
    this.anchorEl.setAttribute('aria-expanded', isExpanded.toString());
  }
  get menuItems() {
    return (Array.from(this.menuElem.children).filter(e => e.tagName === 'MX-MENU-ITEM') ||
      []);
  }
  get hostClass() {
    let str = 'mx-menu-accordion block z-50';
    if (!this.isOpen)
      str += ' invisible h-0 overflow-hidden';
    return str;
  }
  render() {
    return (h(Host, { class: this.hostClass }, h("div", { id: this.uuid, ref: el => (this.menuElem = el), class: "flex flex-col overflow-hidden rounded-b pl-12" }, h("slot", null))));
  }
  get element() { return this; }
  static get watchers() { return {
    "anchorEl": ["setAnchorElAttributes"]
  }; }
}, [4, "mx-menu-accordion", {
    "anchorEl": [16],
    "isOpen": [1540, "is-open"],
    "toggleMenu": [64],
    "openMenu": [64],
    "closeMenu": [64]
  }, [[6, "click", "onClick"]]]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["mx-menu-accordion"];
  components.forEach(tagName => { switch (tagName) {
    case "mx-menu-accordion":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, MxMenuAccordion$1);
      }
      break;
  } });
}

const MxMenuAccordion = MxMenuAccordion$1;
const defineCustomElement = defineCustomElement$1;

export { MxMenuAccordion, defineCustomElement };

//# sourceMappingURL=mx-menu-accordion.js.map