import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { m as moveToPortal } from './portal.js';
import { c as fadeIn, f as fadeScaleIn, a as fadeOut } from './transitions.js';
import { l as lockBodyScroll, u as unlockBodyScroll } from './bodyScroll.js';
import { d as defineCustomElement$2 } from './mx-icon-button2.js';

const MxModalOverlay$1 = proxyCustomElement(class MxModalOverlay extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.mxClose = createEvent(this, "mxClose", 7);
    this.closeOnEscape = true;
    this.closeOnOutsideClick = true;
    this.isOpen = false;
    this.portal = true;
    this.isVisible = false;
  }
  toggleModal() {
    this.isOpen ? this.openModal() : this.closeModal();
  }
  onKeyDown(e) {
    if (!this.isOpen)
      return;
    if (e.key === 'Tab') {
      if (e.shiftKey && document.activeElement === this.firstFocusElement) {
        this.lastFocusElement.focus();
        e.preventDefault();
      }
      else if (document.activeElement === this.lastFocusElement) {
        this.firstFocusElement.focus();
        e.preventDefault();
      }
    }
  }
  onDocumentKeyDown(e) {
    if (this.isOpen && this.closeOnEscape && e.key === 'Escape')
      this.mxClose.emit();
  }
  disconnectedCallback() {
    unlockBodyScroll(this.element);
  }
  componentDidLoad() {
    if (this.isOpen)
      this.openModal();
  }
  async openModal() {
    if (this.portal)
      moveToPortal(this.element);
    lockBodyScroll(this.element);
    this.isVisible = true;
    requestAnimationFrame(async () => {
      this.getFocusElements();
      await Promise.all([fadeIn(this.backdrop, 250), fadeScaleIn(this.modal, 250)]);
    });
  }
  getFocusElements() {
    this.ancestorFocusedElement = document.activeElement;
    const isVisible = (el) => !!el.offsetParent;
    this.focusElements = Array.from(this.element.querySelectorAll('button, [href], input, select, textarea, [tabindex]:not([tabindex="-1"])')).filter(isVisible);
    if (this.focusElements.length) {
      this.firstFocusElement = this.focusElements[0];
      this.lastFocusElement = this.focusElements[this.focusElements.length - 1];
      this.focusElements[0].focus();
    }
  }
  async closeModal() {
    await Promise.all([fadeOut(this.backdrop), fadeOut(this.modal)]);
    this.isVisible = false;
    unlockBodyScroll(this.element);
    this.ancestorFocusedElement && this.ancestorFocusedElement.focus();
  }
  onBackdropClick() {
    if (this.closeOnOutsideClick)
      this.mxClose.emit();
  }
  get hostClass() {
    let str = 'mx-modal-overlay block fixed inset-0';
    if (!this.isVisible)
      str += ' hidden';
    return str;
  }
  render() {
    return (h(Host, { class: this.hostClass, "aria-modal": "true", role: "dialog" }, h("div", { ref: el => (this.backdrop = el), class: 'bg-modal-backdrop absolute inset-0 z-0' + (this.closeOnOutsideClick ? ' cursor-pointer' : ''), "data-testid": "backdrop", onClick: this.onBackdropClick.bind(this) }), h("div", { ref: el => (this.modal = el), class: "modal flex flex-col absolute inset-0 pt-60 px-10 pb-10 pointer-events-none" }, h("div", { class: "pointer-events-auto pt-10", "data-testid": "modal-content" }, h("slot", null)), h("div", { class: "absolute top-0 right-0 w-60 h-60 flex items-center justify-center" }, h("mx-icon-button", { "el-aria-label": "Close modal", close: true, class: "pointer-events-auto", "data-testid": "close-button", onClick: this.mxClose.emit })))));
  }
  get element() { return this; }
  static get watchers() { return {
    "isOpen": ["toggleModal"]
  }; }
}, [4, "mx-modal-overlay", {
    "closeOnEscape": [4, "close-on-escape"],
    "closeOnOutsideClick": [4, "close-on-outside-click"],
    "isOpen": [516, "is-open"],
    "portal": [4],
    "isVisible": [32]
  }, [[0, "keydown", "onKeyDown"], [4, "keydown", "onDocumentKeyDown"]]]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["mx-modal-overlay", "mx-icon-button"];
  components.forEach(tagName => { switch (tagName) {
    case "mx-modal-overlay":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, MxModalOverlay$1);
      }
      break;
    case "mx-icon-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const MxModalOverlay = MxModalOverlay$1;
const defineCustomElement = defineCustomElement$1;

export { MxModalOverlay, defineCustomElement };

//# sourceMappingURL=mx-modal-overlay.js.map