import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { M as MinWidths, m as minWidthSync } from './minWidthSync.js';
import { m as moveToPortal } from './portal.js';
import { c as fadeIn, a as fadeOut, f as fadeScaleIn, g as fadeSlideIn, h as fadeSlideOut, D as Direction } from './transitions.js';
import { l as lockBodyScroll, u as unlockBodyScroll } from './bodyScroll.js';
import { u as uuidv4 } from './utils.js';
import { d as defineCustomElement$7 } from './mx-button2.js';
import { d as defineCustomElement$6 } from './mx-checkbox2.js';
import { d as defineCustomElement$5 } from './mx-icon-button2.js';
import { d as defineCustomElement$4 } from './mx-menu2.js';
import { d as defineCustomElement$3 } from './mx-menu-item2.js';
import { d as defineCustomElement$2 } from './mx-page-header2.js';

const MxModal$1 = proxyCustomElement(class MxModal extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.mxClose = createEvent(this, "mxClose", 7);
    this.hasCard = false;
    this.hasHeader = false;
    this.hasHeaderBottom = false;
    this.hasHeaderCenter = false;
    this.uuid = uuidv4();
    this.buttons = [];
    this.closeOnEscape = true;
    this.closeOnOutsideClick = true;
    this.contentClass = '';
    this.description = undefined;
    this.fromLeft = false;
    this.fromRight = false;
    this.isOpen = false;
    this.portal = true;
    this.previousPageTitle = 'Back';
    this.previousPageUrl = '';
    this.large = false;
    this.unpadded = false;
    this.minWidths = new MinWidths();
    this.isVisible = false;
  }
  toggleModal() {
    this.isOpen ? this.openModal() : this.closeModal();
  }
  updateSlottedButtonSize() {
    const slottedButtons = this.element.querySelectorAll('[slot*="footer-"] mx-button');
    slottedButtons.forEach((button) => (button.xl = this.minWidths.lg));
  }
  onKeyDown(e) {
    if (!this.isOpen)
      return;
    if (e.key === 'Tab') {
      if (e.shiftKey && document.activeElement === this.firstFocusElement) {
        this.lastFocusElement.focus();
        e.preventDefault();
      }
      else if (document.activeElement === this.lastFocusElement) {
        this.firstFocusElement.focus();
        e.preventDefault();
      }
    }
  }
  onDocumentKeyDown(e) {
    if (this.isOpen && this.closeOnEscape && e.key === 'Escape') {
      const modals = document.querySelectorAll('mx-modal[is-open]');
      const isTopModal = this.element === modals[modals.length - 1];
      if (isTopModal)
        this.mxClose.emit();
    }
  }
  componentWillRender() {
    this.hasHeader =
      !!this.element.querySelector('[slot="header-left"]') || !!this.element.querySelector('[slot="header-right"]');
    this.hasCard = !!this.element.querySelector('[slot="card"]');
    this.hasHeaderBottom = !!this.element.querySelector('[slot="header-bottom"]');
    this.hasHeaderCenter = !!this.element.querySelector('[slot="header-center"]');
    const tabs = this.element.querySelector('mx-tabs');
    if (tabs && this.headerBottomSlotWrapper && this.mobilePageHeader) {
      if (this.minWidths.md)
        this.headerBottomSlotWrapper.appendChild(tabs);
      else
        this.mobilePageHeader.appendChild(tabs);
    }
  }
  connectedCallback() {
    minWidthSync.subscribeComponent(this);
  }
  disconnectedCallback() {
    minWidthSync.unsubscribeComponent(this);
    unlockBodyScroll(this.element);
  }
  componentDidLoad() {
    if (this.isOpen)
      this.openModal();
  }
  async openModal() {
    if (this.portal)
      moveToPortal(this.element);
    lockBodyScroll(this.element);
    this.isVisible = true;
    requestAnimationFrame(async () => {
      this.getFocusElements();
      await Promise.all([fadeIn(this.backdrop, 250), this.openTransition(this.modal)]);
      this.mobilePageHeader.resetResizeObserver();
    });
  }
  getFocusElements() {
    this.ancestorFocusedElement = document.activeElement;
    const isVisible = (el) => !!el.offsetParent;
    this.focusElements = Array.from(this.element.querySelectorAll('button, [href], input, select, textarea, [tabindex]:not([tabindex="-1"])')).filter(isVisible);
    if (this.focusElements.length) {
      this.firstFocusElement = this.focusElements[0];
      this.lastFocusElement = this.focusElements[this.focusElements.length - 1];
      this.focusElements[0].focus();
    }
  }
  async closeModal() {
    await Promise.all([fadeOut(this.backdrop), this.closeTransition(this.modal)]);
    this.isVisible = false;
    unlockBodyScroll(this.element);
    this.ancestorFocusedElement && this.ancestorFocusedElement.focus();
  }
  onBackdropClick() {
    if (this.closeOnOutsideClick)
      this.mxClose.emit();
  }
  get hostClass() {
    let str = 'mx-modal fixed inset-0 flex items-stretch text-3';
    if (!this.isVisible)
      str += ' hidden';
    if (this.fromLeft)
      str += ' justify-start pr-24 sm:pr-40';
    else if (this.fromRight)
      str += ' justify-end pl-24 sm:pl-40';
    else {
      str += ' pt-24 md:pt-0 md:items-center justify-center';
      if (this.minWidths.md) {
        str += this.large ? ' modal-large' : ' modal-medium';
      }
    }
    return str;
  }
  get modalClass() {
    let str = 'modal flex flex-col shadow-9 relative overflow-hidden';
    if (this.fromLeft)
      str += ' rounded-r';
    else if (this.fromRight)
      str += ' rounded-l';
    else
      str += ' sm:rounded-t md:rounded w-full md:w-auto';
    return str;
  }
  get openTransition() {
    let transition = (el) => fadeScaleIn(el, 250);
    if (this.fromRight)
      transition = fadeSlideIn;
    else if (this.fromLeft)
      transition = (el) => fadeSlideIn(el, undefined, Direction.left);
    return transition;
  }
  get closeTransition() {
    let transition = fadeOut;
    if (this.fromRight)
      transition = fadeSlideOut;
    else if (this.fromLeft)
      transition = (el) => fadeSlideOut(el, undefined, Direction.left);
    return transition;
  }
  get hasFooter() {
    return ((this.minWidths.md && (!!this.previousPageUrl || this.buttons.length > 0)) ||
      !!this.element.querySelector('[slot="footer-left"]') ||
      !!this.element.querySelector('[slot="footer-right"]'));
  }
  get buttonsJsx() {
    return (h("div", { class: "flex py-1 space-x-24 justify-end flex-row-reverse space-x-reverse items-center max-w-full", "data-testid": "buttons" }, this.buttons.map((button, index) => {
      let { btnType } = button;
      if (!btnType)
        btnType = index === 0 ? 'contained' : index === 1 ? 'outlined' : 'text';
      return (h("mx-button", Object.assign({}, button, { "btn-type": btnType }), button.label));
    })));
  }
  get modalContentClasses() {
    let str = 'bg-modal-content order-2 flex-1 overflow-auto overscroll-none border-b';
    if (!this.unpadded)
      str += ' px-24 sm:px-40 py-16 sm:py-24';
    if (this.contentClass)
      str += ' ' + this.contentClass;
    return str;
  }
  render() {
    return (h(Host, { class: this.hostClass, "aria-labelledby": this.hasHeader ? this.uuid + '-header-text' : null, "aria-modal": "true", role: "dialog" }, h("div", { ref: el => (this.backdrop = el), class: 'bg-modal-backdrop absolute inset-0 z-0' + (this.closeOnOutsideClick ? ' cursor-pointer' : ''), "data-testid": "backdrop", onClick: this.onBackdropClick.bind(this) }), h("div", { ref: el => (this.modal = el), class: this.modalClass, style: { maxWidth: this.minWidths.md && (this.fromRight || this.fromLeft) ? '37.5rem' : '' } }, h("div", { tabindex: "0", class: this.modalContentClasses, "data-testid": "modal-content" }, this.description && (h("p", { class: "text-4 my-0 mb-16 sm:mb-24", "data-testid": "modal-description" }, this.description)), h("slot", null), this.hasCard && (h("div", null, h("div", { class: "bg-modal-card min-h-full px-24 sm:px-40 py-16 sm:py-24 rounded", "data-testid": "modal-card" }, h("slot", { name: "card" }))))), h("footer", { class: 'bg-modal-footer order-3 flex items-center justify-between h-80 py-20 px-40' +
        (this.hasFooter ? '' : ' hidden') }, h("div", null, h("slot", { name: "footer-left" }, this.previousPageUrl && (h("a", { href: this.previousPageUrl, class: "flex items-center uppercase text-small font-bold", "data-testid": "previous-page" }, h("i", { class: "mds-arrow-left mr-10" }), this.previousPageTitle)))), h("div", { class: "ml-16" }, h("slot", { name: "footer-right" }, this.buttons.length > 0 && this.buttonsJsx))), h("mx-page-header", { ref: el => (this.mobilePageHeader = el), class: "order-1 flex-shrink-0", buttons: this.buttons, modal: true, "previous-page-title": this.previousPageTitle, "previous-page-url": this.previousPageUrl }, h("span", { id: this.uuid + '-header-text', "data-testid": "header-text" }, h("slot", { name: "header-left" })), this.hasHeaderBottom && (h("div", { slot: "tabs" }, h("slot", { name: "header-bottom" }))), this.hasHeaderCenter && (h("div", { slot: "modal-header-center", class: "flex items-center justify-center" }, h("slot", { name: "header-center" }))), h("div", { slot: "modal-header-right" }, h("slot", { name: "header-right" }, h("mx-icon-button", { "el-aria-label": "Close", close: true, "data-testid": "close-button", onClick: this.mxClose.emit })))))));
  }
  get element() { return this; }
  static get watchers() { return {
    "isOpen": ["toggleModal"],
    "minWidths": ["updateSlottedButtonSize"]
  }; }
}, [4, "mx-modal", {
    "buttons": [16],
    "closeOnEscape": [4, "close-on-escape"],
    "closeOnOutsideClick": [4, "close-on-outside-click"],
    "contentClass": [1, "content-class"],
    "description": [1],
    "fromLeft": [4, "from-left"],
    "fromRight": [4, "from-right"],
    "isOpen": [516, "is-open"],
    "portal": [4],
    "previousPageTitle": [1, "previous-page-title"],
    "previousPageUrl": [1, "previous-page-url"],
    "large": [4],
    "unpadded": [4],
    "minWidths": [32],
    "isVisible": [32]
  }, [[0, "keydown", "onKeyDown"], [4, "keydown", "onDocumentKeyDown"]]]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["mx-modal", "mx-button", "mx-checkbox", "mx-icon-button", "mx-menu", "mx-menu-item", "mx-page-header"];
  components.forEach(tagName => { switch (tagName) {
    case "mx-modal":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, MxModal$1);
      }
      break;
    case "mx-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$7();
      }
      break;
    case "mx-checkbox":
      if (!customElements.get(tagName)) {
        defineCustomElement$6();
      }
      break;
    case "mx-icon-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$5();
      }
      break;
    case "mx-menu":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "mx-menu-item":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "mx-page-header":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const MxModal = MxModal$1;
const defineCustomElement = defineCustomElement$1;

export { MxModal, defineCustomElement };

//# sourceMappingURL=mx-modal.js.map