import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { p as propagateDataAttributes } from './utils.js';

const MxSearch$1 = proxyCustomElement(class MxSearch extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.mxClear = createEvent(this, "mxClear", 7);
    this.dataAttributes = {};
    this.componentWillRender = propagateDataAttributes;
    this.autofocus = false;
    this.dense = false;
    this.elAriaLabel = undefined;
    this.flat = false;
    this.name = undefined;
    this.placeholder = undefined;
    this.showClear = true;
    this.value = undefined;
  }
  onInput(e) {
    this.value = e.target.value;
  }
  onClear() {
    this.inputEl.value = '';
    this.inputEl.dispatchEvent(new window.Event('input', { bubbles: true }));
    this.mxClear.emit();
    if (typeof jest === 'undefined')
      this.inputEl.focus();
  }
  get inputClass() {
    let str = 'w-full pl-56 pr-16 rounded outline-none border';
    str += this.flat ? ' flat' : ' shadow-1';
    str += this.dense ? ' h-36 py-8 text-4' : ' h-48 py-12';
    return str;
  }
  get clearButtonClass() {
    let str = 'clear-button absolute right-8 inline-flex items-center justify-center w-24 h-24 text-2 cursor-pointer';
    if (!this.value)
      str += ' hidden';
    return str;
  }
  render() {
    return (h(Host, { class: "mx-search flex items-center text-3 relative" }, h("input", Object.assign({ ref: el => (this.inputEl = el), type: "search", "aria-label": this.elAriaLabel || this.placeholder || 'Search', autofocus: this.autofocus, name: this.name, placeholder: this.placeholder, value: this.value, class: this.inputClass }, this.dataAttributes, { onInput: this.onInput.bind(this) })), h("i", { class: "absolute mds-search left-16 pointer-events-none" }), this.showClear && (h("button", { type: "button", "aria-label": "Clear search", class: this.clearButtonClass, "data-testid": "clear-button", onClick: this.onClear.bind(this) }, h("i", { class: "mds-cross transform rotate-45" })))));
  }
  get element() { return this; }
}, [0, "mx-search", {
    "autofocus": [4],
    "dense": [4],
    "elAriaLabel": [1, "el-aria-label"],
    "flat": [4],
    "name": [1],
    "placeholder": [1],
    "showClear": [4, "show-clear"],
    "value": [1025]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["mx-search"];
  components.forEach(tagName => { switch (tagName) {
    case "mx-search":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, MxSearch$1);
      }
      break;
  } });
}

const MxSearch = MxSearch$1;
const defineCustomElement = defineCustomElement$1;

export { MxSearch, defineCustomElement };

//# sourceMappingURL=mx-search.js.map