import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { u as uuidv4, p as propagateDataAttributes } from './utils.js';

const MxSelect = proxyCustomElement(class MxSelect extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.uuid = uuidv4();
    this.dataAttributes = {};
    this.componentWillRender = propagateDataAttributes;
    this.assistiveText = undefined;
    this.autofocus = false;
    this.dense = false;
    this.disabled = false;
    this.elevated = false;
    this.flat = false;
    this.label = undefined;
    this.floatLabel = false;
    this.elAriaLabel = undefined;
    this.selectClass = undefined;
    this.selectId = undefined;
    this.name = undefined;
    this.suffix = undefined;
    this.error = false;
    this.labelClass = '';
    this.value = undefined;
    this.isFocused = false;
  }
  componentDidLoad() {
    this.updateSelectValue();
  }
  onValueChange() {
    this.updateSelectValue();
  }
  updateSelectValue() {
    this.selectElem.value = this.value;
  }
  onFocus() {
    this.isFocused = true;
    this.error = false;
  }
  onBlur() {
    this.isFocused = false;
  }
  onInput(e) {
    this.value = e.target.value;
  }
  get hasValue() {
    return this.value !== null && this.value !== '' && this.value !== undefined;
  }
  get selectWrapperClass() {
    let str = 'mx-select-wrapper flex items-center relative rounded';
    str += this.dense ? ' h-36' : ' h-48';
    if (!this.hasValue)
      str += ' no-value';
    if (this.elevated)
      str += ' elevated shadow-1';
    if (this.flat)
      str += ' flat';
    str += ' border';
    if (this.error)
      str += ' error';
    if (this.disabled)
      str += ' disabled';
    if (this.selectClass)
      str += ' ' + this.selectClass;
    return str;
  }
  get selectElClass() {
    const str = 'absolute inset-0 w-full pl-16 overflow-hidden outline-none appearance-none bg-transparent cursor-pointer disabled:cursor-auto';
    return str;
  }
  get labelClassNames() {
    let str = 'block pointer-events-none';
    if (this.floatLabel) {
      str += ' absolute mt-0 left-12 px-4';
      if (this.dense)
        str += ' dense text-4';
      if (this.isFocused || this.hasValue)
        str += ' floating';
    }
    else {
      str += ' subtitle2 mb-4';
    }
    return (str += ' ' + this.labelClass);
  }
  get iconSuffixClass() {
    const str = 'icon-suffix absolute flex items-center h-full right-12 space-x-8 pointer-events-none';
    return str;
  }
  get iconEl() {
    let icon = h("i", { "data-testid": "arrow", class: "mds-arrow-triangle-down text-icon" });
    if (this.error)
      icon = h("i", { "data-testid": "error-icon", class: "mds-warning-circle text-icon" });
    return icon;
  }
  render() {
    const labelJsx = (h("label", { htmlFor: this.selectId || this.uuid, class: this.labelClassNames }, this.label));
    return (h(Host, { class: 'mx-select block text-3' + (this.disabled ? ' disabled' : '') }, this.label && !this.floatLabel && labelJsx, h("div", { "data-testid": "select-wrapper", class: this.selectWrapperClass }, h("select", Object.assign({ "aria-label": this.elAriaLabel || this.label, autoFocus: this.autofocus, class: this.selectElClass, disabled: this.disabled, id: this.selectId || this.uuid, name: this.name, onFocus: this.onFocus.bind(this), onBlur: this.onBlur.bind(this), onInput: this.onInput.bind(this), ref: el => (this.selectElem = el) }, this.dataAttributes), h("slot", null)), this.label && this.floatLabel && labelJsx, h("span", { class: this.iconSuffixClass }, this.suffix && h("span", { class: "suffix flex items-center h-full px-4" }, this.suffix), this.iconEl)), this.assistiveText && h("div", { class: "assistive-text caption1 mt-4 ml-16" }, this.assistiveText)));
  }
  get element() { return this; }
  static get watchers() { return {
    "value": ["onValueChange"]
  }; }
}, [4, "mx-select", {
    "assistiveText": [1, "assistive-text"],
    "autofocus": [4],
    "dense": [4],
    "disabled": [4],
    "elevated": [4],
    "flat": [4],
    "label": [1],
    "floatLabel": [4, "float-label"],
    "elAriaLabel": [1, "el-aria-label"],
    "selectClass": [1, "select-class"],
    "selectId": [1, "select-id"],
    "name": [1],
    "suffix": [1],
    "error": [1540],
    "labelClass": [1025, "label-class"],
    "value": [1032],
    "isFocused": [32]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["mx-select"];
  components.forEach(tagName => { switch (tagName) {
    case "mx-select":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, MxSelect);
      }
      break;
  } });
}

export { MxSelect as M, defineCustomElement as d };

//# sourceMappingURL=mx-select2.js.map