import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { u as uuidv4 } from './utils.js';
import { d as defineCustomElement$2 } from './mx-button2.js';

const MxSelectionCard$1 = proxyCustomElement(class MxSelectionCard extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.mxSelect = createEvent(this, "mxSelect", 7);
    this.uuid = uuidv4();
    this.description = undefined;
    this.disabled = false;
    this.elAriaLabel = undefined;
    this.imageUrl = undefined;
    this.label = undefined;
    this.selected = false;
    this.value = undefined;
  }
  toggle() {
    if (this.disabled)
      return;
    this.selected = !this.selected;
    this.mxSelect.emit(this.selected);
  }
  get hostClass() {
    let str = 'mx-selection-card flex items-center justify-center relative p-20 border rounded-sm transform';
    if (this.selected) {
      str += ' selected shadow-drop -translate-y-2';
    }
    else {
      str += ' hover:shadow-drop hover:-translate-y-2';
    }
    return str;
  }
  render() {
    return (h(Host, { class: this.hostClass }, this.selected && (h("i", { class: "selection-card-checked mds-check-circle text-3 absolute top-30 right-30", role: "presentation", "data-testid": "check" })), h("div", { class: "flex flex-col items-center" }, h("div", { class: "h-60", "data-testid": "image" }, h("slot", { name: "image" }, this.imageUrl && h("img", { src: this.imageUrl, alt: "" }))), h("p", { class: "selection-card-label my-0 mt-40", id: this.uuid + '-label', "data-testid": "label" }, h("slot", { name: "label" }, this.label)), h("div", { class: "my-0 mt-20 mb-40 flex-1 text-center leading-tight tracking-0-4", id: this.uuid + '-description', "data-testid": "description" }, h("slot", { name: "description" }, this.description)), h("mx-button", { class: "selection-card-button", disabled: this.disabled, "el-aria-label": this.elAriaLabel, "el-aria-labelledby": this.uuid + '-label', "el-aria-describedby": this.uuid + '-description', "el-aria-pressed": this.selected ? 'true' : 'false', onClick: this.toggle.bind(this) }, this.selected ? 'Selected' : 'Select'))));
  }
}, [4, "mx-selection-card", {
    "description": [1],
    "disabled": [4],
    "elAriaLabel": [1, "el-aria-label"],
    "imageUrl": [1, "image-url"],
    "label": [1],
    "selected": [1540],
    "value": [1]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["mx-selection-card", "mx-button"];
  components.forEach(tagName => { switch (tagName) {
    case "mx-selection-card":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, MxSelectionCard$1);
      }
      break;
    case "mx-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const MxSelectionCard = MxSelectionCard$1;
const defineCustomElement = defineCustomElement$1;

export { MxSelectionCard, defineCustomElement };

//# sourceMappingURL=mx-selection-card.js.map