import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { d as defineCustomElement$1 } from './mx-badge2.js';

const MxTab = proxyCustomElement(class MxTab extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.label = '';
    this.elAriaLabel = '';
    this.icon = '';
    this.selected = false;
    this.badge = false;
    this.badgeClass = '';
    this.elRole = 'tab';
    this.href = null;
    this.target = null;
    this.nav = false;
  }
  componentDidLoad() {
    if (!this.label && !this.elAriaLabel) {
      throw new Error('Please provide either a label or an aria-label for each tab.');
    }
  }
  get labelClass() {
    let str = 'flex whitespace-nowrap items-center uppercase my-0 gap-x-6';
    str += this.nav ? ' text-body' : ' text-small';
    return str;
  }
  get badgeEl() {
    return h("mx-badge", { indicator: true, badgeClass: ['w-8 h-8', this.badgeClass].join(' ') });
  }
  render() {
    const Tag = this.href ? 'a' : 'button';
    return (h(Host, { class: "mx-tab relative inline-flex items-center justify-center min-w-0 h-60" }, h(Tag, { role: this.href ? null : this.elRole, type: this.href ? null : 'button', href: this.href, target: this.target, "aria-selected": this.selected && !this.href ? 'true' : null, "aria-label": this.elAriaLabel || this.label, class: "relative flex items-center justify-center overflow-hidden w-full h-full" }, h("span", { class: this.labelClass }, this.badge && this.badgeEl, h("span", { class: "tracking-0-3 font-bold" }, this.label), this.icon && h("i", { class: this.icon + ' text-icon' }))), h("span", { class: 'active-tab-indicator absolute bottom-0 left-0 w-full h-2 pointer-events-none' +
        (this.selected ? '' : ' opacity-0') })));
  }
  get element() { return this; }
}, [0, "mx-tab", {
    "label": [1],
    "elAriaLabel": [1, "el-aria-label"],
    "icon": [1],
    "selected": [516],
    "badge": [4],
    "badgeClass": [1, "badge-class"],
    "elRole": [1, "el-role"],
    "href": [8],
    "target": [8],
    "nav": [516]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["mx-tab", "mx-badge"];
  components.forEach(tagName => { switch (tagName) {
    case "mx-tab":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, MxTab);
      }
      break;
    case "mx-badge":
      if (!customElements.get(tagName)) {
        defineCustomElement$1();
      }
      break;
  } });
}

export { MxTab as M, defineCustomElement as d };

//# sourceMappingURL=mx-tab2.js.map