import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { c as createPopover } from './popover.js';
import { c as fadeIn, a as fadeOut } from './transitions.js';
import { u as uuidv4 } from './utils.js';

const MxTooltip$1 = proxyCustomElement(class MxTooltip extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.uuid = uuidv4();
    this.appearDelay = 0;
    this.extended = false;
    this.inverted = false;
    this.maxWidth = '10rem';
    this.isOpen = false;
    this.placement = 'bottom';
    this.tooltipClass = undefined;
    this.value = undefined;
  }
  onIsOpenChange() {
    this.isOpen ? this.show() : this.hide();
  }
  componentDidLoad() {
    let anchorEl = this.element.firstElementChild;
    anchorEl = this.element.querySelector('a, button, input, [role="button"]') || anchorEl;
    anchorEl.setAttribute('aria-describedby', this.uuid);
    anchorEl.addEventListener('mouseenter', this.show.bind(this));
    anchorEl.addEventListener('mouseleave', this.hide.bind(this));
    if (anchorEl.tabIndex === -1)
      anchorEl.tabIndex = 0;
    anchorEl.addEventListener('focus', this.show.bind(this));
    anchorEl.addEventListener('blur', this.hide.bind(this));
  }
  async show() {
    clearTimeout(this.openTimeout);
    if (this.isOpen)
      return;
    this.openTimeout = setTimeout(async () => {
      this.isOpen = true;
      this.popoverInstance = await createPopover(this.element.firstElementChild, this.tooltipElem, this.placement, [0, 4]);
      fadeIn(this.tooltipElem);
    }, this.appearDelay);
  }
  async hide() {
    clearTimeout(this.openTimeout);
    if (!this.isOpen)
      return;
    await fadeOut(this.tooltipElem);
    this.isOpen = false;
    if (!this.popoverInstance)
      return;
    this.popoverInstance.destroy();
    this.popoverInstance = null;
  }
  get tooltipClasses() {
    let str = 'mx-tooltip caption1 absolute pointer-events-none z-50';
    if (!this.isOpen)
      str += ' hidden';
    if (this.inverted)
      str += ' inverted';
    if (this.extended) {
      str += ' p-16 rounded shadow-4';
    }
    else {
      str += ' px-12 py-4 rounded';
    }
    if (this.tooltipClass)
      str += ' ' + this.tooltipClass;
    return str;
  }
  render() {
    return (h(Host, { class: "inline-flex" }, h("slot", null), h("div", { ref: el => (this.tooltipElem = el), id: this.uuid, role: "tooltip", class: this.tooltipClasses, style: { maxWidth: this.maxWidth }, "data-testid": "tooltip" }, h("slot", { name: "tooltip" }, this.value))));
  }
  get element() { return this; }
  static get watchers() { return {
    "isOpen": ["onIsOpenChange"]
  }; }
}, [4, "mx-tooltip", {
    "appearDelay": [2, "appear-delay"],
    "extended": [4],
    "inverted": [4],
    "maxWidth": [1, "max-width"],
    "isOpen": [1540, "is-open"],
    "placement": [1],
    "tooltipClass": [1, "tooltip-class"],
    "value": [1]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["mx-tooltip"];
  components.forEach(tagName => { switch (tagName) {
    case "mx-tooltip":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, MxTooltip$1);
      }
      break;
  } });
}

const MxTooltip = MxTooltip$1;
const defineCustomElement = defineCustomElement$1;

export { MxTooltip, defineCustomElement };

//# sourceMappingURL=mx-tooltip.js.map