import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { M as MinWidths, m as minWidthSync } from './minWidthSync.js';
import { d as defineCustomElement$8 } from './mx-badge2.js';
import { d as defineCustomElement$7 } from './mx-checkbox2.js';
import { d as defineCustomElement$6 } from './mx-menu2.js';
import { d as defineCustomElement$5 } from './mx-menu-item2.js';
import { d as defineCustomElement$4 } from './mx-select2.js';
import { d as defineCustomElement$3 } from './mx-tab2.js';
import { d as defineCustomElement$2 } from './mx-tabs2.js';

const MxTopNav$1 = proxyCustomElement(class MxTopNav extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.mxChange = createEvent(this, "mxChange", 7);
    this.mxSearch = createEvent(this, "mxSearch", 7);
    this.hasAvatar = false;
    this.searchLoading = false;
    this.searchForm = undefined;
    this.searchId = undefined;
    this.searchName = undefined;
    this.searchPlaceholder = 'Search';
    this.searchValue = undefined;
    this.selectedTabIndex = null;
    this.showSearch = true;
    this.tabs = undefined;
    this.minWidths = new MinWidths();
    this.isSearchFocused = false;
    this.extendSearch = false;
    this.isMenuOpen = false;
  }
  connectedCallback() {
    minWidthSync.subscribeComponent(this);
  }
  componentDidLoad() {
    if (this.mxTabs)
      this.mxTabs.menuButton = this.menuButton;
    this.setExtendSearch();
    new ResizeObserver(() => this.setExtendSearch()).observe(this.element);
  }
  componentWillRender() {
    this.hasAvatar = !!this.element.querySelector('[slot="avatar"]');
  }
  disconnectedCallback() {
    minWidthSync.unsubscribeComponent(this);
  }
  setExtendSearch() {
    const leftWrapperWidth = this.leftWrapper.offsetWidth;
    const headerWidth = this.leftWrapper.querySelector('header').scrollWidth;
    const availableWidth = leftWrapperWidth - headerWidth;
    this.extendSearch = availableWidth < 250;
  }
  onSearchClick() {
    if (document.activeElement !== this.searchInput) {
      this.searchInput.focus();
    }
    else {
      this.searchLoading = false;
    }
  }
  onSearchKeydown(e) {
    if (e.key === 'Enter' && this.searchInput.value.trim()) {
      this.searchLoading = true;
      this.mxSearch.emit(this.searchInput.value.trim());
    }
  }
  get searchClass() {
    let str = 'top-nav-search';
    if (this.isSearchFocused)
      str += ' search-focused';
    if (this.extendSearch)
      str += ' extend-search';
    return str;
  }
  render() {
    return (h(Host, { class: "mx-top-nav relative flex h-60" }, h("div", { ref: el => (this.leftWrapper = el), class: "flex flex-1 relative items-stretch overflow-hidden" }, h("header", { class: "flex flex-shrink-0 pl-20 items-center overflow-hidden" }, h("slot", { name: "header" })), h("nav", { class: 'flex-grow pl-80 overflow-hidden' + (!this.showSearch ? ' pr-20' : '') }, this.tabs && this.tabs.length && (h("mx-tabs", { ref: el => (this.mxTabs = el), nav: true, tabs: this.tabs, value: this.selectedTabIndex, onMxChange: e => this.mxChange.emit(e.detail), onMxMenuOpen: () => (this.isMenuOpen = true), onMxMenuClose: () => (this.isMenuOpen = false) }, h("slot", { name: "menu", slot: "menu" })))), this.showSearch && (h("div", { class: "top-nav-search-placeholder flex-shrink-0" })), this.showSearch && (h("div", { class: this.searchClass }, h("input", { ref: el => (this.searchInput = el), id: this.searchId, type: "search", placeholder: this.searchPlaceholder, name: this.searchName, value: this.searchValue, form: this.searchForm, onFocus: () => (this.isSearchFocused = true), onBlur: () => (this.isSearchFocused = false), onKeyDown: this.onSearchKeydown.bind(this) }), h("button", { tabindex: "-1", class: "absolute left-0 flex h-60 w-60 items-center justify-center", onClick: () => this.onSearchClick() }, this.searchLoading && this.isSearchFocused ? (h("svg", { class: "top-nav-search-spinner w-14 h-14", viewBox: "0 0 18 18", fill: "none", xmlns: "http://www.w3.org/2000/svg", "data-testid": "search-spinner" }, h("path", { d: "M17 9C17 4.58172 13.4183 1 9 1C4.58172 1 1 4.58172 1 9C1 13.4183 4.58172 17 9 17", "stroke-width": "2", "stroke-linecap": "round" }))) : (h("i", { class: "mds-search text-2" })))))), this.tabs && this.tabs.length && (h("button", { ref: el => (this.menuButton = el), "aria-label": "Show navigation menu", class: 'hidden h-60 w-60 flex-shrink-0 items-center justify-center leading-none' +
        (this.isMenuOpen ? ' menu-open' : '') }, h("i", { class: "mds-list text-2" }))), this.hasAvatar && (h("div", { class: "hidden h-60 w-60 sm:flex flex-shrink-0", "data-testid": "avatar" }, h("slot", { name: "avatar" })))));
  }
  get element() { return this; }
}, [4, "mx-top-nav", {
    "searchLoading": [1540, "search-loading"],
    "searchForm": [1, "search-form"],
    "searchId": [1, "search-id"],
    "searchName": [1, "search-name"],
    "searchPlaceholder": [1, "search-placeholder"],
    "searchValue": [1, "search-value"],
    "selectedTabIndex": [2, "selected-tab-index"],
    "showSearch": [4, "show-search"],
    "tabs": [16],
    "minWidths": [32],
    "isSearchFocused": [32],
    "extendSearch": [32],
    "isMenuOpen": [32]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["mx-top-nav", "mx-badge", "mx-checkbox", "mx-menu", "mx-menu-item", "mx-select", "mx-tab", "mx-tabs"];
  components.forEach(tagName => { switch (tagName) {
    case "mx-top-nav":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, MxTopNav$1);
      }
      break;
    case "mx-badge":
      if (!customElements.get(tagName)) {
        defineCustomElement$8();
      }
      break;
    case "mx-checkbox":
      if (!customElements.get(tagName)) {
        defineCustomElement$7();
      }
      break;
    case "mx-menu":
      if (!customElements.get(tagName)) {
        defineCustomElement$6();
      }
      break;
    case "mx-menu-item":
      if (!customElements.get(tagName)) {
        defineCustomElement$5();
      }
      break;
    case "mx-select":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "mx-tab":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "mx-tabs":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const MxTopNav = MxTopNav$1;
const defineCustomElement = defineCustomElement$1;

export { MxTopNav, defineCustomElement };

//# sourceMappingURL=mx-top-nav.js.map