import { r as registerInstance, c as createEvent, h, H as Host, g as getElement } from './index-b37ad95b.js';

const MxAutocomplete = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.mxSelect = createEvent(this, "mxSelect", 7);
    this.mxClear = createEvent(this, "mxClear", 7);
    this.filterOptions = false;
    this.inputTag = 'mx-block-input';
    this.optionGroups = [];
    this.optionIcon = undefined;
    this.optionLabel = undefined;
    this.options = undefined;
    this.setValueOnSelect = false;
    this.assistiveText = undefined;
    this.autofocus = false;
    this.colspan = undefined;
    this.disabled = false;
    this.error = false;
    this.inputId = undefined;
    this.label = 'Search';
    this.maxlength = undefined;
    this.name = undefined;
    this.placeholder = undefined;
    this.readonly = false;
    this.type = 'search';
    this.value = undefined;
    this.isFocused = false;
  }
  async componentDidLoad() {
    await new Promise(requestAnimationFrame);
    this.menuEl.anchorEl = this.inputEl;
  }
  get filterFunction() {
    if (typeof this.filterOptions === 'function')
      return this.filterOptions;
    return this.defaultFilter;
  }
  get visibleOptions() {
    if (!this.options)
      return [];
    if (!this.filterOptions)
      return this.options;
    const filtered = [];
    this.options.forEach(option => {
      var _a;
      if (Array.isArray(option))
        filtered.push(option.filter(o => { var _a; return this.filterFunction(((_a = this.value) === null || _a === void 0 ? void 0 : _a.trim()) || '', o); }));
      if (this.filterFunction(((_a = this.value) === null || _a === void 0 ? void 0 : _a.trim()) || '', option))
        filtered.push(option);
    });
    return filtered;
  }
  get showNoResults() {
    var _a;
    return ((_a = this.value) === null || _a === void 0 ? void 0 : _a.trim()) && this.visibleOptions.length === 0;
  }
  async onSelect(option) {
    this.mxSelect.emit(option);
    this.menuEl.addEventListener('mxClose', async () => {
      await new Promise(requestAnimationFrame);
      await new Promise(requestAnimationFrame);
      this.inputEl.value = this.setValueOnSelect ? this.getOptionLabel(option) : '';
      this.inputEl.dispatchEvent(new window.Event('input', { cancelable: true, bubbles: true }));
      this.inputEl.querySelector('input').focus();
    }, { once: true });
  }
  defaultFilter(value, option) {
    const optionLabel = this.getOptionLabel(option);
    if (!optionLabel)
      return false;
    if (!(value === null || value === void 0 ? void 0 : value.trim()))
      return true;
    return optionLabel.toLowerCase().includes(value.trim().toLowerCase());
  }
  renderOption(option, index) {
    if (!option)
      return;
    if (!Array.isArray(option))
      return this.renderOptionItem(option);
    if (option.length)
      return this.renderOptionGroup(option, index);
  }
  renderOptionItem(option) {
    return (h("mx-menu-item", { icon: this.getOptionIcon(option), onClick: () => this.onSelect(option) }, this.getOptionLabel(option)));
  }
  renderOptionGroup(option, index) {
    return (h("div", { role: "group" }, this.optionGroups[index] && (h("p", { role: "heading", "aria-level": "2" }, this.optionGroups[index])), option.map(o => this.renderOption(o))));
  }
  getOptionLabel(option) {
    if (typeof this.optionLabel === 'function')
      return this.optionLabel(option);
    if (typeof option === 'object' && typeof this.optionLabel === 'string')
      return option[this.optionLabel];
    return option === null || option === void 0 ? void 0 : option.toString();
  }
  getOptionIcon(option) {
    if (!this.optionIcon)
      return;
    if (typeof this.optionIcon === 'string')
      return this.optionIcon;
    if (typeof this.optionIcon === 'function')
      return this.optionIcon(option);
  }
  render() {
    const Tag = this.inputTag;
    return (h(Host, { class: "mx-block-search contents" }, h(Tag, { ref: el => (this.inputEl = el), type: this.type, assistiveText: this.assistiveText, autofocus: this.autofocus, colspan: this.colspan, disabled: this.disabled, error: this.error, inputId: this.inputId, maxlength: this.maxlength, label: this.label, name: this.name, placeholder: this.placeholder, readonly: this.readonly, value: this.value, onInput: (e) => (this.value = e.target.value), onMxClear: this.mxClear.emit.bind(this) }, h("slot", { name: "label", slot: "label" })), h("mx-menu", { offset: [0, 10], ref: el => (this.menuEl = el), squared: true, autocompleteOnly: true }, this.showNoResults && (h("mx-menu-item", { disabled: true }, h("span", { class: "text-primary", "data-test": "no-results" }, "No matching results"))), this.visibleOptions.map(this.renderOption.bind(this)))));
  }
  get element() { return getElement(this); }
};

export { MxAutocomplete as mx_autocomplete };

//# sourceMappingURL=mx-autocomplete.entry.js.map