import { r as registerInstance, h, H as Host, g as getElement } from './index-b37ad95b.js';

const MxAvatar = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.icon = '';
    this.imageUrl = '';
    this.fullName = '';
  }
  get avatarType() {
    if (this.imageUrl.trim())
      return 'image';
    if (this.icon.trim())
      return 'icon';
    if (this.fullName.trim())
      return 'monogram';
  }
  get initials() {
    if (this.avatarType !== 'monogram')
      return '';
    const names = this.fullName.trim().split(' ');
    if (names.length === 1)
      return names[0].charAt(0);
    return names[0].charAt(0) + names[names.length - 1].charAt(0);
  }
  connectedCallback() {
    if (!this.avatarType)
      console.error('mx-avatar requires either an image, icon, or full name.');
    if (this.fullName && !this.element.getAttribute('aria-label'))
      this.element.setAttribute('aria-label', this.fullName);
  }
  render() {
    return (h(Host, { class: 'mx-avatar avatar-' + this.avatarType }, this.avatarType == 'image' && h("img", { src: this.imageUrl.trim(), alt: "", class: "w-full h-full object-cover" }), this.avatarType == 'icon' && h("i", { class: this.icon.trim(), role: "presentation" }), this.avatarType == 'monogram' && h("div", { class: "truncate uppercase" }, this.initials)));
  }
  get element() { return getElement(this); }
};

export { MxAvatar as mx_avatar };

//# sourceMappingURL=mx-avatar.entry.js.map