import { r as registerInstance, h, H as Host, g as getElement } from './index-b37ad95b.js';
import { u as uuidv4, p as propagateDataAttributes } from './utils-c62bee0c.js';

const MxBlockSelect = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.dataAttributes = {};
    this.uuid = uuidv4();
    this.componentWillRender = propagateDataAttributes;
    this.assistiveText = undefined;
    this.autofocus = false;
    this.colspan = undefined;
    this.disabled = false;
    this.error = false;
    this.inputId = undefined;
    this.label = undefined;
    this.name = undefined;
    this.placeholder = undefined;
    this.readonly = false;
    this.type = 'text';
    this.value = undefined;
    this.isFocused = false;
    this.characterCount = 0;
  }
  componentDidLoad() {
    this.updateValue();
    this.attachMenu();
  }
  onValueChange() {
    this.updateValue();
  }
  async onClick(e) {
    this.menu.style.width = this.containerElement.getBoundingClientRect().width + 'px';
    const clickedMenuItem = e.target.closest('mx-menu-item');
    if (!clickedMenuItem)
      return;
    this.value = await clickedMenuItem.getValue();
    this.textInput.dispatchEvent(new Event('input', { bubbles: true, cancelable: true }));
  }
  updateValue() {
    this.textInput.value = this.hasValue ? this.value : '';
  }
  onFocus() {
    this.isFocused = true;
    this.error = false;
  }
  onBlur() {
    if (this.menu && this.menu.isOpen)
      return;
    this.isFocused = false;
  }
  onContainerClick() {
    if (!this.disabled && !this.readonly)
      this.textInput.focus();
  }
  onInput(e) {
    this.characterCount = e.target.value.length;
    this.value = e.target.value;
  }
  onMenuClose(e) {
    e.stopPropagation();
    if (!this.textInput.contains(document.activeElement))
      this.isFocused = false;
  }
  attachMenu() {
    if (!this.disabled && !this.readonly)
      this.menu.anchorEl = this.containerElement;
    else
      this.menu.anchorEl = undefined;
  }
  get hasValue() {
    return this.value !== null && this.value !== '' && this.value !== undefined;
  }
  get hostClass() {
    let str = 'mx-block-input';
    if (this.colspan > 0 && this.colspan < 7) {
      str += ' col-span-' + this.colspan;
    }
    return str;
  }
  get containerClass() {
    let str = 'mx-block-input-container';
    if (this.disabled)
      str += ' disabled';
    if (this.error)
      str += ' error';
    return str;
  }
  render() {
    return (h(Host, { class: this.hostClass }, h("div", { class: this.containerClass, onClick: this.onContainerClick.bind(this), ref: el => (this.containerElement = el) }, h("div", { class: "mx-block-input-grid" }, h("label", { class: "text-small", htmlFor: this.inputId || this.uuid }, this.label, h("slot", { name: "label" }), this.assistiveText && h("span", { id: this.inputId || this.uuid + '-assistive' }, this.assistiveText)), h("input", Object.assign({ "aria-describedby": this.assistiveText ? (this.inputId || this.uuid) + '-assistive' : null, autofocus: this.autofocus, disabled: this.disabled, id: this.inputId || this.uuid, name: this.name, onBlur: this.onBlur.bind(this), onFocus: this.onFocus.bind(this), onInput: this.onInput.bind(this), placeholder: this.placeholder, readonly: !this.disabled, ref: el => (this.textInput = el), type: this.type, value: this.value }, this.dataAttributes)), h("i", { class: "dropdown-icon mds-chevron-down text-icon" }))), h("mx-menu", { ref: el => (this.menu = el), placement: "bottom", offset: [0, 10], onMxClose: this.onMenuClose.bind(this), squared: true }, h("slot", null))));
  }
  get element() { return getElement(this); }
  static get watchers() { return {
    "value": ["onValueChange"]
  }; }
};

export { MxBlockSelect as mx_block_select };

//# sourceMappingURL=mx-block-select.entry.js.map