import { r as registerInstance, h, H as Host, g as getElement, c as createEvent } from './index-b37ad95b.js';
import { d as getScrollingParent, e as getBounds, a as getCursorCoords, g as getPageRect, f as isScrolledOutOfView } from './utils-c62bee0c.js';
import { d as collapse, e as expand } from './transitions-ed8f0c75.js';

const MxLinearProgress = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.value = null;
    this.simulateProgressDuration = null;
    this.appearDelay = 0;
  }
  simulateProgress() {
    clearInterval(this.simulateProgressInterval);
    if (!this.simulateProgressDuration)
      return;
    this.simulateProgressInterval = setInterval(() => {
      if (this.value === 100)
        return;
      this.value = Math.min((this.value || 0) + 1, 99);
    }, this.simulateProgressDuration / 100);
  }
  connectedCallback() {
    this.simulateProgress();
    if (!this.appearDelay)
      return;
    this.element.classList.remove('block');
    this.element.classList.add('hidden');
    this.delayTimeout = setTimeout(() => {
      this.element.classList.remove('hidden');
      this.element.classList.add('block');
    }, this.appearDelay);
  }
  disconnectedCallback() {
    clearTimeout(this.delayTimeout);
  }
  get determinateBarStyle() {
    return {
      transform: `translateX(${this.value - 100}%)`,
      transition: 'transform 0.4s linear',
    };
  }
  render() {
    return (h(Host, { class: "mx-linear-progress block h-4 w-full rounded-sm overflow-hidden pointer-events-none", role: "progressbar", "aria-valuenow": this.value != null ? Math.round(this.value) : null, "aria-valuemin": this.value != null ? 0 : null, "aria-valuemax": this.value != null ? 100 : null }, h("div", { class: "relative h-full" }, this.value != null ? (h("div", { "data-testid": "determinate", class: "fill h-4 absolute inset-0 rounded-sm", style: this.determinateBarStyle })) : ([
      h("div", { "data-testid": "indeterminate1", class: "indeterminate1 absolute h-full w-full" }, h("div", { class: "fill absolute w-full h-full rounded-sm" })),
      h("div", { "data-testid": "indeterminate2", class: "indeterminate2 absolute h-full w-full" }, h("div", { class: "fill absolute w-full h-full rounded-sm" })),
    ]))));
  }
  get element() { return getElement(this); }
  static get watchers() { return {
    "simulateProgressDuration": ["simulateProgress"]
  }; }
};

const MAX_PAGE_BUTTONS = 5;
const MxPagination = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.mxPageChange = createEvent(this, "mxPageChange", 7);
    this.breakpoint = 0;
    this.page = 1;
    this.rowsPerPageOptions = [10, 25, 50, 100];
    this.rowsPerPage = 100;
    this.totalRows = undefined;
    this.disabled = false;
    this.disableNextPage = false;
    this.hideRangeAndRowsPerPage = false;
  }
  componentDidLoad() {
    if (this.rowsMenu && this.rowsMenuAnchor)
      this.rowsMenu.anchorEl = this.rowsMenuAnchor;
    this.setBreakpoint();
    this.resizeObserver = new ResizeObserver(() => this.updateResponsiveElements());
    this.resizeObserver.observe(this.element);
  }
  async setBreakpoint() {
    this.hideRangeAndRowsPerPage = false;
    await new Promise(requestAnimationFrame);
    this.breakpoint = Array.from(this.element.children).reduce((total, child) => {
      return total + child.scrollWidth;
    }, 0);
    this.updateResponsiveElements();
  }
  updateResponsiveElements() {
    this.hideRangeAndRowsPerPage = this.element.scrollWidth < this.breakpoint;
  }
  onClickFirstPage() {
    if (this.isPreviousPageDisabled)
      return;
    this.mxPageChange.emit({ page: 1, rowsPerPage: this.rowsPerPage });
  }
  onClickPreviousPage() {
    if (this.isPreviousPageDisabled)
      return;
    this.mxPageChange.emit({ page: this.page - 1, rowsPerPage: this.rowsPerPage });
  }
  onClickPageNumber(page) {
    if (page === this.page)
      return;
    this.mxPageChange.emit({ page, rowsPerPage: this.rowsPerPage });
  }
  onClickNextPage() {
    if (this.isNextPageDisabled)
      return;
    this.mxPageChange.emit({ page: this.page + 1, rowsPerPage: this.rowsPerPage });
  }
  onClickLastPage() {
    if (this.isLastPageDisabled)
      return;
    this.mxPageChange.emit({ page: this.lastPage, rowsPerPage: this.rowsPerPage });
  }
  onChangeRowsPerPage(rowsPerPage) {
    this.mxPageChange.emit({ page: 1, rowsPerPage });
  }
  get isPreviousPageDisabled() {
    return this.page === 1 || this.disabled;
  }
  get isNextPageDisabled() {
    return this.page === this.lastPage || this.disabled || this.disableNextPage;
  }
  get isFirstPageDisabled() {
    return this.page === 1 || this.disabled;
  }
  get isLastPageDisabled() {
    return this.totalRows == null || this.page === this.lastPage || this.disabled;
  }
  get lastPage() {
    if (this.totalRows === 0)
      return 1;
    if (this.totalRows == null)
      return null;
    return Math.ceil(this.totalRows / this.rowsPerPage);
  }
  get pageNumbers() {
    const length = Math.min(MAX_PAGE_BUTTONS, this.lastPage);
    if (this.page <= MAX_PAGE_BUTTONS)
      return Array.from({ length }, (_, i) => i + 1);
    if (this.page > this.lastPage - MAX_PAGE_BUTTONS) {
      return Array.from({ length }, (_, i) => this.lastPage - MAX_PAGE_BUTTONS + i + 1);
    }
    const start = this.page - Math.floor(MAX_PAGE_BUTTONS / 2);
    return Array.from({ length }, (_, i) => start + i);
  }
  get currentRange() {
    const start = this.rowsPerPage * (this.page - 1) + 1;
    const end = Math.min(this.totalRows, start + this.rowsPerPage - 1);
    return start + '–' + end;
  }
  get pageNumberGridStyle() {
    return {
      gridTemplateColumns: `repeat(${Math.min(this.lastPage, MAX_PAGE_BUTTONS)}, 1fr)`,
    };
  }
  render() {
    return (h(Host, { class: "mx-pagination relative flex items-center text-4 whitespace-nowrap select-none" }, h("nav", { "aria-label": "Page navigation", class: "flex items-center" }, h("button", { type: "button", "aria-label": "First page", disabled: this.isFirstPageDisabled, class: "underline mr-10", onClick: this.onClickFirstPage.bind(this) }, "First"), h("button", { type: "button", "aria-label": "Previous page", disabled: this.isPreviousPageDisabled, class: "pagination-icon-button text-icon", onClick: this.onClickPreviousPage.bind(this) }, h("i", { class: "mds-chevron-left" })), this.totalRows != null && (h("div", { class: "grid gap-10 ml-20", "data-testid": "page-numbers", style: this.pageNumberGridStyle }, this.pageNumbers.map(page => (h("button", { type: "button", class: "page-number-button", "aria-label": 'Page ' + page, disabled: this.page === page || this.disabled, "aria-current": this.page === page ? 'page' : null, onClick: this.onClickPageNumber.bind(this, page) }, page))))), h("button", { type: "button", "aria-label": "Next page", disabled: this.isNextPageDisabled, class: "pagination-icon-button text-icon ml-20", onClick: this.onClickNextPage.bind(this) }, h("i", { class: "mds-chevron-right" })), this.totalRows != null && (h("button", { type: "button", "aria-label": "Last page", disabled: this.isLastPageDisabled, class: "underline ml-10", onClick: this.onClickLastPage.bind(this) }, "Last"))), !this.hideRangeAndRowsPerPage && this.totalRows > 0 && (h("div", { "data-testid": "row-range", class: "text-center flex-shrink min-w-0 whitespace-nowrap pl-24" }, "Displaying ", this.currentRange, " of ", this.totalRows)), !this.hideRangeAndRowsPerPage && this.rowsPerPageOptions && this.rowsPerPageOptions.length > 1 && (h("div", { class: "flex pl-24 ml-auto" }, h("button", { type: "button", "data-testid": "rows-per-page", ref: el => (this.rowsMenuAnchor = el), class: "appearance-none flex gap-x-20 items-center cursor-pointer" }, h("span", { class: "text-small uppercase font-bold" }, "Rows per page"), h("span", null, this.rowsPerPage), h("i", { class: "mds-chevron-down text-1" })), h("mx-menu", { ref: el => (this.rowsMenu = el), onMxClose: e => e.stopPropagation() }, this.rowsPerPageOptions.map(option => (h("mx-menu-item", { disabled: this.disabled, onClick: this.onChangeRowsPerPage.bind(this, option) }, option))))))));
  }
  get element() { return getElement(this); }
  static get watchers() { return {
    "totalRows": ["setBreakpoint"],
    "rowsPerPage": ["setBreakpoint"],
    "rowsPerPageOptions": ["setBreakpoint"]
  }; }
};

const MxTableCell = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.columnIndex = undefined;
    this.heading = undefined;
  }
  render() {
    return (h(Host, { role: "gridcell", "aria-describedby": this.columnIndex != null ? `column-header-${this.columnIndex}` : null, class: "mx-table-cell flex flex-1 items-center min-w-min overflow-y-hidden" }, h("div", null, h("div", { class: "min-h-16 max-w-full whitespace-normal", role: this.columnIndex == null ? 'heading' : null, "aria-level": this.columnIndex == null ? '1' : null }, h("slot", null)))));
  }
  get element() { return getElement(this); }
};

const SCROLL_PX = 5;
const SCROLL_INTERVAL_MS = 5;
class DragScroller {
  constructor(dragEl) {
    this.scrollingContainer = getScrollingParent(dragEl);
  }
  update(e) {
    clearInterval(this.interval);
    const { clientX, clientY } = getCursorCoords(e);
    const bounds = getBounds(this.scrollingContainer);
    if (clientY >= bounds.top && clientY <= bounds.bottom && clientX >= bounds.left && clientX <= bounds.right)
      return;
    const directionX = clientX < bounds.left ? -1 : 1;
    const directionY = clientY < bounds.top ? -1 : 1;
    this.interval = setInterval(window.scrollBy, SCROLL_INTERVAL_MS, SCROLL_PX * directionX, SCROLL_PX * directionY);
  }
  stop() {
    clearInterval(this.interval);
  }
}

let rowAccordionDebounce;
const MxTableRow = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.mxCheck = createEvent(this, "mxCheck", 7);
    this.mxRowDragStart = createEvent(this, "mxRowDragStart", 7);
    this.mxRowDragEnd = createEvent(this, "mxRowDragEnd", 7);
    this.mxDragKeyDown = createEvent(this, "mxDragKeyDown", 7);
    this.mxRowAccordion = createEvent(this, "mxRowAccordion", 7);
    this.dragOrigin = { x: 0, y: 0 };
    this.indentLevel = 0;
    this.columnCount = 1;
    this.isHidden = false;
    this.rowId = undefined;
    this.actions = [];
    this.doNotCollapse = false;
    this.doNotDrag = false;
    this.rowIndex = undefined;
    this.checked = false;
    this.collapseNestedRows = false;
    this.subheader = false;
    this.checkable = false;
    this.checkOnRowClick = false;
    this.isDraggable = false;
    this.isDragging = false;
  }
  onCollapseNestedRowsChange() {
    this.toggleNestedRows();
  }
  async translateRow(x, y) {
    const transform = `translate3d(${x}px, ${y}px, 0)`;
    if (this.dragShadowEl)
      this.dragShadowEl.style.transform = transform;
    (await this.getChildren()).forEach((child) => (child.style.transform = transform));
  }
  async toggle(hideRow, skipTransition) {
    this.isHidden = hideRow;
    const children = await this.getChildren();
    const transition = this.isHidden ? collapse : expand;
    await Promise.all(children.map(child => transition(child, skipTransition ? 0 : undefined)));
    children.forEach(child => (child.style.border = this.isHidden ? '0' : ''));
    this.element.setAttribute('aria-hidden', this.isHidden ? 'true' : 'false');
  }
  connectedCallback() {
    if (this.actions.some(action => !action.value))
      throw new Error('Table row actions must have a value property!');
    this.setIndentLevel();
  }
  componentDidLoad() {
    if (this.collapseNestedRows)
      this.toggleNestedRows(true);
  }
  componentWillRender() {
    const table = this.element.closest('mx-table');
    this.checkable = table && table.checkable;
    this.isDraggable = table && table.draggableRows && !this.doNotDrag;
    this.columnCount = (table && table.columns.length) + (this.actions.length ? 1 : 0);
    if (this.checkable && this.rowId == null)
      throw new Error('Checkable rows require either a getRowId prop on the table, or a rowId on the row!');
    if (this.checkable)
      this.checkOnRowClick = table.checkOnRowClick;
  }
  componentDidRender() {
    if (this.actions.length > 1 && this.actionMenu && this.actionMenuButton)
      this.actionMenu.anchorEl = this.actionMenuButton;
    this.wrapFirstColumn();
    this.moveNestedRows();
  }
  setIndentLevel() {
    let parentRow = this.element.parentElement.closest('mx-table-row');
    this.indentLevel = 0;
    while (parentRow) {
      if (!parentRow.subheader)
        this.indentLevel++;
      parentRow = parentRow.parentElement.closest('mx-table-row');
    }
  }
  toggleNestedRows(skipTransition = false) {
    const nestedRows = Array.from(this.childRowWrapper.children).filter((row) => !row.doNotCollapse);
    nestedRows.forEach(async (row) => {
      row.toggle(this.collapseNestedRows, skipTransition);
    });
    clearTimeout(rowAccordionDebounce);
    rowAccordionDebounce = setTimeout(this.mxRowAccordion.emit, 200);
  }
  wrapFirstColumn() {
    if (this.firstCellTarget && this.firstCellTarget.parentNode) {
      const firstCell = this.element.querySelector('mx-table-cell');
      if (firstCell)
        this.firstCellTarget.parentNode.replaceChild(firstCell, this.firstCellTarget);
    }
  }
  moveNestedRows() {
    const nestedRows = Array.from(this.rowEl.children).filter(c => c.tagName === 'MX-TABLE-ROW');
    nestedRows.forEach(childRow => this.childRowWrapper.appendChild(childRow));
  }
  onClick(e) {
    if (e.target.closest('a, button, input, mx-menu'))
      return;
    if (this.checkable && this.checkOnRowClick) {
      this.checked = !this.checked;
      this.mxCheck.emit({ rowId: this.rowId, checked: this.checked });
    }
  }
  onMouseOver(e) {
    e.stopPropagation();
    const isDraggingChildRow = e.buttons > 0;
    if (!isDraggingChildRow)
      this.rowEl.classList.add('hovered-row');
  }
  onMouseOut(e) {
    e.stopPropagation();
    this.rowEl.classList.remove('hovered-row');
  }
  onKeyboardHandleKeyDown(e) {
    if (!this.isDragging && [' ', 'Enter'].includes(e.key))
      this.startDragging(e);
  }
  async startDragging(e) {
    e.stopPropagation();
    e.preventDefault();
    this.isDragging = true;
    if (e.type !== 'keydown') {
      const { pageX, pageY } = getCursorCoords(e);
      this.dragOrigin.x = pageX;
      this.dragOrigin.y = pageY;
    }
    else {
      const { top, left } = getPageRect(this.rowEl.children[0]);
      this.dragOrigin.x = left;
      this.dragOrigin.y = top;
    }
    this.rowEl.classList.add('pointer-events-none');
    this.createDragShadowEl();
    const children = await this.getChildren();
    for (let i = 0; i < children.length; i++) {
      const child = children[i];
      child.style.zIndex = '9999';
    }
    this.addDragListeners(e);
    this.mxRowDragStart.emit({ isKeyboard: e.type === 'keydown' });
  }
  addDragListeners(startEvent) {
    const onMouseMove = (e) => {
      requestAnimationFrame(() => {
        if (!this.isDragging)
          return;
        const { pageX, pageY } = getCursorCoords(e);
        const x = pageX - this.dragOrigin.x;
        const y = pageY - this.dragOrigin.y;
        this.translateRow(x, y);
        this.dragScroller && this.dragScroller.update(e);
      });
    };
    const onMouseUp = (e) => {
      e.stopPropagation();
      document.removeEventListener('mousemove', onMouseMove);
      document.removeEventListener('mouseup', onMouseUp);
      document.removeEventListener('touchmove', onMouseMove);
      document.removeEventListener('touchend', onMouseUp);
      document.removeEventListener('touchcancel', onMouseUp);
      this.dragScroller.stop();
      this.dragScroller = null;
      this.stopDragging(e.type === 'touchcancel');
    };
    const onKeyDown = (e) => {
      if ([' ', 'Enter'].includes(e.key)) {
        document.removeEventListener('keydown', onKeyDown);
        this.stopDragging(true);
      }
      else if (['Escape', 'Tab'].includes(e.key)) {
        document.removeEventListener('keydown', onKeyDown);
        this.stopDragging(true, true);
      }
      else if (e.key.includes('Arrow')) {
        this.mxDragKeyDown.emit(e.key);
      }
      else {
        return;
      }
      e.stopPropagation();
      e.preventDefault();
    };
    if (startEvent.type === 'keydown') {
      document.addEventListener('keydown', onKeyDown);
    }
    else if (startEvent.type === 'touchstart') {
      this.dragScroller = new DragScroller(this.rowEl);
      document.addEventListener('touchmove', onMouseMove);
      document.addEventListener('touchend', onMouseUp);
      document.addEventListener('touchcancel', onMouseUp);
    }
    else {
      this.dragScroller = new DragScroller(this.rowEl);
      document.addEventListener('mousemove', onMouseMove);
      document.addEventListener('mouseup', onMouseUp);
    }
  }
  async stopDragging(isKeyboard = false, isCancel = false) {
    this.isDragging = false;
    this.rowEl.classList.remove('drag-row', 'pointer-events-none');
    if (this.dragShadowEl)
      this.dragShadowEl.remove();
    this.dragShadowEl = undefined;
    const children = await this.getChildren();
    for (let i = 0; i < children.length; i++) {
      const child = children[i];
      child.style.transform = '';
      child.style.zIndex = '';
    }
    this.mxRowDragEnd.emit({ isKeyboard, isCancel });
  }
  async createDragShadowEl() {
    this.dragShadowEl = document.createElement('div');
    this.dragShadowEl.classList.add('absolute', 'w-full', 'shadow-24');
    this.dragShadowEl.style.zIndex = '9998';
    this.dragShadowEl.style.height = (await this.getHeight()) + 'px';
    const firstChild = (await this.getChildren())[0];
    this.dragShadowEl.style.top = firstChild.offsetTop + 'px';
    this.dragShadowEl.style.left = firstChild.offsetLeft + 'px';
    this.element.parentNode.insertBefore(this.dragShadowEl, this.element);
  }
  accordion() {
    return;
  }
  async focusDragHandle() {
    if (this.keyboardDragHandle)
      this.keyboardDragHandle.focus();
  }
  async getChildren() {
    const children = [];
    Array.from(this.rowEl.children).forEach(child => {
      if (!child.offsetParent)
        children.push(...Array.from(child.children));
      else
        children.push(child);
    });
    if (!this.collapseNestedRows) {
      const nestedRows = Array.from(this.childRowWrapper.children);
      await Promise.all(nestedRows.map(childRow => childRow.getChildren().then(grandchildren => children.push(...grandchildren))));
    }
    return children;
  }
  async getNestedRowIndexes() {
    const nestedRows = Array.from(this.childRowWrapper.children);
    return nestedRows.map((row) => row.rowIndex).filter(x => x != null);
  }
  async getHeight() {
    let height = (await this.getChildren())[0].offsetHeight;
    const nestedRows = Array.from(this.childRowWrapper.children);
    await Promise.all(nestedRows.map(childRow => childRow.getHeight().then(childHeight => (height += childHeight))));
    return height;
  }
  onTransitionEnd(e) {
    if (e.target === this.rowEl.children[0] && isScrolledOutOfView(this.rowEl.children[0]))
      this.rowEl.children[0].scrollIntoView();
  }
  onCheckboxInput(e) {
    this.mxCheck.emit({ rowId: this.rowId, checked: e.target.checked });
  }
  get rowEl() {
    return this.element.firstElementChild;
  }
  get rowClass() {
    let str = 'table-row';
    str += ' contents';
    if (this.checkable)
      str += ' checkable-row';
    if (this.checkable && this.checkOnRowClick)
      str += ' cursor-pointer';
    if (this.subheader)
      str += ' subheader overline2';
    return str;
  }
  get indentStyle() {
    return { width: 3.75 * this.indentLevel + 'rem' };
  }
  render() {
    return (h(Host, { class: "mx-table-row contents" }, h("div", { role: "row", class: this.rowClass, onClick: this.onClick.bind(this), onTransitionEnd: this.onTransitionEnd.bind(this), onMouseOver: this.onMouseOver.bind(this), onMouseOut: this.onMouseOut.bind(this) }, h("div", { class: 'first-column-wrapper flex items-center min-w-min overflow-hidden' +
        (this.subheader ? ' col-span-full pr-0' : '') }, h("div", { class: "table-row-indent flex items-center justify-center h-full", style: this.indentStyle, "data-testid": 'indent-' + this.indentLevel }, h("svg", { class: "stroke-current", width: "14", height: "18", viewBox: "0 0 14 18", fill: "none", xmlns: "http://www.w3.org/2000/svg" }, h("path", { d: "M9 9L13 13L9 17", "stroke-linecap": "round", "stroke-linejoin": "round" }), h("path", { d: "M1 1V13H13", "stroke-linecap": "round", "stroke-linejoin": "round" }))), this.checkable && (h("div", { class: "flex items-center pr-4 row-start-auto col-start-auto", onClick: this.accordion.bind(this) }, h("mx-checkbox", { ref: el => (this.checkbox = el), checked: this.checked, onInput: this.onCheckboxInput.bind(this), onClick: e => e.stopPropagation(), "label-name": "Select row", "hide-label": true }))), this.isDraggable && (h("div", { class: "drag-handle flex items-center row-start-auto col-start-auto cursor-move", "data-testid": "drag-handle", onMouseDown: this.startDragging.bind(this), onTouchStart: this.startDragging.bind(this) }, h("i", { "aria-label": "Press Space or Enter to move this row", ref: el => (this.keyboardDragHandle = el), role: "button", tabindex: "0", class: 'mds-drag-dots text-3 pointer-events-none' + (this.checkable ? ' mx-8' : ''), onKeyDown: this.onKeyboardHandleKeyDown.bind(this) }), this.isDragging && (h("p", { class: "sr-only", role: "alert" }, "Use the arrow keys to move the row up and down. Press Space or Enter to accept. Press Escape to cancel.")))), h("div", { ref: el => (this.firstCellTarget = el), class: "contents" }), this.subheader && (h("button", { type: "button", class: "flex border-0 items-center h-40 justify-end px-12", "aria-label": "Toggle visibility of rows grouped under this one", onClick: () => (this.collapseNestedRows = !this.collapseNestedRows), onMouseDown: e => e.preventDefault() }, h("i", { class: 'subheader-chevron mds-chevron-down text-icon transform' +
        (!this.collapseNestedRows ? ' rotate-180' : '') })))), h("slot", null), this.actions.length === 1 && (h("div", { class: "action-cell flex items-center justify-end col-span-1" }, h("mx-button", Object.assign({ "data-testid": "action-button", "btn-type": "text" }, this.actions[0]), this.actions[0].value))), this.actions.length > 1 && (h("div", { class: "action-cell flex items-center justify-end col-span-1" }, h("mx-icon-button", { ref: el => (this.actionMenuButton = el), "el-aria-label": "Row Actions", icon: "mds-dots-vertical transform rotate-90" }), h("mx-menu", { "data-testid": "action-menu", ref: el => (this.actionMenu = el), onMxClose: e => e.stopPropagation() }, this.actions.map(action => (h("mx-menu-item", Object.assign({}, action), action.value))))))), h("div", { ref: el => (this.childRowWrapper = el), class: "contents" })));
  }
  get element() { return getElement(this); }
  static get watchers() { return {
    "collapseNestedRows": ["onCollapseNestedRowsChange"]
  }; }
};

export { MxLinearProgress as mx_linear_progress, MxPagination as mx_pagination, MxTableCell as mx_table_cell, MxTableRow as mx_table_row };

//# sourceMappingURL=mx-linear-progress_4.entry.js.map