import { r as registerInstance, c as createEvent, h, H as Host, g as getElement } from './index-b37ad95b.js';
import { e as expand, d as collapse } from './transitions-ed8f0c75.js';
import { u as uuidv4 } from './utils-c62bee0c.js';

const MxMenuAccordion = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.mxClose = createEvent(this, "mxClose", 7);
    this.mxOpen = createEvent(this, "mxOpen", 7);
    this.isClosing = false;
    this.uuid = uuidv4();
    this.anchorEl = undefined;
    this.isOpen = false;
  }
  onClick(e) {
    const anchorElWasClicked = this.anchorEl && this.anchorEl.contains(e.target);
    if (!anchorElWasClicked)
      return;
    e.preventDefault();
    this.isOpen ? this.closeMenu() : this.openMenu();
  }
  async toggleMenu() {
    return this.isOpen ? this.closeMenu : this.openMenu;
  }
  async openMenu() {
    if (this.isOpen || !this.anchorEl)
      return false;
    this.isOpen = true;
    this.mxOpen.emit();
    await new Promise(requestAnimationFrame);
    await expand(this.menuElem);
    return true;
  }
  setAnchorElAttributes() {
    if (!this.anchorEl)
      return;
    this.anchorEl.setAttribute('aria-controls', this.uuid);
    this.setAnchorAriaExpanded(this.isOpen);
  }
  async closeMenu(skipTransition = false) {
    if (!this.isOpen || this.isClosing)
      return false;
    this.isClosing = true;
    this.setAnchorAriaExpanded(false);
    this.menuItems.forEach(m => m.closeSubMenu());
    await collapse(this.menuElem, !skipTransition ? undefined : 0);
    this.isClosing = false;
    this.mxClose.emit();
    this.isOpen = false;
    return true;
  }
  componentDidLoad() {
    if (this.menuItems.length) {
      const role = this.element.querySelector('[role="option"]') ? 'listbox' : 'menu';
      this.menuElem.setAttribute('role', role);
    }
    this.setAnchorElAttributes();
  }
  componentWillUpdate() {
    this.setAnchorAriaExpanded(this.isOpen);
    const anyMenuItemHasIcon = this.menuItems.some(m => !!m.icon);
    if (anyMenuItemHasIcon) {
      this.menuItems.forEach(m => {
        if (m.icon === undefined)
          m.icon = null;
      });
    }
  }
  setAnchorAriaExpanded(isExpanded = false) {
    if (!this.anchorEl)
      return;
    this.anchorEl.setAttribute('aria-expanded', isExpanded.toString());
  }
  get menuItems() {
    return (Array.from(this.menuElem.children).filter(e => e.tagName === 'MX-MENU-ITEM') ||
      []);
  }
  get hostClass() {
    let str = 'mx-menu-accordion block z-50';
    if (!this.isOpen)
      str += ' invisible h-0 overflow-hidden';
    return str;
  }
  render() {
    return (h(Host, { class: this.hostClass }, h("div", { id: this.uuid, ref: el => (this.menuElem = el), class: "flex flex-col overflow-hidden rounded-b pl-12" }, h("slot", null))));
  }
  get element() { return getElement(this); }
  static get watchers() { return {
    "anchorEl": ["setAnchorElAttributes"]
  }; }
};

export { MxMenuAccordion as mx_menu_accordion };

//# sourceMappingURL=mx-menu-accordion.entry.js.map