import { q as queryPrefersReducedMotion } from './utils-c62bee0c.js';

var Direction;
(function (Direction) {
  Direction["top"] = "top";
  Direction["right"] = "right";
  Direction["bottom"] = "bottom";
  Direction["left"] = "left";
})(Direction || (Direction = {}));
const FADE_IN = {
  property: 'opacity',
  startValue: '0',
  endValue: '1',
  timing: 'cubic-bezier(0.4, 0, 0.2, 1)',
};
const FADE_OUT = {
  property: 'opacity',
  startValue: '1',
  endValue: '0',
  timing: 'ease',
};
const SCALE_IN = {
  property: 'transform',
  startValue: 'scale(0.8)',
  endValue: 'scale(1)',
  timing: 'cubic-bezier(0.4, 0, 0.2, 1)',
};
const getSlideOptions = (direction, isSlidingIn = true, timing = 'cubic-bezier(0.4, 0, 0.2, 1)') => {
  const translate = [0, 0, 0];
  let translatePercent = 100;
  if ([Direction.top, Direction.left].includes(direction))
    translatePercent *= -1;
  let translateCoordsIndex = 0;
  if ([Direction.top, Direction.bottom].includes(direction))
    translateCoordsIndex = 1;
  translate[translateCoordsIndex] = translatePercent;
  const translateString = translate.map(p => (p === 0 ? p : p + '%')).join(', ');
  return {
    property: 'transform',
    startValue: `translate3d(${isSlidingIn ? translateString : '0, 0, 0'})`,
    endValue: `translate3d(${!isSlidingIn ? translateString : '0, 0, 0'})`,
    timing,
  };
};
const fadeIn = (el, duration = 180) => {
  return executeTransition(el, [FADE_IN], duration);
};
const fadeOut = (el, duration = 150) => {
  return executeTransition(el, [FADE_OUT], duration);
};
const fadeScaleIn = (el, duration = 150, transformOrigin) => {
  return executeTransition(el, [FADE_IN, SCALE_IN], duration, transformOrigin);
};
const fadeSlideIn = (el, duration = 250, fromDirection = Direction.right, timing = null) => {
  return executeTransition(el, [getSlideOptions(fromDirection, true, timing), FADE_IN], duration);
};
const fadeSlideOut = (el, duration = 200, toDirection = Direction.right, timing = null) => {
  return executeTransition(el, [getSlideOptions(toDirection, false, timing), FADE_OUT], duration);
};
const slideIn = (el, duration = 250, fromDirection = Direction.top, timing = null) => {
  return executeTransition(el, [getSlideOptions(fromDirection, true, timing)], duration);
};
const slideOut = (el, duration = 200, toDirection = Direction.top, timing = null) => {
  return executeTransition(el, [getSlideOptions(toDirection, false, timing)], duration);
};
const collapse = async (el, duration = 150, collapsedHeight = '0') => {
  const options = {
    property: 'max-height',
    startValue: el.scrollHeight + 'px',
    endValue: collapsedHeight,
    timing: 'cubic-bezier(0.4, 0, 0.2, 1)',
  };
  return executeTransition(el, [options], duration);
};
const expand = async (el, duration = 150) => {
  const startValue = el.style.maxHeight || '0';
  el.style.maxHeight = '';
  const expandedHeight = el.scrollHeight;
  const options = {
    property: 'max-height',
    startValue,
    endValue: expandedHeight + 'px',
    timing: 'cubic-bezier(0.4, 0, 0.2, 1)',
  };
  await executeTransition(el, [options], duration);
  el.style.maxHeight = '';
};
function executeTransition(el, transitionOptions, duration, transformOrigin) {
  return new Promise(async (resolve) => {
    if (queryPrefersReducedMotion() || typeof jest !== 'undefined')
      return resolve();
    transitionOptions.forEach(transition => {
      setStyleProperty(el, transition.property, transition.startValue);
    });
    if (transformOrigin)
      el.style.transformOrigin = transformOrigin;
    await new Promise(requestAnimationFrame);
    el.style.transition = transitionOptions
      .map(transition => {
      return `${transition.property} ${duration}ms ${transition.timing}`;
    })
      .join(', ');
    await new Promise(requestAnimationFrame);
    if (!el)
      return;
    requestAnimationFrame(() => {
      transitionOptions.forEach(transition => {
        setStyleProperty(el, transition.property, transition.endValue);
      });
    });
    setTimeout(resolve, duration);
  });
}
function setStyleProperty(el, property, value) {
  if (!el)
    return;
  if (property !== 'transform') {
    el.style[property] = value;
  }
  else {
    const matchTransforms = /\w*\((-?((\d+)|(\d*\.\d+))\w*,\s*)*(-?(\d+)|(\d*\.\d+))\w*\)/gi;
    let transforms = el.style.transform.match(matchTransforms) || [];
    const transformName = /^(\w*)\(/.exec(value)[1];
    transforms = transforms.filter(t => !t.startsWith(transformName));
    transforms.push(value);
    el.style.transform = transforms.join(' ');
  }
}

export { Direction as D, slideOut as a, fadeScaleIn as b, fadeOut as c, collapse as d, expand as e, fadeIn as f, fadeSlideIn as g, fadeSlideOut as h, slideIn as s };

//# sourceMappingURL=transitions-ed8f0c75.js.map