import { EventEmitter } from '../../stencil-public-runtime';
import { MinWidths } from '../../utils/minWidthSync';
import { IMxMenuItemProps } from '../mx-menu-item/mx-menu-item';
import { PageChangeEventDetail } from '../mx-pagination/mx-pagination';
export interface ITableRowAction extends IMxMenuItemProps {
  value: string;
}
export type SortChangeEventDetail = {
  sortBy: string;
  sortAscending: boolean;
};
export interface ITableColumn {
  property?: string;
  heading?: string;
  type?: 'string' | 'number' | 'date' | 'dateTime' | 'boolean';
  align?: 'left' | 'center' | 'right';
  sortable?: boolean;
  getValue?: (row: unknown, rowIndex?: number) => any;
  sortCompare?: (rowA: unknown, rowB: unknown) => number;
  headerClass?: string;
  cellClass?: string;
  isActionColumn?: boolean;
}
export declare class MxTable {
  actionMenu: HTMLMxMenuElement;
  actionMenuButton: HTMLMxButtonElement;
  hasDefaultSlot: boolean;
  hasSearch: boolean;
  hasFilter: boolean;
  hasFooter: boolean;
  showOperationsBar: boolean;
  dragRowEl: HTMLMxTableRowElement;
  dragRowElSiblings: HTMLMxTableRowElement[];
  dragOverRowEl: HTMLMxTableRowElement;
  dragRowElIndex: number;
  dragOverRowElIndex: number;
  dragRowElHeight: number;
  dragMoveHandler: (e: MouseEvent) => any;
  autoWidth: boolean;
  checkable: boolean;
  checkOnRowClick: boolean;
  columns: ITableColumn[];
  disableNextPage: boolean;
  disablePagination: boolean;
  draggableRows: boolean;
  getGroupByHeading: (row: unknown) => string;
  getMultiRowActions: (rows: string[]) => ITableRowAction[];
  getRowActions: (row: unknown) => ITableRowAction[];
  getRowId: (row: unknown) => string;
  groupBy: string;
  hoverable: boolean;
  mobileSearchOnTop: boolean;
  mutateOnDrag: boolean;
  operationsBarClass: string;
  page: number;
  paginate: boolean;
  progressAppearDelay: number;
  progressValue: number;
  rows: unknown[];
  rowsPerPage: number;
  rowsPerPageOptions: number[];
  serverPaginate: boolean;
  showCheckAll: boolean;
  showProgressBar: boolean;
  sortAscending: boolean;
  sortBy: string;
  totalRows: number;
  minWidths: MinWidths;
  checkedRowIds: string[];
  element: HTMLMxTableElement;
  mxSortChange: EventEmitter<SortChangeEventDetail>;
  mxRowCheck: EventEmitter<string[]>;
  mxCheckAll: EventEmitter<boolean>;
  mxVisibleRowsChange: EventEmitter<unknown[]>;
  mxRowMove: EventEmitter<any>;
  onMxCheck(e: CustomEvent): void;
  onMxRowDragStart(e: CustomEvent): Promise<void>;
  onDragKeyDown(e: CustomEvent): Promise<void>;
  onMxRowDragEnd(e: CustomEvent): Promise<void>;
  onVisibleRowsChange(): void;
  onPageChange(): void;
  resetPage(): void;
  getCheckedRowIds(): Promise<string[]>;
  setCheckedRowIds(checkedRowIds?: string[]): Promise<void>;
  checkAll(): Promise<void>;
  checkNone(): Promise<void>;
  hasActionsColumnFromSlot: boolean;
  getTableRows(): HTMLMxTableRowElement[];
  onCheckAllClick(e: InputEvent): void;
  onDragMove(e?: MouseEvent): void;
  reorderRowsArray(): Promise<void>;
  setCellProps(): void;
  getRowGroup(row: any): string;
  setRowsChecked(): void;
  connectedCallback(): void;
  componentWillLoad(): void;
  componentWillRender(): void;
  componentDidRender(): void;
  componentDidLoad(): void;
  disconnectedCallback(): void;
  get cols(): ITableColumn[];
  get uniqueGroups(): string[];
  get groupedRows(): unknown[];
  get visibleRows(): unknown[];
  get visibleGroups(): string[];
  get allRowsChecked(): boolean;
  get someRowsChecked(): boolean;
  get multiRowActions(): ITableRowAction[];
  get hasActionsColumn(): boolean;
  get scrollClass(): string;
  get operationsBarStyle(): any;
  get searchStyle(): any;
  get checkAllClass(): string;
  get filterClass(): string;
  get gridStyle(): any;
  get emptyStateClass(): string;
  sortRows(rows: unknown[]): void;
  getCellSortableValue(row: unknown, col: ITableColumn): string | number;
  getCellValue(row: unknown, col: ITableColumn, rowIndex: number): any;
  getHeaderClass(col: ITableColumn, colIndex: number): string;
  getHeaderArrowClass(col: ITableColumn): string;
  getAlignClasses(col: ITableColumn): string[];
  getRowJsx(row: any, rowIndex: number): any;
  onHeaderClick(col: ITableColumn): void;
  onMxPageChange(e: {
    detail: PageChangeEventDetail;
  }): void;
  setLastRowClass(): void;
  render(): any;
}
